/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 34083
 |                DRUG ABUSE WARNING NETWORK (DAWN), 2010
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\34083-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
VALUE toxtestf  -9='(-9) MISSING:(-9)' -7='(-7) NOT APPLICABLE:(-7)'
                1='(1) CONFIRMED TEST:(1)' 2='(2) NOT CONFIRMED:(2)';
VALUE casetypf  1='(1) SUICICDE ATTEMPT:(1)' 2='(2) SEEKING DETOX:(2)'
                3='(3) ALCOHOL ONLY (AGE < 21):(3)' 4='(4) ADVERSE REACTION:(4)'
                5='(5) OVERMEDICATION:(5)' 6='(6) MALICIOUS POISONING:(6)'
                7='(7) ACCIDENTAL INGESTION:(7)' 8='(8) OTHER:(8)';
VALUE sdled_1f  -7='(-7) NOT APPLICABLE:(-7)' 1='(01) MAJOR SUBSTANCES OF ABUSE:(1)'
                17='(17) OTHER SUBSTANCES:(17)';
VALUE catid_3f  -7='(-007) NOT APPLICABLE:(-7)' 31='(0031) BACTERIAL VACCINES:(31)'
                32='(0032) COLONY STIMULATING FACTORS:(32)' 38='(0038) VIRAL VACCINES:(38)'
                61='(0061) NONSTEROIDAL ANTI-INFLAMMATORY AGENTS:(61)' 68='(0068) BARBITURATES:(68)'
                69='(0069) BENZODIAZEPINES:(69)'
                70='(0070) MISCELLANEOUS ANXIOLYTICS, SEDATIVES AND HYPNOTICS:(70)'
                74='(0074) NEUROMUSCULAR BLOCKING AGENTS:(74)'
                76='(0076) MISCELLANEOUS ANTIDEPRESSANTS:(76)'
                77='(0077) MISCELLANEOUS ANTIPSYCHOTIC AGENTS:(77)'
                79='(0079) PSYCHOTHERAPEUTIC COMBINATIONS:(79)'
                89='(0089) ANTICHOLINERGICS/ANTISPASMODICS:(89)' 102='(0102) CONTRACEPTIVES:(102)'
                126='(0126) METHYLXANTHINES:(126)' 137='(0137) TOPICAL ANTI-INFECTIVES:(137)'
                138='(0138) TOPICAL STEROIDS:(138)' 139='(0139) TOPICAL ANESTHETICS:(139)'
                140='(0140) MISCELLANEOUS TOPICAL AGENTS:(140)'
                141='(0141) TOPICAL STEROIDS WITH ANTI-INFECTIVES:(141)'
                143='(0143) TOPICAL ACNE AGENTS:(143)' 144='(0144) TOPICAL ANTIPSORIATICS:(144)'
                149='(0149) SPERMICIDES:(149)' 154='(0154) LOOP DIURETICS:(154)'
                155='(0155) POTASSIUM-SPARING DIURETICS:(155)'
                156='(0156) THIAZIDE AND THIAZIDE-LIKE DIURETICS:(156)'
                157='(0157) CARBONIC ANHYDRASE INHIBITORS:(157)'
                158='(0158) MISCELLANEOUS DIURETICS:(158)'
                159='(0159) FIRST GENERATION CEPHALOSPORINS:(159)'
                160='(0160) SECOND GENERATION CEPHALOSPORINS:(160)'
                161='(0161) THIRD GENERATION CEPHALOSPORINS:(161)'
                162='(0162) FOURTH GENERATION CEPHALOSPORINS:(162)'
                163='(0163) OPHTHALMIC ANTI-INFECTIVES:(163)'
                164='(0164) OPHTHALMIC GLAUCOMA AGENTS:(164)' 165='(0165) OPHTHALMIC STEROIDS:(165)'
                166='(0166) OPHTHALMIC STEROIDS WITH ANTI-INFECTIVES:(166)'
                167='(0167) OPHTHALMIC ANTI-INFLAMMATORY AGENTS:(167)'
                168='(0168) OPHTHALMIC LUBRICANTS AND IRRIGATIONS:(168)'
                169='(0169) MISCELLANEOUS OPHTHALMIC AGENTS:(169)'
                170='(0170) OTIC ANTI-INFECTIVES:(170)'
                171='(0171) OTIC STEROIDS WITH ANTI-INFECTIVES:(171)'
                172='(0172) MISCELLANEOUS OTIC AGENTS:(172)'
                173='(0173) HMG-COA REDUCTASE INHIBITORS:(173)'
                174='(0174) MISCELLANEOUS ANTIHYPERLIPIDEMIC AGENTS:(174)'
                175='(0175) PROTEASE INHIBITORS:(175)' 176='(0176) NRTIS:(176)'
                177='(0177) MISCELLANEOUS ANTIVIRALS:(177)' 178='(0178) SKELETAL MUSCLE RELAXANTS:(178)'
                179='(0179) SKELETAL MUSCLE RELAXANT COMBINATIONS:(179)'
                180='(0180) ADRENERGIC BRONCHODILATORS:(180)'
                181='(0181) BRONCHODILATOR COMBINATIONS:(181)'
                182='(0182) ANDROGENS AND ANABOLIC STEROIDS:(182)' 183='(0183) ESTROGENS:(183)'
                184='(0184) GONADOTROPINS:(184)' 185='(0185) PROGESTINS:(185)'
                186='(0186) SEX HORMONE COMBINATIONS:(186)' 187='(0187) MISCELLANEOUS SEX HORMONES:(187)'
                193='(0193) ANTIMIGRAINE AGENTS:(193)' 195='(0195) 5HT3 RECEPTOR ANTAGONISTS:(195)'
                196='(0196) PHENOTHIAZINE ANTIEMETICS:(196)'
                197='(0197) ANTICHOLINERGIC ANTIEMETICS:(197)'
                198='(0198) MISCELLANEOUS ANTIEMETICS:(198)' 199='(0199) HYDANTOIN ANTICONVULSANTS:(199)'
                200='(0200) SUCCINIMIDE ANTICONVULSANTS:(200)'
                201='(0201) BARBITURATE ANTICONVULSANTS:(201)'
                202='(0202) OXAZOLIDINEDIONE ANTICONVULSANTS:(202)'
                203='(0203) BENZODIAZEPINE ANTICONVULSANTS:(203)'
                204='(0204) MISCELLANEOUS ANTICONVULSANTS:(204)'
                205='(0205) ANTICHOLINERGIC ANTIPARKINSON AGENTS:(205)'
                206='(0206) MISCELLANEOUS ANTIPARKINSON AGENTS:(206)'
                208='(0208) SSRI ANTIDEPRESSANTS:(208)' 209='(0209) TRICYCLIC ANTIDEPRESSANTS:(209)'
                210='(0210) PHENOTHIAZINE ANTIPSYCHOTICS:(210)'
                211='(0211) PLATELET AGGREGATION INHIBITORS:(211)'
                212='(0212) GLYCOPROTEIN PLATELET INHIBITORS:(212)' 213='(0213) SULFONYLUREAS:(213)'
                214='(0214) BIGUANIDES:(214)' 215='(0215) INSULIN:(215)'
                216='(0216) ALPHA-GLUCOSIDASE INHIBITORS:(216)' 217='(0217) BISPHOSPHONATES:(217)'
                222='(0222) PENICILLINASE RESISTANT PENICILLINS:(222)'
                223='(0223) ANTIPSEUDOMONAL PENICILLINS:(223)' 224='(0224) AMINOPENICILLINS:(224)'
                225='(0225) BETA-LACTAMASE INHIBITORS:(225)' 226='(0226) NATURAL PENICILLINS:(226)'
                227='(0227) NNRTIS:(227)' 228='(0228) ADAMANTANE ANTIVIRALS:(228)'
                229='(0229) PURINE NUCLEOSIDES:(229)' 230='(0230) AMINOSALICYLATES:(230)'
                231='(0231) NICOTINIC ACID DERIVATIVES:(231)' 232='(0232) RIFAMYCIN DERIVATIVES:(232)'
                233='(0233) STREPTOMYCES DERIVATIVES:(233)'
                234='(0234) MISCELLANEOUS ANTITUBERCULOSIS AGENTS:(234)' 235='(0235) POLYENES:(235)'
                236='(0236) AZOLE ANTIFUNGALS:(236)' 237='(0237) MISCELLANEOUS ANTIFUNGALS:(237)'
                238='(0238) ANTIMALARIAL QUINOLINES:(238)' 239='(0239) MISCELLANEOUS ANTIMALARIALS:(239)'
                241='(0241) FIBRIC ACID DERIVATIVES:(241)'
                244='(0244) NASAL LUBRICANTS AND IRRIGATIONS:(244)' 245='(0245) NASAL STEROIDS:(245)'
                246='(0246) NASAL ANTIHISTAMINES AND DECONGESTANTS:(246)'
                248='(0248) TOPICAL EMOLLIENTS:(248)' 250='(0250) MONOAMINE OXIDASE INHIBITORS:(250)'
                252='(0252) BILE ACID SEQUESTRANTS:(252)' 256='(0256) INTERFERONS:(256)'
                261='(0261) HEPARINS:(261)' 262='(0262) COUMARINS AND INDANEDIONES:(262)'
                267='(0267) OPHTHALMIC ANTIHISTAMINES AND DECONGESTANTS:(267)'
                268='(0268) VAGINAL ANTI-INFECTIVES:(268)'
                269='(0269) MISCELLANEOUS VAGINAL AGENTS:(269)' 271='(0271) THIAZOLIDINEDIONES:(271)'
                274='(0274) CARDIOSELECTIVE BETA BLOCKERS:(274)'
                275='(0275) NON-CARDIOSELECTIVE BETA BLOCKERS:(275)'
                276='(0276) DOPAMINERGIC ANTIPARKINSONISM AGENTS:(276)'
                278='(0278) COX-2 INHIBITORS:(278)'
                279='(0279) GONADOTROPIN-RELEASING HORMONE AND ANALOGS:(279)'
                280='(0280) THIOXANTHENES:(280)' 281='(0281) NEURAMINIDASE INHIBITORS:(281)'
                282='(0282) MEGLITINIDES:(282)' 283='(0283) THROMBIN INHIBITORS:(283)'
                285='(0285) FACTOR XA INHIBITORS:(285)' 286='(0286) MYDRIATICS:(286)'
                287='(0287) OPHTHALMIC ANESTHETICS:(287)' 290='(0290) TOPICAL ANTIBIOTICS:(290)'
                291='(0291) TOPICAL ANTIVIRALS:(291)' 292='(0292) TOPICAL ANTIFUNGALS:(292)'
                296='(0296) INHALED CORTICOSTEROIDS:(296)' 297='(0297) MUCOLYTICS:(297)'
                298='(0298) MAST CELL STABILIZERS:(298)'
                299='(0299) ANTICHOLINERGIC BRONCHODILATORS:(299)' 300='(0300) CORTICOTROPIN:(300)'
                301='(0301) GLUCOCORTICOIDS:(301)' 302='(0302) MINERALOCORTICOIDS:(302)'
                304='(0304) MACROLIDES:(304)' 305='(0305) KETOLIDES:(305)'
                306='(0306) PHENYLPIPERAZINE ANTIDEPRESSANTS:(306)'
                307='(0307) TETRACYCLIC ANTIDEPRESSANTS:(307)' 308='(0308) SSNRI ANTIDEPRESSANTS:(308)'
                309='(0309) MISCELLANEOUS ANTIDIABETIC AGENTS:(309)' 310='(0310) ECHINOCANDINS:(310)'
                311='(0311) DIBENZAZEPINE ANTICONVULSANTS:(311)'
                314='(0314) ANTIDIABETIC COMBINATIONS:(314)'
                316='(0316) CHOLESTEROL ABSORPTION INHIBITORS:(316)'
                317='(0317) ANTIHYPERLIPIDEMIC COMBINATIONS:(317)'
                321='(0321) OPHTHALMIC DIAGNOSTIC AGENTS:(321)'
                322='(0322) OPHTHALMIC SURGICAL AGENTS:(322)' 327='(0327) ANTIVIRAL COMBINATIONS:(327)'
                328='(0328) ANTIMALARIAL COMBINATIONS:(328)'
                329='(0329) ANTITUBERCULOSIS COMBINATIONS:(329)' 330='(0330) ANTIVIRAL INTERFERONS:(330)'
                333='(0333) MISCELLANEOUS IODINATED CONTRAST MEDIA:(333)'
                334='(0334) LYMPHATIC STAINING AGENTS:(334)'
                335='(0335) MAGNETIC RESONANCE IMAGING CONTRAST MEDIA:(335)'
                336='(0336) NON-IODINATED CONTRAST MEDIA:(336)'
                337='(0337) ULTRASOUND CONTRAST MEDIA:(337)'
                338='(0338) DIAGNOSTIC RADIOPHARMACEUTICALS:(338)'
                339='(0339) THERAPEUTIC RADIOPHARMACEUTICALS:(339)'
                341='(0341) ATYPICAL ANTIPSYCHOTICS:(341)'
                345='(0345) FATTY ACID DERIVATIVE ANTICONVULSANTS:(345)'
                346='(0346) GAMMA-AMINOBUTYRIC ACID REUPTAKE INHIBITORS:(346)'
                347='(0347) GAMMA-AMINOBUTYRIC ACID ANALOGS:(347)'
                348='(0348) TRIAZINE ANTICONVULSANTS:(348)' 349='(0349) CARBAMATE ANTICONVULSANTS:(349)'
                350='(0350) PYRROLIDINE ANTICONVULSANTS:(350)'
                351='(0351) CARBONIC ANHYDRASE INHIBITOR ANTICONVULSANTS:(351)'
                352='(0352) UREA ANTICONVULSANTS:(352)'
                353='(0353) ANTI-ANGIOGENIC OPHTHALMIC AGENTS:(353)'
                356='(0356) SEROTONINERGIC NEUROENTERIC MODULATORS:(356)'
                362='(0362) CHLORIDE CHANNEL ACTIVATORS:(362)'
                364='(0364) ANTIVIRAL CHEMOKINE RECEPTOR ANTAGONIST:(364)'
                366='(0366) INTEGRASE STRAND TRANSFER INHIBITOR:(366)'
                368='(0368) NON-IONIC IODINATED CONTRAST MEDIA:(368)'
                369='(0369) IONIC IODINATED CONTRAST MEDIA:(369)' 370='(0370) OTIC STEROIDS:(370)'
                371='(0371) DIPEPTIDYL PEPTIDASE 4 INHIBITORS:(371)' 372='(0372) AMYLIN ANALOGS:(372)'
                373='(0373) INCRETIN MIMETICS:(373)' 374='(0374) CARDIAC STRESSING AGENTS:(374)'
                375='(0375) PERIPHERAL OPIOID RECEPTOR ANTAGONISTS:(375)'
                379='(0379) FIFTH GENERATION CEPHALOSPORINS:(379)'
                380='(0380) TOPICAL DEBRIDING AGENTS:(380)'
                381='(0381) TOPICAL DEPIGMENTING AGENTS:(381)' 382='(0382) TOPICAL ANTIHISTAMINES:(382)'
                385='(0385) GROUP I ANTIARRHYTHMICS:(385)' 387='(0387) GROUP III ANTIARRHYTHMICS:(387)'
                389='(0389) GROUP V ANTIARRHYTHMICS:(389)' 392='(0392) OTIC ANESTHETICS:(392)'
                393='(0393) CERUMENOLYTICS:(393)' 394='(0394) TOPICAL ASTRINGENTS:(394)'
                395='(0395) TOPICAL KERATOLYTICS:(395)'
                415='(0415) MISCELLANEOUS BONE RESORPTION INHIBITORS:(415)'
                432='(0432) VACCINE COMBINATIONS:(432)' 439='(0439) OTHER IMMUNOSTIMULANTS:(439)'
                440='(0440) THERAPEUTIC VACCINES:(440)' 441='(0441) CALCINEURIN INHIBITORS:(441)'
                442='(0442) TNF ALFA INHIBITORS:(442)' 443='(0443) INTERLEUKIN INHIBITORS:(443)'
                444='(0444) SELECTIVE IMMUNOSUPPRESSANTS:(444)'
                445='(0445) OTHER IMMUNOSUPPRESSANTS:(445)'
                448='(0448) TOPICAL NON-STEROIDAL ANTI-INFLAMMATORIES:(448)'
                2005='(2005) ALCOHOL IN COMBINATION:(2005)'
                2007='(2007) MISCELLANEOUS BRONCHODILATORS:(2007)'
                2008='(2008) MISCELLANEOUS NASAL PREPARATIONS:(2008)'
                2030='(2030) MISCELLANEOUS BETA-ADRENERGIC BLOCKING AGENTS:(2030)'
                2031='(2031) MISCELLANEOUS HALLUCINOGENS:(2031)'
                2032='(2032) ILLICIT MAJOR SUBSTANCE OF ABUSE:(2032)'
                2033='(2033) ILLICIT COMBINATIONS:(2033)'
                2034='(2034) ILLICIT AND OTHER COMBINATIONS:(2034)'
                2036='(2036) MISCELLANEOUS CEPHALOSPORINS:(2036)' 2043='(2043) VOLATILE AGENT:(2043)'
                2044='(2044) NITRITES:(2044)' 2045='(2045) CHLORO-FLUORO-HYDROCARBONS:(2045)'
                2046='(2046) MISCELLANEOUS MUSCLE RELAXANTS:(2046)'
                2047='(2047) NARCOTIC ANALGESICS/COMBINATIONS:(2047)'
                2048='(2048) SALICYLATES/COMBINATIONS:(2048)'
                2049='(2049) MISCELLANEOUS ANALGESIC/COMBINATIONS:(2049)'
                2050='(2050) ANALGESIC COMBINATIONS NTA:(2050)'
                2052='(2052) MISCELLANEOUS RESPIRATORY INHALANT PRODUCTS:(2052)'
                2053='(2053) MISCELLANEOUS MACROLIDE:(2053)'
                2054='(2054) MISCELLANEOUS ADRENAL CORTICAL STEROIDS:(2054)'
                2055='(2055) MISCELLANEOUS RADIOCONTRAST AGENTS:(2055)'
                2056='(2056) MISCELLANEOUS RADIOPHARMACEUTICALS:(2056)';
VALUE quarterf  1='(1) 1ST (JANUARY TO MARCH):(1)' 2='(2) 2ND (APRIL TO JUNE):(2)'
                3='(3) 3RD (JULY TO SEPTEMBER):(3)' 4='(4) 4TH (OCTOBER TO DECEMBER):(4)';
VALUE nonmedpf  0='(0) EPISODE DOES NOT INVOLVE NON-MEDICAL USE OF PHARMACEUTICALS:(0)'
                1='(1) EPISODE INVOLVES NON-MEDICAL USE OF PHARMACEUTICALS:(1)';
VALUE sdled_5f  -7='(-00007) NOT APPLICABLE' 20.41='(000020) NEFAZODONE:(20.41)'
                20.42='(000020) TRAZODONE:(20.42)' 20.71='(000020) DESVENLAFAXINE:(20.71)'
                20.72='(000020) DULOXETINE:(20.72)' 20.73='(000020) VENLAFAXINE:(20.73)'
                20.79='(000020) SSNRI ANTIDEPRESSANTS NTA:(20.79)' 21.01='(000021) CITALOPRAM:(21.01)'
                21.02='(000021) FLUOXETINE:(21.02)' 21.03='(000021) FLUVOXAMINE:(21.03)'
                21.04='(000021) PAROXETINE:(21.04)' 21.05='(000021) SERTRALINE:(21.05)'
                21.09='(000021) SSRI ANTIDEPRESSANTS NTA:(21.09)' 21.51='(000021) MAPROTILINE:(21.51)'
                21.52='(000021) MIRTAZAPINE:(21.52)' 22.01='(000022) AMITRIPTYLINE:(22.01)'
                22.02='(000022) DESIPRAMINE:(22.02)' 22.03='(000022) DOXEPIN:(22.03)'
                22.04='(000022) IMIPRAMINE:(22.04)' 22.05='(000022) NORTRIPTYLINE:(22.05)'
                22.06='(000022) TRICYCLIC ANTIDEPRESSANTS-NOS:(22.06)'
                22.09='(000022) TRICYCLIC ANTIDEPRESSANTS NTA:(22.09)' 23.01='(000023) BUPROPION:(23.01)'
                23.06='(000023) ANTIDEPRESSANTS-NOS:(23.06)'
                23.09='(000023) MISCELLANEOUS ANTIDEPRESSANTS NTA:(23.09)'
                25.01='(000025) CLOZAPINE:(25.01)' 25.02='(000025) OLANZAPINE:(25.02)'
                25.03='(000025) QUETIAPINE:(25.03)' 25.04='(000025) RISPERIDONE:(25.04)'
                25.09='(000025) ATYPICAL ANTIPSYCHOTICS NTA:(25.09)'
                26.01='(000026) CHLORPROMAZINE:(26.01)' 26.02='(000026) FLUPHENAZINE:(26.02)'
                26.03='(000026) PERPHENAZINE:(26.03)' 26.04='(000026) PROCHLORPERAZINE:(26.04)'
                26.05='(000026) THIORIDAZINE:(26.05)' 26.06='(000026) TRIFLUPROMAZINE:(26.06)'
                26.09='(000026) PHENOTHIAZINE ANTIPSYCHOTICS NTA:(26.09)'
                27.01='(000027) HALOPERIDOL:(27.01)' 27.02='(000027) LITHIUM:(27.02)'
                27.09='(000027) MISCELLANEOUS ANTIPSYCHOTIC AGENTS NTA:(27.09)'
                36.75='(000036) OPIATES/OPIOIDS, UNSPECIFIED:(36.75)'
                37.5='(000037) NARCOTIC ANALGESICS:(37.5)'
                39.01='(000039) IBUPROFEN/COMBINATIONS:(39.01)'
                39.02='(000039) NAPROXEN/COMBINATIONS:(39.02)'
                39.03='(000039) NONSTEROIDAL ANTI-INFLAMMATORY AGENTS NTA:(39.03)'
                40.501='(000040) ASPIRIN/COMBINATIONS:(40.501)'
                40.502='(000040) SALICYLATES-NOS:(40.502)'
                40.503='(000040) SALICYLATES/COMBINATIONS NTA:(40.503)'
                41.501='(000041) ACETAMINOPHEN/COMBINATIONS:(41.501)'
                41.502='(000041) TRAMADOL/COMBINATIONS:(41.502)'
                41.505='(000041) ANALGESICS-NOS:(41.505)'
                41.506='(000041) MISCELLANEOUS ANALGESIC/COMBINATIONS NTA:(41.506)'
                44.041='(000044) TOPIRAMATE:(44.041)'
                44.049='(000044) CARBONIC ANHYDRASE INHIBITOR ANTICONVULSANTS NTA:(44.049)'
                44.051='(000044) CARBAMAZEPINE:(44.051)' 44.052='(000044) OXCARBAZEPINE:(44.052)'
                44.053='(000044) RUFINAMIDE:(44.053)' 44.061='(000044) DIVALPROEX SODIUM:(44.061)'
                44.062='(000044) VALPROIC ACID:(44.062)' 44.071='(000044) GABAPENTIN:(44.071)'
                44.079='(000044) GAMMA-AMINOBUTYRIC ACID ANALOGS NTA:(44.079)'
                44.091='(000044) PHENYTOIN:(44.091)'
                44.099='(000044) HYDANTOIN ANTICONVULSANTS NTA:(44.099)'
                46.011='(000046) BENZTROPINE:(46.011)'
                46.019='(000046) ANTICHOLINERGIC ANTIPARKINSON AGENTS NTA:(46.019)'
                46.3101='(000046) PHENOBARBITAL:(46.3101)' 46.3102='(000046) BARBITURATES-NOS:(46.3102)'
                46.3109='(000046) BARBITURATES NTA:(46.3109)' 46.3201='(000046) ALPRAZOLAM:(46.3201)'
                46.3202='(000046) CHLORDIAZEPOXIDE:(46.3202)' 46.3203='(000046) CLONAZEPAM:(46.3203)'
                46.3204='(000046) CLORAZEPATE:(46.3204)' 46.3205='(000046) DIAZEPAM:(46.3205)'
                46.3206='(000046) FLURAZEPAM:(46.3206)' 46.3207='(000046) LORAZEPAM:(46.3207)'
                46.3208='(000046) OXAZEPAM:(46.3208)' 46.3209='(000046) TEMAZEPAM:(46.3209)'
                46.321='(000046) TRIAZOLAM:(46.321)' 46.3211='(000046) BENZODIAZEPINES-NOS:(46.3211)'
                46.3219='(000046) BENZODIAZEPINES NTA:(46.3219)' 46.3301='(000046) BUSPIRONE:(46.3301)'
                46.3302='(000046) CHLORAL HYDRATE:(46.3302)' 46.3303='(000046) DIPHENHYDRAMINE:(46.3303)'
                46.3304='(000046) DOXYLAMINE:(46.3304)' 46.3305='(000046) HYDROXYZINE:(46.3305)'
                46.3306='(000046) ZOLPIDEM:(46.3306)'
                46.3307='(000046) ANXIOLYTICS, SEDATIVES AND HYPNOTICS-NOS:(46.3307)'
                46.3309='(000046) MISC. ANXIOLYTICS, SEDATIVES, AND HYPNOTICS NTA:(46.3309)'
                46.5091='(000046) CAFFEINE/MULTIVITAMIN:(46.5091)'
                46.5092='(000046) OTHER CNS STIMULANTS NTA:(46.5092)'
                48.031='(000048) CARISOPRODOL:(48.031)' 48.032='(000048) CHLORZOXAZONE:(48.032)'
                48.033='(000048) CYCLOBENZAPRINE:(48.033)' 48.034='(000048) METAXALONE:(48.034)'
                48.035='(000048) METHOCARBAMOL:(48.035)' 48.036='(000048) TIZANIDINE:(48.036)'
                48.039='(000048) SKELETAL MUSCLE RELAXANTS NTA:(48.039)'
                56.052='(000056) INHALED CORTICOSTEROIDS:(56.052)'
                56.053='(000056) MAST CELL STABILIZERS:(56.053)' 56.054='(000056) MUCOLYTICS:(56.054)'
                56.059='(000056) MISCELLANEOUS RESPIRATORY INHALANT PRODUCTS:(56.059)'
                59.011='(000059) ATENOLOL:(59.011)'
                59.019='(000059) CARDIOSELECTIVE BETA BLOCKERS NTA:(59.019)'
                59.021='(000059) PROPRANOLOL:(59.021)'
                59.029='(000059) NON-CARDIOSELECTIVE BETA BLOCKERS NTA:(59.029)'
                62.081='(000062) GROUP I ANTIARRHYTHMICS:(62.081)'
                62.083='(000062) GROUP III ANTIARRHYTHMICS:(62.083)'
                62.085='(000062) GROUP V ANTIARRHYTHMICS:(62.085)'
                62.089='(000062) ANTIARRHYTHMIC AGENTS NTA:(62.089)' 62.151='(000062) EPHEDRINE:(62.151)'
                62.159='(000062) VASOPRESSORS NTA:(62.159)';
VALUE sexfffff  -8='(-8) NOT DOCUMENTED:(-8)' 1='(1) MALE:(1)' 2='(2) FEMALE:(2)';
VALUE sdled_4f  -7='(-00007) NOT APPLICABLE:(-7.00)' 5.01='(000005) MARIJUANA:(5.01)'
                5.02='(000005) SYNTHETIC CANNABINOIDS:(5.02)' 6='(000006) AMPHETAMINES:(6)'
                7='(000007) METHAMPHETAMINE:(7)' 7.1='(000007) OTHER STIMULANTS:(7.1)'
                20='(000020) MAO INHIBITORS:(20)' 20.4='(000020) PHENYLPIPERAZINE ANTIDEPRESSANTS:(20.4)'
                20.7='(000020) SSNRI ANTIDEPRESSANTS:(20.7)' 21='(000021) SSRI ANTIDEPRESSANTS:(21)'
                21.5='(000021) TETRACYCLIC ANTIDEPRESSANTS:(21.5)'
                22='(000022) TRICYCLIC ANTIDEPRESSANTS:(22)'
                23='(000023) MISCELLANEOUS ANTIDEPRESSANTS:(23)'
                25='(000025) ATYPICAL ANTIPSYCHOTICS:(25)'
                26='(000026) PHENOTHIAZINE ANTIPSYCHOTICS:(26)'
                26.5='(000026) PSYCHOTHERAPEUTIC COMBINATIONS:(26.5)'
                26.7='(000026) THIOXANTHENES:(26.7)'
                27='(000027) MISCELLANEOUS ANTIPSYCHOTIC AGENTS:(27)'
                35='(000035) ANTIMIGRAINE AGENTS:(35)' 36='(000036) COX-2 INHIBITORS:(36)'
                36.5='(000036) OPIATES/OPIOIDS:(36.5)'
                39='(000039) NONSTEROIDAL ANTI-INFLAMMATORY AGENTS:(39)'
                40.5='(000040) SALICYLATES/COMBINATIONS:(40.5)'
                41.5='(000041) MISCELLANEOUS ANALGESICS/COMBINATIONS:(41.5)'
                42.5='(000042) ANALGESIC COMBINATIONS NTA:(42.5)'
                43.01='(000043) PHENYLPROPANOLAMINE:(43.01)' 43.02='(000043) ANOREXIANTS-NOS:(43.02)'
                43.09='(000043) ANOREXIANTS NTA:(43.09)'
                44.01='(000044) BARBITURATE ANTICONVULSANTS:(44.01)'
                44.02='(000044) BENZODIAZEPINE ANTICONVULSANTS:(44.02)'
                44.03='(000044) CARBAMATE ANTICONVULSANTS:(44.03)'
                44.04='(000044) CARBONIC ANHYDRASE INHIBITOR ANTICONVULSANTS:(44.04)'
                44.05='(000044) DIBENZAZEPINE ANTICONVULSANTS:(44.05)'
                44.06='(000044) FATTY ACID DERIVATIVE ANTICONVULSANTS:(44.06)'
                44.07='(000044) GAMMA-AMINOBUTYRIC ACID ANALOGS:(44.07)'
                44.08='(000044) GAMMA-AMINOBUTYRIC ACID REUPTAKE INHIBITORS:(44.08)'
                44.09='(000044) HYDANTOIN ANTICONVULSANTS:(44.09)'
                44.11='(000044) OXAZOLIDINEDIONE ANTICONVULSANTS:(44.11)'
                44.12='(000044) PYRROLIDINE ANTICONVULSANTS:(44.12)'
                44.13='(000044) SUCCINIMIDE ANTICONVULSANTS:(44.13)'
                44.14='(000044) TRIAZINE ANTICONVULSANTS:(44.14)'
                44.99='(000044) MISCELLANEOUS ANTICONVULSANTS:(44.99)'
                45.01='(000045) 5HT3 RECEPTOR ANTAGONISTS:(45.01)'
                45.02='(000045) ANTICHOLINERGIC ANTIEMETICS:(45.02)'
                45.03='(000045) PHENOTHIAZINE ANTIEMETICS:(45.03)'
                45.04='(000045) MISCELLANEOUS ANTIEMETICS:(45.04)'
                46.01='(000046) ANTICHOLINERGIC ANTIPARKINSON AGENTS:(46.01)'
                46.02='(000046) DOPAMINERGIC ANTIPARKINSONISM AGENTS:(46.02)'
                46.03='(000046) MISCELLANEOUS ANTIPARKINSON AGENTS:(46.03)'
                46.31='(000046) BARBITURATES:(46.31)' 46.32='(000046) BENZODIAZEPINES:(46.32)'
                46.33='(000046) MISC. ANXIOLYTICS, SEDATIVES, AND HYPNOTICS:(46.33)'
                46.501='(000046) AMPHETAMINE-DEXTROAMPHETAMINE:(46.501)'
                46.502='(000046) BENZPHETAMINE:(46.502)' 46.503='(000046) CAFFEINE:(46.503)'
                46.504='(000046) DEXTROAMPHETAMINE:(46.504)' 46.505='(000046) METHYLPHENIDATE:(46.505)'
                46.509='(000046) CNS STIMULANTS NTA:(46.509)'
                48.01='(000048) NEUROMUSCULAR BLOCKING AGENTS:(48.01)'
                48.02='(000048) SKELETAL MUSCLE RELAXANT COMBINATIONS:(48.02)'
                48.03='(000048) SKELETAL MUSCLE RELAXANTS:(48.03)'
                48.04='(000048) MISCELLANEOUS MUSCLE RELAXANTS:(48.04)'
                49.01='(000049) CHOLINERGIC AGONISTS:(49.01)'
                49.02='(000049) CHOLINESTERASE INHIBITORS:(49.02)'
                49.03='(000049) MISCELLANEOUS CENTRAL NERVOUS SYSTEM AGENTS:(49.03)'
                52.01='(000052) ADRENERGIC BRONCHODILATORS:(52.01)'
                52.02='(000052) ANTICHOLINERGIC BRONCHODILATORS:(52.02)'
                52.03='(000052) BRONCHODILATOR COMBINATIONS:(52.03)'
                52.04='(000052) METHYLXANTHINES:(52.04)'
                52.05='(000052) MISCELLANEOUS BRONCHODILATORS:(52.05)'
                56.01='(000056) ANTIASTHMATIC COMBINATIONS:(56.01)' 56.02='(000056) ANTITUSSIVES:(56.02)'
                56.03='(000056) LEUKOTRIENE MODIFIERS:(56.03)'
                56.05='(000056) RESPIRATORY INHALANT PRODUCTS:(56.05)'
                56.06='(000056) MISCELLANEOUS RESPIRATORY AGENTS:(56.06)'
                58.01='(000058) CLONIDINE:(58.01)'
                58.09='(000058) ANTIADRENERGIC AGENTS, CENTRALLY ACTING NTA:(58.09)'
                59.01='(000059) CARDIOSELECTIVE BETA BLOCKERS:(59.01)'
                59.02='(000059) NON-CARDIOSELECTIVE BETA BLOCKERS:(59.02)'
                59.03='(000059) MISCELLANEOUS BETA-ADRENERGIC BLOCKING AGENTS:(59.03)'
                61.01='(000061) CARBONIC ANHYDRASE INHIBITORS:(61.01)'
                61.02='(000061) LOOP DIURETICS:(61.02)'
                61.03='(000061) POTASSIUM-SPARING DIURETICS:(61.03)'
                61.04='(000061) THIAZIDE AND THIAZIDE-LIKE DIURETICS:(61.04)'
                61.05='(000061) MISCELLANEOUS DIURETICS:(61.05)'
                62.01='(000062) AGENTS FOR HYPERTENSIVE EMERGENCIES:(62.01)'
                62.02='(000062) AGENTS FOR PULMONARY HYPERTENSION:(62.02)'
                62.03='(000062) ALDOSTERONE RECEPTOR ANTAGONISTS:(62.03)'
                62.04='(000062) ANGIOTENSIN CONVERTING ENZYME INHIBITORS:(62.04)'
                62.05='(000062) ANGIOTENSIN II INHIBITORS:(62.05)'
                62.06='(000062) ANTIADRENERGIC AGENTS, PERIPHERALLY ACTING:(62.06)'
                62.07='(000062) ANTIANGINAL AGENTS:(62.07)'
                62.08='(000062) ANTIARRHYTHMIC AGENTS:(62.08)'
                62.09='(000062) ANTIHYPERTENSIVE COMBINATIONS:(62.09)'
                62.1='(000062) CATECHOLAMINES:(62.1)' 62.11='(000062) INOTROPIC AGENTS:(62.11)'
                62.12='(000062) PERIPHERAL VASODILATORS:(62.12)'
                62.13='(000062) SCLEROSING AGENTS:(62.13)' 62.14='(000062) VASODILATORS:(62.14)'
                62.15='(000062) VASOPRESSORS:(62.15)'
                62.99='(000062) MISCELLANEOUS CARDIOVASCULAR AGENTS:(62.99)'
                64.041='(000064) AZOLE ANTIFUNGALS:(64.041)' 64.042='(000064) ECHINOCANDINS:(64.042)'
                64.043='(000064) POLYENES:(64.043)' 64.044='(000064) MISCELLANEOUS ANTIFUNGALS:(64.044)'
                64.051='(000064) ANTIMALARIAL COMBINATIONS:(64.051)'
                64.052='(000064) ANTIMALARIAL QUINOLINES:(64.052)'
                64.053='(000064) MISCELLANEOUS ANTIMALARIALS:(64.053)'
                64.061='(000064) AMINOSALICYLATES:(64.061)'
                64.062='(000064) ANTITUBERCULOSIS COMBINATIONS:(64.062)'
                64.063='(000064) NICOTINIC ACID DERIVATIVES:(64.063)'
                64.064='(000064) RIFAMYCIN DERIVATIVES:(64.064)'
                64.065='(000064) STREPTOMYCES DERIVATIVES:(64.065)'
                64.066='(000064) MISCELLANEOUS ANTITUBERCULOSIS AGENTS:(64.066)'
                64.0701='(000064) ADAMANTANE ANTIVIRALS:(64.0701)'
                64.0702='(000064) ANTIVIRAL CHEMOKINE RECEPTOR ANTAGONIST:(64.0702)'
                64.0703='(000064) ANTIVIRAL COMBINATIONS:(64.0703)'
                64.0704='(000064) ANTIVIRAL INTERFERONS:(64.0704)'
                64.0705='(000064) INTEGRASE STRAND TRANSFER INHIBITOR:(64.0705)'
                64.0706='(000064) NEURAMINIDASE INHIBITORS:(64.0706)' 64.0707='(000064) NNRTIS:(64.0707)'
                64.0708='(000064) NRTIS:(64.0708)' 64.0709='(000064) PROTEASE INHIBITORS:(64.0709)'
                64.071='(000064) PURINE NUCLEOSIDES:(64.071)'
                64.0711='(000064) MISCELLANEOUS ANTIVIRALS:(64.0711)'
                64.091='(000064) FIRST GENERATION CEPHALOSPORINS:(64.091)'
                64.092='(000064) SECOND GENERATION CEPHALOSPORINS:(64.092)'
                64.093='(000064) THIRD GENERATION CEPHALOSPORINS:(64.093)'
                64.094='(000064) FOURTH GENERATION CEPHALOSPORINS:(64.094)'
                64.095='(000064) FIFTH GENERATION CEPHALOSPORINS:(64.095)'
                64.096='(000064) MISCELLANEOUS CEPHALOSPORINS:(64.096)'
                64.141='(000064) KETOLIDES:(64.141)' 64.142='(000064) MACROLIDES:(64.142)'
                64.143='(000064) MISCELLANEOUS MACROLIDES:(64.143)'
                64.151='(000064) AMINOPENICILLINS:(64.151)'
                64.152='(000064) ANTIPSEUDOMONAL PENICILLINS:(64.152)'
                64.153='(000064) BETA-LACTAMASE INHIBITORS:(64.153)'
                64.154='(000064) NATURAL PENICILLINS:(64.154)'
                64.155='(000064) PENICILLINASE RESISTANT PENICILLINS:(64.155)'
                67.011='(000067) COUMARINS AND INDANEDIONES:(67.011)'
                67.012='(000067) FACTOR XA INHIBITORS:(67.012)' 67.013='(000067) HEPARINS:(67.013)'
                67.014='(000067) THROMBIN INHIBITORS:(67.014)'
                67.021='(000067) GLYCOPROTEIN PLATELET INHIBITORS:(67.021)'
                67.022='(000067) PLATELET AGGREGATION INHIBITORS:(67.022)'
                68.061='(000068) ANTICHOLINERGICS/ANTISPASMODICS:(68.061)'
                68.062='(000068) CHLORIDE CHANNEL ACTIVATORS:(68.062)'
                68.063='(000068) PERIPHERAL OPIOID RECEPTOR ANTAGONISTS:(68.063)'
                68.064='(000068) SEROTONINERGIC NEUROENTERIC MODULATORS:(68.064)'
                70.021='(000070) CORTICOTROPIN:(70.021)' 70.022='(000070) GLUCOCORTICOIDS:(70.022)'
                70.023='(000070) MINERALOCORTICOIDS:(70.023)'
                70.029='(000070) MISCELLANEOUS ADRENAL CORTICAL STEROIDS:(70.029)'
                70.202='(000070) ANDROGENS AND ANABOLIC STEROIDS:(70.202)'
                70.203='(000070) CONTRACEPTIVES:(70.203)' 70.204='(000070) ESTROGENS:(70.204)'
                70.205='(000070) GONADOTROPIN-RELEASING HORMONE AND ANALOGS:(70.205)'
                70.206='(000070) GONADOTROPINS:(70.206)' 70.207='(000070) PROGESTINS:(70.207)'
                70.208='(000070) SEX HORMONE COMBINATIONS:(70.208)'
                70.209='(000070) MISCELLANEOUS SEX HORMONES:(70.209)'
                71.021='(000071) BACTERIAL VACCINES:(71.021)'
                71.022='(000071) COLONY STIMULATING FACTORS:(71.022)'
                71.023='(000071) INTERFERONS:(71.023)' 71.025='(000071) THERAPEUTIC VACCINES:(71.025)'
                71.026='(000071) VACCINE COMBINATIONS:(71.026)' 71.027='(000071) VIRAL VACCINES:(71.027)'
                71.029='(000071) OTHER IMMUNOSTIMULANTS:(71.029)'
                71.031='(000071) CALCINEURIN INHIBITORS:(71.031)'
                71.032='(000071) INTERLEUKIN INHIBITORS:(71.032)'
                71.033='(000071) SELECTIVE IMMUNOSUPPRESSANTS:(71.033)'
                71.034='(000071) TNF ALFA INHIBITORS:(71.034)'
                71.039='(000071) OTHER IMMUNOSUPPRESSANTS:(71.039)'
                73.0101='(000073) ALPHA-GLUCOSIDASE INHIBITORS:(73.0101)'
                73.0102='(000073) AMYLIN ANALOGS:(73.0102)'
                73.0103='(000073) ANTIDIABETIC COMBINATIONS:(73.0103)'
                73.0104='(000073) DIPEPTIDYL PEPTIDASE 4 INHIBITORS:(73.0104)'
                73.0105='(000073) INCRETIN MIMETICS:(73.0105)' 73.0106='(000073) INSULIN:(73.0106)'
                73.0107='(000073) MEGLITINIDES:(73.0107)' 73.0108='(000073) BIGUANIDES:(73.0108)'
                73.0109='(000073) SULFONYLUREAS:(73.0109)' 73.011='(000073) THIAZOLIDINEDIONES:(73.011)'
                73.019='(000073) MISCELLANEOUS ANTIDIABETIC AGENTS:(73.019)'
                73.031='(000073) ANTIHYPERLIPIDEMIC COMBINATIONS:(73.031)'
                73.032='(000073) BILE ACID SEQUESTRANTS:(73.032)'
                73.033='(000073) CHOLESTEROL ABSORPTION INHIBITORS:(73.033)'
                73.034='(000073) FIBRIC ACID DERIVATIVES:(73.034)'
                73.035='(000073) HMG-COA REDUCTASE INHIBITORS:(73.035)'
                73.036='(000073) MISCELLANEOUS ANTIHYPERLIPIDEMIC AGENTS:(73.036)'
                73.051='(000073) BISPHOSPHONATES:(73.051)'
                73.059='(000073) MISCELLANEOUS BONE RESORPTION INHIBITORS:(73.059)'
                77.011='(000077) IONIC IODINATED CONTRAST MEDIA:(77.011)'
                77.012='(000077) LYMPHATIC STAINING AGENTS:(77.012)'
                77.013='(000077) MAGNETIC RESONANCE IMAGING CONTRAST MEDIA:(77.013)'
                77.014='(000077) NON-IODINATED CONTRAST MEDIA:(77.014)'
                77.015='(000077) NON-IONIC IODINATED CONTRAST MEDIA:(77.015)'
                77.016='(000077) ULTRASOUND CONTRAST MEDIA:(77.016)'
                77.017='(000077) MISCELLANEOUS IODINATED CONTRAST MEDIA:(77.017)'
                77.019='(000077) MISCELLANEOUS RADIOCONTRAST AGENTS:(77.019)'
                77.021='(000077) CARDIAC STRESSING AGENTS:(77.021)'
                77.031='(000077) DIAGNOSTIC RADIOPHARMACEUTICALS:(77.031)'
                77.032='(000077) THERAPEUTIC RADIOPHARMACEUTICALS:(77.032)'
                77.033='(000077) MISCELLANEOUS RADIOPHARMACEUTICALS:(77.033)'
                78.0301='(000078) TOPICAL ACNE AGENTS:(78.0301)'
                78.0302='(000078) TOPICAL ANESTHETICS:(78.0302)'
                78.0303='(000078) TOPICAL ANTIBIOTICS:(78.0303)'
                78.0304='(000078) TOPICAL ANTIFUNGALS:(78.0304)'
                78.0305='(000078) TOPICAL ANTIHISTAMINES:(78.0305)'
                78.0306='(000078) TOPICAL ANTI-INFECTIVES:(78.0306)'
                78.0307='(000078) TOPICAL ANTIPSORIATICS:(78.0307)'
                78.0308='(000078) TOPICAL ANTIVIRALS:(78.0308)'
                78.0309='(000078) TOPICAL ASTRINGENTS:(78.0309)'
                78.031='(000078) TOPICAL DEBRIDING AGENTS:(78.031)'
                78.0311='(000078) TOPICAL DEPIGMENTING AGENTS:(78.0311)'
                78.0312='(000078) TOPICAL EMOLLIENTS:(78.0312)'
                78.0313='(000078) TOPICAL KERATOLYTICS:(78.0313)'
                78.0314='(000078) TOPICAL NON-STEROIDAL ANTI-INFLAMMATORIES:(78.0314)'
                78.0315='(000078) TOPICAL STEROIDS:(78.0315)'
                78.0316='(000078) TOPICAL STEROIDS WITH ANTI-INFECTIVES:(78.0316)'
                78.0399='(000078) MISCELLANEOUS TOPICAL AGENTS:(78.0399)'
                78.051='(000078) NASAL ANTIHISTAMINES AND DECONGESTANTS:(78.051)'
                78.053='(000078) NASAL LUBRICANTS AND IRRIGATIONS:(78.053)'
                78.054='(000078) NASAL STEROIDS:(78.054)'
                78.055='(000078) MISCELLANEOUS NASAL PREPARATIONS:(78.055)'
                78.0602='(000078) ANTI-ANGIOGENIC OPHTHALMIC AGENTS:(78.0602)'
                78.061='(000078) MYDRIATICS:(78.061)' 78.062='(000078) OPHTHALMIC ANESTHETICS:(78.062)'
                78.063='(000078) OPHTHALMIC ANTIHISTAMINES AND DECONGESTANTS:(78.063)'
                78.064='(000078) OPHTHALMIC ANTI-INFECTIVES:(78.064)'
                78.065='(000078) OPHTHALMIC ANTI-INFLAMMATORY AGENTS:(78.065)'
                78.066='(000078) OPHTHALMIC DIAGNOSTIC AGENTS:(78.066)'
                78.067='(000078) OPHTHALMIC GLAUCOMA AGENTS:(78.067)'
                78.068='(000078) OPHTHALMIC LUBRICANTS AND IRRIGATIONS:(78.068)'
                78.069='(000078) OPHTHALMIC STEROIDS:(78.069)'
                78.0691='(000078) OPHTHALMIC STEROIDS WITH ANTI-INFECTIVES:(78.0691)'
                78.0692='(000078) OPHTHALMIC SURGICAL AGENTS:(78.0692)'
                78.0693='(000078) MISCELLANEOUS OPHTHALMIC AGENTS:(78.0693)'
                78.071='(000078) CERUMENOLYTICS:(78.071)' 78.072='(000078) OTIC ANESTHETICS:(78.072)'
                78.073='(000078) OTIC ANTI-INFECTIVES:(78.073)' 78.074='(000078) OTIC STEROIDS:(78.074)'
                78.075='(000078) OTIC STEROIDS WITH ANTI-INFECTIVES:(78.075)'
                78.076='(000078) MISCELLANEOUS OTIC AGENTS:(78.076)'
                78.091='(000078) SPERMICIDES:(78.091)' 78.092='(000078) VAGINAL ANTI-INFECTIVES:(78.092)'
                78.093='(000078) MISCELLANEOUS VAGINAL AGENTS:(78.093)';
VALUE drugid_f  -7='(-007) NOT APPLICABLE' 1='(0001) D00001 ACYCLOVIR'
                2='(0002) D00002 AMIODARONE' 3='(0003) D00003 AMPICILLIN' 4='(0004) D00004 ATENOLOL'
                5='(0005) D00006 CAPTOPRIL' 6='(0006) D00007 CEFAZOLIN' 7='(0007) D00008 CEFOTAXIME'
                8='(0008) D00009 CEFTAZIDIME' 9='(0009) D00010 CEFTIZOXIME'
                10='(0010) D00011 CIPROFLOXACIN' 11='(0011) D00012 CODEINE' 12='(0012) D00013 ENALAPRIL'
                13='(0013) D00014 GENTAMICIN' 14='(0014) D00015 IBUPROFEN' 15='(0015) D00016 LABETALOL'
                16='(0016) D00017 MEPERIDINE' 17='(0017) D00018 NADOLOL' 18='(0018) D00019 NAPROXEN'
                19='(0019) D00020 QUINIDINE' 20='(0020) D00021 RANITIDINE' 21='(0021) D00022 WARFARIN'
                22='(0022) D00023 ALLOPURINOL' 23='(0023) D00024 AZATHIOPRINE'
                24='(0024) D00025 CHLORAMPHENICOL' 25='(0025) D00026 FENOPROFEN'
                26='(0026) D00027 HALOPERIDOL' 27='(0027) D00028 KETOPROFEN' 28='(0028) D00029 NAFCILLIN'
                29='(0029) D00030 PENTAMIDINE' 30='(0030) D00031 PROBENECID'
                31='(0031) D00032 PROPRANOLOL' 32='(0032) D00033 SULINDAC' 33='(0033) D00034 ZIDOVUDINE'
                34='(0034) D00035 CHLOROQUINE' 35='(0035) D00036 CYCLOPHOSPHAMIDE'
                36='(0036) D00037 DOXYCYCLINE' 37='(0037) D00038 FLUCYTOSINE'
                38='(0038) D00039 INDOMETHACIN' 39='(0039) D00040 OXAZEPAM'
                40='(0040) D00041 TETRACYCLINE' 41='(0041) D00042 CHLORPROPAMIDE'
                42='(0042) D00043 CLINDAMYCIN' 43='(0043) D00044 CLONIDINE' 44='(0044) D00045 DILTIAZEM'
                45='(0045) D00046 ERYTHROMYCIN' 46='(0046) D00047 RIFAMPIN' 47='(0047) D00048 VERAPAMIL'
                48='(0048) D00049 ACETAMINOPHEN' 49='(0049) D00050 METHADONE'
                50='(0050) D00051 NIFEDIPINE' 51='(0051) D00052 CEFTRIAXONE'
                52='(0052) D00053 CEPHRADINE' 53='(0053) D00054 TOLMETIN' 54='(0054) D00055 CEFOTETAN'
                55='(0055) D00056 CEFUROXIME' 56='(0056) D00057 PIPERACILLIN'
                57='(0057) D00058 CARBAMAZEPINE' 58='(0058) D00059 LIDOCAINE'
                59='(0059) D00060 METHOTREXATE' 60='(0060) D00061 LITHIUM' 61='(0061) D00062 CEFAMANDOLE'
                62='(0062) D00064 CHLORPROMAZINE' 63='(0063) D00065 FOSCARNET'
                64='(0064) D00066 GANCICLOVIR' 65='(0065) D00067 AZTREONAM' 66='(0066) D00068 ETHAMBUTOL'
                67='(0067) D00069 TOBRAMYCIN' 68='(0068) D00070 FUROSEMIDE'
                69='(0069) D00071 FLUCONAZOLE' 70='(0070) D00072 CEFIXIME' 71='(0071) D00073 CEFPROZIL'
                72='(0072) D00074 CEFOPERAZONE' 73='(0073) D00075 PROCAINAMIDE'
                74='(0074) D00077 AMPHOTERICIN B' 75='(0075) D00078 DIDANOSINE'
                76='(0076) D00079 CYCLOSPORINE' 77='(0077) D00080 CEFADROXIL' 78='(0078) D00081 CEFACLOR'
                79='(0079) D00082 IMIPENEM-CILASTATIN' 80='(0080) D00083 VALPROIC ACID'
                81='(0081) D00084 PREDNISOLONE' 82='(0082) D00085 RIBAVIRIN'
                83='(0083) D00086 AMANTADINE' 84='(0084) D00087 AMIKACIN' 85='(0085) D00088 AMOXICILLIN'
                86='(0086) D00089 AMOXICILLIN-CLAVULANATE' 87='(0087) D00090 AMPICILLIN-SULBACTAM'
                88='(0088) D00091 AZITHROMYCIN' 89='(0089) D00092 CARBENICILLIN'
                90='(0090) D00093 CEFMETAZOLE' 91='(0091) D00094 CEFOXITIN'
                92='(0092) D00095 CEFPODOXIME' 93='(0093) D00096 CEPHALEXIN'
                94='(0094) D00097 CLARITHROMYCIN' 95='(0095) D00098 DAPSONE' 96='(0096) D00099 ENOXACIN'
                97='(0097) D00100 GRISEOFULVIN' 98='(0098) D00101 ISONIAZID'
                99='(0099) D00102 ITRACONAZOLE' 100='(0100) D00103 KETOCONAZOLE'
                101='(0101) D00104 LOMEFLOXACIN' 102='(0102) D00105 LORACARBEF'
                103='(0103) D00106 METHENAMINE' 104='(0104) D00107 METHICILLIN'
                105='(0105) D00108 METRONIDAZOLE' 106='(0106) D00109 MEZLOCILLIN'
                107='(0107) D00110 MINOCYCLINE' 108='(0108) D00112 NITROFURANTOIN'
                109='(0109) D00113 NORFLOXACIN' 110='(0110) D00114 OFLOXACIN'
                111='(0111) D00115 OXACILLIN' 112='(0112) D00116 PENICILLIN'
                113='(0113) D00117 PYRAZINAMIDE' 114='(0114) D00118 SULFADIAZINE'
                115='(0115) D00119 SULFAMETHOXAZOLE' 116='(0116) D00120 SULFISOXAZOLE'
                117='(0117) D00121 TICARCILLIN' 118='(0118) D00122 TICARCILLIN-CLAVULANATE'
                119='(0119) D00123 TRIMETHOPRIM' 120='(0120) D00124 SULFAMETHOXAZOLE-TRIMETHOPRIM'
                121='(0121) D00125 VANCOMYCIN' 122='(0122) D00128 ACEBUTOLOL'
                123='(0123) D00129 DIAZOXIDE' 124='(0124) D00132 HYDRALAZINE'
                125='(0125) D00133 METHYLDOPA' 126='(0126) D00134 METOPROLOL'
                127='(0127) D00135 MINOXIDIL' 128='(0128) D00137 PINDOLOL' 129='(0129) D00138 PRAZOSIN'
                130='(0130) D00139 TIMOLOL' 131='(0131) D00140 CIMETIDINE' 132='(0132) D00141 FAMOTIDINE'
                133='(0133) D00142 THEOPHYLLINE' 134='(0134) D00143 PHENYTOIN'
                135='(0135) D00144 NORTRIPTYLINE' 136='(0136) D00145 DESIPRAMINE'
                137='(0137) D00146 AMITRIPTYLINE' 138='(0138) D00147 CHLORAL HYDRATE'
                139='(0139) D00148 DIAZEPAM' 140='(0140) D00149 LORAZEPAM' 141='(0141) D00150 COLCHICINE'
                142='(0142) D00152 CLOXACILLIN' 143='(0143) D00153 DICLOXACILLIN'
                144='(0144) D00154 MEBENDAZOLE' 145='(0145) D00155 MICONAZOLE'
                146='(0146) D00157 NALIDIXIC ACID' 147='(0147) D00158 QUINACRINE'
                148='(0148) D00159 STREPTOMYCIN' 149='(0149) D00161 ACETAZOLAMIDE'
                150='(0150) D00164 ADENOSINE' 151='(0151) D00167 ALFENTANIL'
                152='(0152) D00168 ALPRAZOLAM' 153='(0153) D00169 AMILORIDE' 154='(0154) D00170 ASPIRIN'
                155='(0155) D00171 AMOBARBITAL' 156='(0156) D00172 INAMRINONE'
                157='(0157) D00173 ATRACURIUM' 158='(0158) D00174 ATROPINE'
                159='(0159) D00175 BENZTROPINE' 160='(0160) D00176 BETAXOLOL'
                161='(0161) D00177 BLEOMYCIN' 162='(0162) D00178 BROMOCRIPTINE'
                163='(0163) D00179 BUMETANIDE' 164='(0164) D00180 BUPIVACAINE'
                165='(0165) D00181 BUPROPION' 166='(0166) D00182 BUSPIRONE' 167='(0167) D00183 BUSULFAN'
                168='(0168) D00184 CARBIDOPA' 169='(0169) D00185 CARBOPLATIN'
                170='(0170) D00186 CEPHALOTHIN' 171='(0171) D00187 CEPHAPIRIN'
                172='(0172) D00188 CHLORAMBUCIL' 173='(0173) D00189 CHLORDIAZEPOXIDE'
                174='(0174) D00190 CHLOROTHIAZIDE' 175='(0175) D00191 CHLORPHENIRAMINE'
                176='(0176) D00192 CHLORTHALIDONE' 177='(0177) D00193 CHOLESTYRAMINE'
                178='(0178) D00195 CISPLATIN' 179='(0179) D00197 CLONAZEPAM'
                180='(0180) D00198 CLORAZEPATE' 181='(0181) D00199 CLOZAPINE'
                182='(0182) D00200 CROMOLYN' 183='(0183) D00201 CYTARABINE'
                184='(0184) D00202 DACARBAZINE' 185='(0185) D00203 DACTINOMYCIN'
                186='(0186) D00204 DANAZOL' 187='(0187) D00205 DAUNORUBICIN'
                188='(0188) D00206 DEXAMETHASONE' 189='(0189) D00207 DEXTROMETHORPHAN'
                190='(0190) D00208 DIFLUNISAL' 191='(0191) D00209 DIGITOXIN' 192='(0192) D00210 DIGOXIN'
                193='(0193) D00211 DIHYDROERGOTAMINE' 194='(0194) D00212 DIPHENHYDRAMINE'
                195='(0195) D00213 DIPYRIDAMOLE' 196='(0196) D00214 DISOPYRAMIDE'
                197='(0197) D00215 DOBUTAMINE' 198='(0198) D00216 DOPAMINE' 199='(0199) D00217 DOXEPIN'
                200='(0200) D00218 DOXORUBICIN' 201='(0201) D00219 DROPERIDOL'
                202='(0202) D00220 EDROPHONIUM' 203='(0203) D00222 ERGOTAMINE'
                204='(0204) D00223 EPOETIN ALFA' 205='(0205) D00224 ESMOLOL'
                206='(0206) D00226 ETHCHLORVYNOL' 207='(0207) D00227 ETHOSUXIMIDE'
                208='(0208) D00229 ETHINYL ESTRADIOL' 209='(0209) D00230 ETOPOSIDE'
                210='(0210) D00231 FELODIPINE' 211='(0211) D00233 FENTANYL'
                212='(0212) D00234 FLECAINIDE' 213='(0213) D00235 FLUOROURACIL'
                214='(0214) D00236 FLUOXETINE' 215='(0215) D00237 FLUPHENAZINE'
                216='(0216) D00238 FLURAZEPAM' 217='(0217) D00239 FLURBIPROFEN'
                218='(0218) D00240 FLUTAMIDE' 219='(0219) D00241 FOLIC ACID'
                220='(0220) D00242 FOSINOPRIL' 221='(0221) D00243 FURAZOLIDONE'
                222='(0222) D00245 GEMFIBROZIL' 223='(0223) D00246 GLIPIZIDE'
                224='(0224) D00248 GLYBURIDE' 225='(0225) D00250 GOLD SODIUM THIOMALATE'
                226='(0226) D00252 HEPARIN' 227='(0227) D00253 HYDROCHLOROTHIAZIDE'
                228='(0228) D00254 HYDROCORTISONE' 229='(0229) D00255 HYDROMORPHONE'
                230='(0230) D00256 IDARUBICIN' 231='(0231) D00257 IFOSFAMIDE'
                232='(0232) D00259 IMIPRAMINE' 233='(0233) D00260 INDAPAMIDE' 234='(0234) D00262 INSULIN'
                235='(0235) D00265 IPRATROPIUM' 236='(0236) D00267 ISOFLURANE'
                237='(0237) D00268 ISOSORBIDE DINITRATE' 238='(0238) D00269 ISOSORBIDE MONONITRATE'
                239='(0239) D00270 ISRADIPINE' 240='(0240) D00271 KANAMYCIN' 241='(0241) D00272 KETAMINE'
                242='(0242) D00273 KETOROLAC' 243='(0243) D00275 LEUCOVORIN'
                244='(0244) D00276 LEVAMISOLE' 245='(0245) D00277 LEVODOPA'
                246='(0246) D00278 LEVOTHYROXINE' 247='(0247) D00279 LINCOMYCIN'
                248='(0248) D00280 LOVASTATIN' 249='(0249) D00282 MANNITOL'
                250='(0250) D00283 MECLOFENAMATE' 251='(0251) D00284 MEDROXYPROGESTERONE'
                252='(0252) D00285 MEFENAMIC ACID' 253='(0253) D00286 MEFLOQUINE'
                254='(0254) D00287 MELPHALAN' 255='(0255) D00288 MEPROBAMATE'
                256='(0256) D00289 MERCAPTOPURINE' 257='(0257) D00290 METHIMAZOLE'
                258='(0258) D00292 METHSUXIMIDE' 259='(0259) D00293 METHYLPREDNISOLONE'
                260='(0260) D00295 METHYLTESTOSTERONE' 261='(0261) D00297 METIPRANOLOL OPHTHALMIC'
                262='(0262) D00298 METOCLOPRAMIDE' 263='(0263) D00299 METOLAZONE'
                264='(0264) D00300 MEXILETINE' 265='(0265) D00301 MIDAZOLAM'
                266='(0266) D00302 MILRINONE' 267='(0267) D00303 MISOPROSTOL'
                268='(0268) D00305 MITOMYCIN' 269='(0269) D00306 MITOXANTRONE'
                270='(0270) D00307 MORICIZINE' 271='(0271) D00308 MORPHINE'
                272='(0272) D00310 NABUMETONE' 273='(0273) D00311 NALOXONE' 274='(0274) D00312 NEOMYCIN'
                275='(0275) D00313 NEOSTIGMINE' 276='(0276) D00314 NIACIN'
                277='(0277) D00315 NICARDIPINE' 278='(0278) D00316 NICOTINE'
                279='(0279) D00318 NIMODIPINE' 280='(0280) D00321 NITROGLYCERIN'
                281='(0281) D00322 NIZATIDINE' 282='(0282) D00323 NOREPINEPHRINE'
                283='(0283) D00325 OMEPRAZOLE' 284='(0284) D00328 OXYBUTYNIN'
                285='(0285) D00329 OXYCODONE' 286='(0286) D00330 PANCURONIUM'
                287='(0287) D00331 PARAAMINOBENZOIC ACID' 288='(0288) D00332 PENBUTOLOL'
                289='(0289) D00333 PENICILLAMINE' 290='(0290) D00334 PENTAZOCINE'
                291='(0291) D00335 PENTOBARBITAL' 292='(0292) D00336 PENTOXIFYLLINE'
                293='(0293) D00337 PHENAZOPYRIDINE' 294='(0294) D00340 PHENOBARBITAL'
                295='(0295) D00341 PHENYLBUTAZONE' 296='(0296) D00342 PHYSOSTIGMINE'
                297='(0297) D00343 PIROXICAM' 298='(0298) D00344 POLYMYXIN B SULFATE'
                299='(0299) D00345 POTASSIUM CHLORIDE' 300='(0300) D00346 POVIDONE IODINE TOPICAL'
                301='(0301) D00348 PRAVASTATIN' 302='(0302) D00349 PRAZIQUANTEL'
                303='(0303) D00350 PREDNISONE' 304='(0304) D00351 PRIMAQUINE'
                305='(0305) D00352 PRIMIDONE' 306='(0306) D00353 PROBUCOL'
                307='(0307) D00354 PROCARBAZINE' 308='(0308) D00355 PROCHLORPERAZINE'
                309='(0309) D00356 PROMAZINE' 310='(0310) D00358 PROPAFENONE'
                311='(0311) D00359 PROPANTHELINE' 312='(0312) D00360 PROPOXYPHENE'
                313='(0313) D00361 PROPYLTHIOURACIL' 314='(0314) D00362 PROTAMINE'
                315='(0315) D00363 PYRIDOSTIGMINE' 316='(0316) D00364 PYRIMETHAMINE'
                317='(0317) D00365 QUINAPRIL' 318='(0318) D00366 QUININE' 319='(0319) D00367 RESERPINE'
                320='(0320) D00368 SECOBARBITAL' 321='(0321) D00370 OCTREOTIDE'
                322='(0322) D00371 SOTALOL' 323='(0323) D00373 SPIRONOLACTONE'
                324='(0324) D00374 STREPTOKINASE' 325='(0325) D00375 STREPTOZOCIN'
                326='(0326) D00376 SUCCINYLCHOLINE' 327='(0327) D00377 SUCRALFATE'
                328='(0328) D00378 SUFENTANIL' 329='(0329) D00379 SULFASALAZINE'
                330='(0330) D00381 TAMOXIFEN' 331='(0331) D00384 TEMAZEPAM' 332='(0332) D00386 TERAZOSIN'
                333='(0333) D00387 TERFENADINE' 334='(0334) D00388 THIOPENTAL'
                335='(0335) D00389 THIORIDAZINE' 336='(0336) D00391 THIOTHIXENE'
                337='(0337) D00393 TOLAZAMIDE' 338='(0338) D00394 TOLBUTAMIDE'
                339='(0339) D00395 TRAZODONE' 340='(0340) D00396 TRIAMTERENE'
                341='(0341) D00397 TRIAZOLAM' 342='(0342) D00398 VASOPRESSIN'
                343='(0343) D00399 VECURONIUM' 344='(0344) D00400 VINBLASTINE'
                345='(0345) D00401 VINCRISTINE' 346='(0346) D00402 VITAMIN A'
                347='(0347) D00405 VITAMIN E' 348='(0348) D00409 RIBOFLAVIN'
                349='(0349) D00412 PYRIDOXINE' 350='(0350) D00413 CYANOCOBALAMIN'
                351='(0351) D00417 BIOFLAVONOIDS' 352='(0352) D00425 CALCIUM CARBONATE'
                353='(0353) D00426 ASCORBIC ACID'
                354='(0354) D00427 POTASSIUM PHOSPHATE-SODIUM PHOSPHATE' 355='(0355) D00428 FLUORIDE'
                356='(0356) D00438 SODIUM CHLORIDE' 357='(0357) D00439 CITRIC ACID-POTASSIUM CITRATE'
                358='(0358) D00440 SODIUM BICARBONATE' 359='(0359) D00468 MAGNESIUM SULFATE'
                360='(0360) D00471 SODIUM ACETATE' 361='(0361) D00472 TROMETHAMINE'
                362='(0362) D00475 SODIUM PHOSPHATE' 363='(0363) D00476 AMMONIUM CHLORIDE'
                364='(0364) D00481 AMMONIUM MOLYBDATE TETRAHYDRATE' 365='(0365) D00484 SELENIUM'
                366='(0366) D00485 IODINE TOPICAL' 367='(0367) D00487 GLUTAMIC ACID'
                368='(0368) D00488 LYSINE' 369='(0369) D00491 LEVOCARNITINE' 370='(0370) D00496 INOSITOL'
                371='(0371) D00497 OMEGA-3 POLYUNSATURATED FATTY ACIDS' 372='(0372) D00512 FILGRASTIM'
                373='(0373) D00513 SARGRAMOSTIM' 374='(0374) D00514 TICLOPIDINE'
                375='(0375) D00519 ANISINDIONE' 376='(0376) D00521 ALTEPLASE'
                377='(0377) D00523 UROKINASE' 378='(0378) D00524 ANTITHROMBIN III'
                379='(0379) D00525 ANTIHEMOPHILIC FACTOR (OBSOLETE)'
                380='(0380) D00526 ANTI-INHIBITOR COAGULANT COMPLEX'
                381='(0381) D00527 FACTOR IX COMPLEX (OBSOLETE)' 382='(0382) D00528 AMINOCAPROIC ACID'
                383='(0383) D00529 TRANEXAMIC ACID' 384='(0384) D00534 ESTRONE'
                385='(0385) D00537 ESTRADIOL' 386='(0386) D00541 CONJUGATED ESTROGENS'
                387='(0387) D00542 ESTERIFIED ESTROGENS' 388='(0388) D00543 ESTROPIPATE'
                389='(0389) D00546 DIETHYLSTILBESTROL' 390='(0390) D00550 PROGESTERONE'
                391='(0391) D00554 HYDROXYPROGESTERONE' 392='(0392) D00555 NORETHINDRONE'
                393='(0393) D00557 LEVONORGESTREL' 394='(0394) D00558 TESTOSTERONE'
                395='(0395) D00562 FLUOXYMESTERONE' 396='(0396) D00563 FINASTERIDE'
                397='(0397) D00565 STANOZOLOL' 398='(0398) D00566 OXANDROLONE'
                399='(0399) D00568 NANDROLONE' 400='(0400) D00569 CLOMIPHENE'
                401='(0401) D00570 UROFOLLITROPIN' 402='(0402) D00571 MENOTROPINS'
                403='(0403) D00572 CHORIONIC GONADOTROPIN (HCG)' 404='(0404) D00574 NAFARELIN'
                405='(0405) D00575 HISTRELIN' 406='(0406) D00576 SOMATREM' 407='(0407) D00577 SOMATROPIN'
                408='(0408) D00578 ARGININE' 409='(0409) D00583 DESMOPRESSIN'
                410='(0410) D00584 OXYTOCIN' 411='(0411) D00586 ERGONOVINE'
                412='(0412) D00587 METHYLERGONOVINE' 413='(0413) D00589 DINOPROSTONE TOPICAL'
                414='(0414) D00592 METYRAPONE' 415='(0415) D00593 GLUCAGON' 416='(0416) D00595 GLUCOSE'
                417='(0417) D00598 CALCITONIN' 418='(0418) D00599 ETIDRONATE'
                419='(0419) D00601 PAMIDRONATE' 420='(0420) D00602 GALLIUM NITRATE'
                421='(0421) D00603 RITODRINE' 422='(0422) D00604 CORTICOTROPIN'
                423='(0423) D00607 COSYNTROPIN' 424='(0424) D00608 FLUDROCORTISONE'
                425='(0425) D00609 CORTISONE' 426='(0426) D00620 TRIAMCINOLONE'
                427='(0427) D00626 DEXAMETHASONE TOPICAL' 428='(0428) D00628 BETAMETHASONE'
                429='(0429) D00640 METHAZOLAMIDE' 430='(0430) D00641 BENDROFLUMETHIAZIDE'
                431='(0431) D00643 METHYCLOTHIAZIDE' 432='(0432) D00644 BENZTHIAZIDE'
                433='(0433) D00645 HYDROFLUMETHIAZIDE' 434='(0434) D00646 TRICHLORMETHIAZIDE'
                435='(0435) D00647 POLYTHIAZIDE' 436='(0436) D00649 ETHACRYNIC ACID'
                437='(0437) D00651 UREA TOPICAL' 438='(0438) D00652 GLYCERIN'
                439='(0439) D00653 ISOSORBIDE' 440='(0440) D00655 THYROID DESICCATED'
                441='(0441) D00658 LIOTHYRONINE' 442='(0442) D00659 LIOTRIX'
                443='(0443) D00666 AMYL NITRITE' 444='(0444) D00683 LIDOCAINE TOPICAL'
                445='(0445) D00688 BEPRIDIL' 446='(0446) D00689 AMLODIPINE'
                447='(0447) D00693 ISOXSUPRINE' 448='(0448) D00695 PAPAVERINE'
                449='(0449) D00696 ETHAVERINE' 450='(0450) D00697 ISOPROTERENOL'
                451='(0451) D00699 EPINEPHRINE' 452='(0452) D00700 EPHEDRINE'
                453='(0453) D00703 METHOXAMINE' 454='(0454) D00704 PHENYLEPHRINE'
                455='(0455) D00708 CARTEOLOL' 456='(0456) D00709 BISOPROLOL'
                457='(0457) D00717 GUANFACINE' 458='(0458) D00726 DOXAZOSIN' 459='(0459) D00728 RAMIPRIL'
                460='(0460) D00730 BENAZEPRIL' 461='(0461) D00732 LISINOPRIL'
                462='(0462) D00733 PHENTOLAMINE' 463='(0463) D00734 PHENOXYBENZAMINE'
                464='(0464) D00735 METYROSINE' 465='(0465) D00739 MECAMYLAMINE'
                466='(0466) D00743 SODIUM POLYSTYRENE SULFONATE' 467='(0467) D00744 COLESTIPOL'
                468='(0468) D00746 SIMVASTATIN' 469='(0469) D00747 DEXTROTHYROXINE SODIUM'
                470='(0470) D00749 ALBUTEROL' 471='(0471) D00750 METAPROTERENOL'
                472='(0472) D00752 TERBUTALINE' 473='(0473) D00755 PIRBUTEROL'
                474='(0474) D00758 AMINOPHYLLINE' 475='(0475) D00759 DYPHYLLINE'
                476='(0476) D00760 BECLOMETHASONE' 477='(0477) D00761 FLUNISOLIDE'
                478='(0478) D00762 ACETYLCYSTEINE' 479='(0479) D00765 CROMOLYN OPHTHALMIC'
                480='(0480) D00767 PHENYLPROPANOLAMINE' 481='(0481) D00769 PSEUDOEPHEDRINE'
                482='(0482) D00771 NAPHAZOLINE OPHTHALMIC' 483='(0483) D00772 OXYMETAZOLINE NASAL'
                484='(0484) D00773 TETRAHYDROZOLINE OPHTHALMIC' 485='(0485) D00774 XYLOMETAZOLINE NASAL'
                486='(0486) D00775 ALPHA 1-PROTEINASE INHIBITOR' 487='(0487) D00780 CLEMASTINE'
                488='(0488) D00782 PYRILAMINE' 489='(0489) D00784 DEXCHLORPHENIRAMINE'
                490='(0490) D00785 BROMPHENIRAMINE' 491='(0491) D00786 TRIPROLIDINE'
                492='(0492) D00787 PROMETHAZINE' 493='(0493) D00788 TRIMEPRAZINE'
                494='(0494) D00789 METHDILAZINE' 495='(0495) D00790 CYPROHEPTADINE'
                496='(0496) D00791 AZATADINE' 497='(0497) D00793 PHENINDAMINE'
                498='(0498) D00796 BENZONATATE' 499='(0499) D00797 GUAIFENESIN'
                500='(0500) D00800 POTASSIUM IODIDE' 501='(0501) D00801 CAFFEINE'
                502='(0502) D00802 DOXAPRAM' 503='(0503) D00803 AMPHETAMINE'
                504='(0504) D00804 DEXTROAMPHETAMINE' 505='(0505) D00805 METHAMPHETAMINE'
                506='(0506) D00806 PHENTERMINE' 507='(0507) D00807 BENZPHETAMINE'
                508='(0508) D00809 PHENDIMETRAZINE' 509='(0509) D00810 DIETHYLPROPION'
                510='(0510) D00811 MAZINDOL' 511='(0511) D00812 FENFLURAMINE'
                512='(0512) D00813 BENZOCAINE TOPICAL' 513='(0513) D00814 METHOTRIMEPRAZINE'
                514='(0514) D00817 HYDROXYCHLOROQUINE' 515='(0515) D00824 OPIUM'
                516='(0516) D00825 LEVORPHANOL' 517='(0517) D00833 OXYMORPHONE'
                518='(0518) D00838 BUTORPHANOL' 519='(0519) D00839 NALBUPHINE'
                520='(0520) D00840 BUPRENORPHINE' 521='(0521) D00842 SALSALATE'
                522='(0522) D00846 MAGNESIUM SALICYLATE' 523='(0523) D00848 DICLOFENAC'
                524='(0524) D00851 ETODOLAC' 525='(0525) D00853 OXAPROZIN'
                526='(0526) D00855 PERPHENAZINE' 527='(0527) D00857 THIETHYLPERAZINE'
                528='(0528) D00858 CYCLIZINE' 529='(0529) D00859 MECLIZINE'
                530='(0530) D00861 DIMENHYDRINATE' 531='(0531) D00862 TRIMETHOBENZAMIDE'
                532='(0532) D00866 DRONABINOL' 533='(0533) D00867 ONDANSETRON'
                534='(0534) D00873 TRIMIPRAMINE' 535='(0535) D00874 AMOXAPINE'
                536='(0536) D00875 PROTRIPTYLINE' 537='(0537) D00876 CLOMIPRAMINE'
                538='(0538) D00877 MAPROTILINE' 539='(0539) D00880 SERTRALINE'
                540='(0540) D00882 ISOCARBOXAZID' 541='(0541) D00883 PHENELZINE'
                542='(0542) D00884 TRANYLCYPROMINE' 543='(0543) D00889 MESORIDAZINE'
                544='(0544) D00890 TRIFLUOPERAZINE' 545='(0545) D00896 MOLINDONE'
                546='(0546) D00897 LOXAPINE' 547='(0547) D00898 PIMOZIDE'
                548='(0548) D00900 METHYLPHENIDATE' 549='(0549) D00901 PEMOLINE'
                550='(0550) D00902 ERGOLOID MESYLATES' 551='(0551) D00907 HYDROXYZINE'
                552='(0552) D00909 CHLORMEZANONE' 553='(0553) D00910 ZOLPIDEM'
                554='(0554) D00911 PARALDEHYDE' 555='(0555) D00912 ACETYLCARBROMAL'
                556='(0556) D00915 ESTAZOLAM' 557='(0557) D00917 QUAZEPAM'
                558='(0558) D00919 MEPHOBARBITAL' 559='(0559) D00923 BUTABARBITAL'
                560='(0560) D00929 METHOHEXITAL' 561='(0561) D00931 ETOMIDATE'
                562='(0562) D00933 PROPOFOL' 563='(0563) D00934 NITROUS OXIDE'
                564='(0564) D00942 ETHOTOIN' 565='(0565) D00943 PHENSUXIMIDE'
                566='(0566) D00944 PARAMETHADIONE' 567='(0567) D00960 CARISOPRODOL'
                568='(0568) D00962 CHLORZOXAZONE' 569='(0569) D00963 CYCLOBENZAPRINE'
                570='(0570) D00964 METAXALONE' 571='(0571) D00965 METHOCARBAMOL'
                572='(0572) D00966 ORPHENADRINE' 573='(0573) D00967 BACLOFEN'
                574='(0574) D00968 DANTROLENE' 575='(0575) D00969 PROCYCLIDINE'
                576='(0576) D00970 TRIHEXYPHENIDYL' 577='(0577) D00972 BIPERIDEN'
                578='(0578) D00976 SELEGILINE' 579='(0579) D00977 PERGOLIDE'
                580='(0580) D00978 ALUMINUM HYDROXIDE'
                581='(0581) D00980 DIHYDROXYALUMINUM SODIUM CARBONATE'
                582='(0582) D00982 MAGNESIUM HYDROXIDE' 583='(0583) D00984 MAGALDRATE'
                584='(0584) D00985 HYOSCYAMINE' 585='(0585) D00986 SCOPOLAMINE'
                586='(0586) D00988 BELLADONNA' 587='(0587) D00989 METHSCOPOLAMINE'
                588='(0588) D00991 CLIDINIUM' 589='(0589) D00992 GLYCOPYRROLATE'
                590='(0590) D00999 DICYCLOMINE' 591='(0591) D01002 PANCRELIPASE'
                592='(0592) D01003 PANCREATIN' 593='(0593) D01005 URSODIOL'
                594='(0594) D01008 MAGNESIUM CITRATE' 595='(0595) D01009 SODIUM BIPHOSPHATE'
                596='(0596) D01010 CASCARA SAGRADA' 597='(0597) D01012 PHENOLPHTHALEIN'
                598='(0598) D01013 SENNA' 599='(0599) D01014 CASTOR OIL' 600='(0600) D01015 BISACODYL'
                601='(0601) D01017 POLYCARBOPHIL' 602='(0602) D01018 PSYLLIUM'
                603='(0603) D01019 MINERAL OIL' 604='(0604) D01021 DOCUSATE'
                605='(0605) D01023 POLYETHYLENE GLYCOL 3350 WITH ELECTROLYTES'
                606='(0606) D01024 LACTULOSE' 607='(0607) D01025 LOPERAMIDE'
                608='(0608) D01026 BISMUTH SUBSALICYLATE' 609='(0609) D01027 SIMETHICONE'
                610='(0610) D01028 CHARCOAL' 611='(0611) D01030 DEHYDROCHOLIC ACID'
                612='(0612) D01031 MESALAMINE' 613='(0613) D01032 OLSALAZINE'
                614='(0614) D01068 DEMECLOCYCLINE' 615='(0615) D01070 OXYTETRACYCLINE'
                616='(0616) D01090 SULFAMETHIZOLE' 617='(0617) D01097 RIFABUTIN'
                618='(0618) D01100 ETHIONAMIDE' 619='(0619) D01101 CYCLOSERINE'
                620='(0620) D01104 PAROMOMYCIN' 621='(0621) D01105 IODOQUINOL'
                622='(0622) D01112 COLISTIN SULFATE OTIC' 623='(0623) D01113 COLISTIMETHATE'
                624='(0624) D01115 BACITRACIN' 625='(0625) D01120 ATOVAQUONE'
                626='(0626) D01121 CLOFAZIMINE' 627='(0627) D01123 PYRANTEL'
                628='(0628) D01124 PIPERAZINE' 629='(0629) D01128 METHYLENE BLUE'
                630='(0630) D01129 CINOXACIN' 631='(0631) D01133 IMMUNE GLOBULIN INTRAVENOUS'
                632='(0632) D01135 IMMUNE GLOBULIN INTRAMUSCULAR'
                633='(0633) D01136 HEPATITIS B IMMUNE GLOBULIN'
                634='(0634) D01138 VARICELLA ZOSTER IMMUNE GLOBULIN'
                635='(0635) D01139 RHO (D) IMMUNE GLOBULIN'
                636='(0636) D01141 LYMPHOCYTE IMMUNE GLOBULIN, ANTI-THY (OBS)'
                637='(0637) D01142 DIPHTHERIA ANTITOXIN'
                638='(0638) D01144 ANTIVENIN (CROTALIDAE) POLYVALENT'
                639='(0639) D01146 ANTIVENIN (BLACK WIDOW SPIDER)'
                640='(0640) D01147 RABIES VACCINE (OBSOLETE)'
                641='(0641) D01148 RABIES IMMUNE GLOBULIN, HUMAN' 642='(0642) D01150 BCG'
                643='(0643) D01152 STAPHAGE LYSATE (SPL)'
                644='(0644) D01153 MENINGOCOCCAL POLYSACCHARIDE VACCINE'
                645='(0645) D01156 TYPHOID VACCINE, INACTIVATED'
                646='(0646) D01158 HAEMOPHILUS B CONJUGATE VACCINE (OBSOLETE)'
                647='(0647) D01159 MEASLES VIRUS VACCINE' 648='(0648) D01160 RUBELLA VIRUS VACCINE'
                649='(0649) D01161 MUMPS VIRUS VACCINE'
                650='(0650) D01162 POLIOVIRUS VACCINE, LIVE, TRIVALENT'
                651='(0651) D01163 POLIOVIRUS VACCINE, INACTIVATED'
                652='(0652) D01164 INFLUENZA VIRUS VACCINE, INACTIVATED'
                653='(0653) D01165 YELLOW FEVER VACCINE'
                654='(0654) D01166 HEPATITIS B VACCINE (OBSOLETE)' 655='(0655) D01168 TETANUS TOXOID'
                656='(0656) D01171 TUBERCULIN PURIFIED PROTEIN DERIVATIVE'
                657='(0657) D01184 DIPIVEFRIN OPHTHALMIC' 658='(0658) D01187 LEVOBUNOLOL OPHTHALMIC'
                659='(0659) D01188 ACETYLCHOLINE OPHTHALMIC' 660='(0660) D01191 PILOCARPINE OPHTHALMIC'
                661='(0661) D01195 ECHOTHIOPHATE IODIDE OPHTHALMIC'
                662='(0662) D01199 HOMATROPINE OPHTHALMIC' 663='(0663) D01200 TROPICAMIDE OPHTHALMIC'
                664='(0664) D01201 CYCLOPENTOLATE OPHTHALMIC' 665='(0665) D01204 SUPROFEN OPHTHALMIC'
                666='(0666) D01208 SULFACETAMIDE SODIUM OPHTHALMIC'
                667='(0667) D01210 YELLOW MERCURIC OXIDE OPHTHALMIC'
                668='(0668) D01215 TRIFLURIDINE OPHTHALMIC' 669='(0669) D01217 TETRACAINE'
                670='(0670) D01218 PROPARACAINE OPHTHALMIC' 671='(0671) D01219 FLUORESCEIN OPHTHALMIC'
                672='(0672) D01222 SODIUM HYALURONATE OPHTHALMIC' 673='(0673) D01225 BORIC ACID TOPICAL'
                674='(0674) D01226 HYDROXYPROPYL METHYLCELLULOSE OPHTHALMIC'
                675='(0675) D01227 BOTULINUM TOXIN TYPE A (OBSOLETE)'
                676='(0676) D01231 CHLORHEXIDINE TOPICAL' 677='(0677) D01232 CARBAMIDE PEROXIDE TOPICAL'
                678='(0678) D01233 NYSTATIN' 679='(0679) D01234 BUTOCONAZOLE TOPICAL'
                680='(0680) D01235 TIOCONAZOLE TOPICAL' 681='(0681) D01236 CLOTRIMAZOLE'
                682='(0682) D01238 TERCONAZOLE TOPICAL' 683='(0683) D01239 GENTIAN VIOLET TOPICAL'
                684='(0684) D01240 SULFANILAMIDE TOPICAL' 685='(0685) D01241 CLINDAMYCIN TOPICAL'
                686='(0686) D01242 NONOXYNOL 9 TOPICAL' 687='(0687) D01243 OCTOXYNOL TOPICAL'
                688='(0688) D01244 TRETINOIN TOPICAL' 689='(0689) D01245 ISOTRETINOIN'
                690='(0690) D01246 BENZOYL PEROXIDE TOPICAL' 691='(0691) D01254 ANTHRALIN TOPICAL'
                692='(0692) D01257 NITROFURAZONE TOPICAL' 693='(0693) D01258 MAFENIDE TOPICAL'
                694='(0694) D01259 SILVER SULFADIAZINE TOPICAL'
                695='(0695) D01263 PYRITHIONE ZINC TOPICAL'
                696='(0696) D01265 SULFACETAMIDE SODIUM TOPICAL' 697='(0697) D01266 CHLOROXINE TOPICAL'
                698='(0698) D01267 MUPIROCIN TOPICAL' 699='(0699) D01271 ECONAZOLE TOPICAL'
                700='(0700) D01272 CICLOPIROX TOPICAL' 701='(0701) D01273 TRIACETIN TOPICAL'
                702='(0702) D01274 TOLNAFTATE TOPICAL' 703='(0703) D01275 SULCONAZOLE TOPICAL'
                704='(0704) D01277 NAFTIFINE TOPICAL' 705='(0705) D01278 LINDANE TOPICAL'
                706='(0706) D01279 PERMETHRIN TOPICAL' 707='(0707) D01280 CROTAMITON TOPICAL'
                708='(0708) D01282 ALCLOMETASONE TOPICAL' 709='(0709) D01288 CLOBETASOL TOPICAL'
                710='(0710) D01289 CLOCORTOLONE TOPICAL' 711='(0711) D01290 DESONIDE TOPICAL'
                712='(0712) D01291 DESOXIMETASONE TOPICAL' 713='(0713) D01292 DIFLORASONE TOPICAL'
                714='(0714) D01293 FLUOCINOLONE TOPICAL' 715='(0715) D01294 FLUOCINONIDE TOPICAL'
                716='(0716) D01295 FLURANDRENOLIDE TOPICAL' 717='(0717) D01296 FLUTICASONE'
                718='(0718) D01298 HALOBETASOL TOPICAL' 719='(0719) D01300 MOMETASONE TOPICAL'
                720='(0720) D01301 DIBUCAINE TOPICAL' 721='(0721) D01302 BUTAMBEN TOPICAL'
                722='(0722) D01303 PRAMOXINE TOPICAL' 723='(0723) D01305 DYCLONINE TOPICAL'
                724='(0724) D01306 COCAINE TOPICAL' 725='(0725) D01307 SALICYLIC ACID TOPICAL'
                726='(0726) D01308 PODOPHYLLUM RESIN TOPICAL' 727='(0727) D01309 PODOFILOX TOPICAL'
                728='(0728) D01313 TRICHLOROACETIC ACID TOPICAL' 729='(0729) D01314 SUTILAINS TOPICAL'
                730='(0730) D01315 COLLAGENASE TOPICAL' 731='(0731) D01316 MASOPROCOL TOPICAL'
                732='(0732) D01319 HYDROQUINONE TOPICAL' 733='(0733) D01320 FORMALDEHYDE TOPICAL'
                734='(0734) D01321 CAPSAICIN TOPICAL'
                735='(0735) D01322 ALUMINUM CHLORIDE HEXAHYDRATE TOPICAL'
                736='(0736) D01323 MONOBENZONE TOPICAL' 737='(0737) D01325 ARNICA TOPICAL'
                738='(0738) D01332 HEXACHLOROPHENE TOPICAL'
                739='(0739) D01333 BENZALKONIUM CHLORIDE TOPICAL'
                740='(0740) D01335 SODIUM HYPOCHLORITE TOPICAL'
                741='(0741) D01338 PHYSIOLOGICAL IRRIGATING SOLUTION' 742='(0742) D01339 MECHLORETHAMINE'
                743='(0743) D01341 LOMUSTINE' 744='(0744) D01342 CARMUSTINE'
                745='(0745) D01344 FLOXURIDINE' 746='(0746) D01345 THIOGUANINE'
                747='(0747) D01346 FLUDARABINE' 748='(0748) D01348 MEGESTROL'
                749='(0749) D01351 ESTRAMUSTINE' 750='(0750) D01353 LEUPROLIDE'
                751='(0751) D01354 GOSERELIN' 752='(0752) D01356 PENTOSTATIN'
                753='(0753) D01361 PLICAMYCIN' 754='(0754) D01368 INTERFERON ALFA-2A'
                755='(0755) D01369 INTERFERON ALFA-2B' 756='(0756) D01372 ALTRETAMINE'
                757='(0757) D01373 HYDROXYUREA' 758='(0758) D01375 ALDESLEUKIN'
                759='(0759) D01376 PACLITAXEL' 760='(0760) D01378 MITOTANE'
                761='(0761) D01379 ASPARAGINASE ESCHERICHIA COLI' 762='(0762) D01382 ETHANOLAMINE OLEATE'
                763='(0763) D01383 SODIUM TETRADECYL SULFATE' 764='(0764) D01384 MORRHUATE SODIUM'
                765='(0765) D01385 BETA-CAROTENE' 766='(0766) D01386 YOHIMBINE'
                767='(0767) D01387 ALPROSTADIL' 768='(0768) D01389 DISULFIRAM'
                769='(0769) D01393 HYALURONIDASE' 770='(0770) D01394 PROCAINE'
                771='(0771) D01395 CHLOROPROCAINE' 772='(0772) D01396 PRILOCAINE'
                773='(0773) D01398 MEPIVACAINE' 774='(0774) D01402 DEFEROXAMINE'
                775='(0775) D01404 SODIUM THIOSULFATE' 776='(0776) D01406 NALTREXONE'
                777='(0777) D01407 FLUMAZENIL' 778='(0778) D01409 PRALIDOXIME'
                779='(0779) D01410 DIGOXIN IMMUNE FAB' 780='(0780) D01411 MESNA'
                781='(0781) D01413 IPECAC' 782='(0782) D01416 TRIENTINE' 783='(0783) D01417 SUCCIMER'
                784='(0784) D01420 AMBENONIUM' 785='(0785) D01422 GUANIDINE'
                786='(0786) D01423 POTASSIUM CITRATE' 787='(0787) D01424 POTASSIUM ACID PHOSPHATE'
                788='(0788) D01425 FLAVOXATE' 789='(0789) D01427 BETHANECHOL'
                790='(0790) D01431 DIMETHYL SULFOXIDE' 791='(0791) D01433 ACETOHYDROXAMIC ACID'
                792='(0792) D01434 METHOXSALEN' 793='(0793) D01438 IOPANOIC ACID'
                794='(0794) D01445 BARIUM SULFATE' 795='(0795) D01451 GADOPENTETATE DIMEGLUMINE'
                796='(0796) D01452 IODAMIDE' 797='(0797) D01456 IOHEXOL' 798='(0798) D01461 IOPAMIDOL'
                799='(0799) D01469 IOVERSOL' 800='(0800) D01472 METRIZAMIDE'
                801='(0801) D01473 DIATRIZOATE' 802='(0802) D01475 IOTHALAMATE'
                803='(0803) D01476 ETHIODIZED OIL' 804='(0804) D01482 ISOSULFAN BLUE'
                805='(0805) D02373 PHOSPHORATED CARBOHYDRATE SOLUTION' 806='(0806) D02374 DESFLURANE'
                807='(0807) D02375 PLASMA PROTEIN FRACTION' 808='(0808) D02376 ALBUMIN HUMAN'
                809='(0809) D02378 HETASTARCH' 810='(0810) D02381 POTASSIUM PERCHLORATE'
                811='(0811) D03001 CLADRIBINE' 812='(0812) D03003 DIPHTHERIA-TETANUS TOXOIDS (OBSOLETE)'
                813='(0813) D03004 DIPHTHERIA/PERTUSSIS, WHOLE CELL/TETANUS'
                814='(0814) D03006 MEASLES-RUBELLA VIRUS VACCINE'
                815='(0815) D03007 MEASLES/MUMPS/RUBELLA VIRUS VACCINE'
                816='(0816) D03008 INTERFERON GAMMA-1B' 817='(0817) D03034 NORGESTREL'
                818='(0818) D03041 ENOXAPARIN' 819='(0819) D03050 LORATADINE'
                820='(0820) D03051 INTERFERON BETA-1B'
                821='(0821) D03052 HYDROCHLOROTHIAZIDE-TRIAMTERENE' 822='(0822) D03054 AMYLASE'
                823='(0823) D03056 ATTAPULGITE' 824='(0824) D03058 BENZOIC ACID'
                825='(0825) D03061 BUTALBITAL' 826='(0826) D03062 CASANTHRANOL'
                827='(0827) D03066 CITRIC ACID' 828='(0828) D03068 DICHLORALPHENAZONE'
                829='(0829) D03075 HYDROCODONE' 830='(0830) D03077 ISOMETHEPTENE MUCATE'
                831='(0831) D03085 PEPSIN' 832='(0832) D03086 PHENIRAMINE'
                833='(0833) D03089 PHENYLTOLOXAMINE' 834='(0834) D03094 SALICYLAMIDE'
                835='(0835) D03096 SODIUM BENZOATE' 836='(0836) D03097 SODIUM BORATE TOPICAL'
                837='(0837) D03098 SODIUM CITRATE'
                838='(0838) D03109 JAPANESE ENCEPHALITIS VIRUS VACCINE NAKAYAMA'
                839='(0839) D03110 DIPHTH/PERTUSSIS, ACEL/TETANUS (OBSOLETE)'
                840='(0840) D03112 NEDOCROMIL' 841='(0841) D03113 DEXTRAN, LOW MOLECULAR WEIGHT'
                842='(0842) D03114 DEXTRAN, HIGH MOLECULAR WEIGHT' 843='(0843) D03116 BISMUTH SUBGALLATE'
                844='(0844) D03118 MUROMONAB-CD3' 845='(0845) D03125 DIHYDROTACHYSTEROL'
                846='(0846) D03126 CALCITRIOL' 847='(0847) D03128 ERGOCALCIFEROL'
                848='(0848) D03129 CHOLECALCIFEROL' 849='(0849) D03130 THIAMINE'
                850='(0850) D03133 HYDROXOCOBALAMIN' 851='(0851) D03135 PHYTONADIONE'
                852='(0852) D03136 VITAMIN A & D TOPICAL' 853='(0853) D03137 CALCIUM-VITAMIN D'
                854='(0854) D03140 MULTIVITAMIN' 855='(0855) D03141 MULTIVITAMIN WITH IRON'
                856='(0856) D03143 MULTIVITAMIN WITH FLUORIDE'
                857='(0857) D03145 MULTIVITAMIN WITH MINERALS' 858='(0858) D03148 MULTIVITAMIN, PRENATAL'
                859='(0859) D03152 TRIFLUPROMAZINE' 860='(0860) D03154 DOXYLAMINE'
                861='(0861) D03157 PAROXETINE' 862='(0862) D03158 RIMANTADINE'
                863='(0863) D03159 CHOLINE' 864='(0864) D03160 SUMATRIPTAN'
                865='(0865) D03162 ALCOHOL (ETHANOL)' 866='(0866) D03165 PIPERACILLIN-TAZOBACTAM'
                867='(0867) D03166 CISAPRIDE' 868='(0868) D03168 DIHYDROCODEINE'
                869='(0869) D03169 TRIMETREXATE' 870='(0870) D03170 FELBAMATE'
                871='(0871) D03171 GRANISETRON' 872='(0872) D03173 DORNASE ALFA'
                873='(0873) D03176 TACRINE' 874='(0874) D03180 RISPERIDONE'
                875='(0875) D03181 VENLAFAXINE' 876='(0876) D03182 GABAPENTIN'
                877='(0877) D03183 FLUVASTATIN' 878='(0878) D03187 LEVOMETHADYL ACETATE'
                879='(0879) D03189 TORSEMIDE' 880='(0880) D03190 OXICONAZOLE TOPICAL'
                881='(0881) D03191 TERBINAFINE TOPICAL' 882='(0882) D03192 ZINC OXIDE TOPICAL'
                883='(0883) D03193 AMILORIDE-HYDROCHLOROTHIAZIDE' 884='(0884) D03195 MICONAZOLE TOPICAL'
                885='(0885) D03196 GENTAMICIN TOPICAL' 886='(0886) D03197 BETAMETHASONE TOPICAL'
                887='(0887) D03200 ERYTHROMYCIN TOPICAL' 888='(0888) D03201 ACYCLOVIR TOPICAL'
                889='(0889) D03202 KETOCONAZOLE TOPICAL' 890='(0890) D03203 MINOXIDIL TOPICAL'
                891='(0891) D03204 FLUOROURACIL TOPICAL' 892='(0892) D03205 HYDROCORTISONE TOPICAL'
                893='(0893) D03206 TRIAMCINOLONE TOPICAL' 894='(0894) D03207 AMPHOTERICIN B TOPICAL'
                895='(0895) D03208 METRONIDAZOLE TOPICAL' 896='(0896) D03210 SELENIUM SULFIDE TOPICAL'
                897='(0897) D03211 CIPROFLOXACIN OPHTHALMIC' 898='(0898) D03212 ATROPINE OPHTHALMIC'
                899='(0899) D03213 DICLOFENAC OPHTHALMIC' 900='(0900) D03214 KETOROLAC OPHTHALMIC'
                901='(0901) D03221 PREDNISOLONE OPHTHALMIC' 902='(0902) D03222 TOBRAMYCIN OPHTHALMIC'
                903='(0903) D03224 NEOMYCIN TOPICAL' 904='(0904) D03226 SALIVA SUBSTITUTES'
                905='(0905) D03227 FLUOROMETHOLONE OPHTHALMIC' 906='(0906) D03228 LODOXAMIDE OPHTHALMIC'
                907='(0907) D03229 LEVOCABASTINE OPHTHALMIC' 908='(0908) D03231 TRIPLE SULFA TOPICAL'
                909='(0909) D03232 VITAMINS A, D, AND E TOPICAL' 910='(0910) D03233 VITAMIN E TOPICAL'
                911='(0911) D03238 ETHINYL ESTRADIOL-NORETHINDRONE'
                912='(0912) D03240 MESTRANOL-NORETHINDRONE'
                913='(0913) D03241 ETHINYL ESTRADIOL-NORGESTREL'
                914='(0914) D03242 ETHINYL ESTRADIOL-LEVONORGESTREL'
                915='(0915) D03245 ESTERIFIED ESTROGENS-METHYLTESTOSTERONE'
                916='(0916) D03247 HYDROCHLOROTHIAZIDE-SPIRONOLACTONE'
                917='(0917) D03251 HYDROCHLOROTHIAZIDE-RESERPINE'
                918='(0918) D03255 BENDROFLUMETHIAZIDE-RAUWOLFIA SERPENTINA'
                919='(0919) D03256 HYDRALAZINE/HYDROCHLOROTHIAZIDE/RESERPINE'
                920='(0920) D03257 HYDRALAZINE-HYDROCHLOROTHIAZIDE'
                921='(0921) D03258 ATENOLOL-CHLORTHALIDONE'
                922='(0922) D03259 BENDROFLUMETHIAZIDE-NADOLOL'
                923='(0923) D03260 HYDROCHLOROTHIAZIDE-TIMOLOL'
                924='(0924) D03261 HYDROCHLOROTHIAZIDE-PROPRANOLOL'
                925='(0925) D03263 HYDROCHLOROTHIAZIDE-METHYLDOPA'
                926='(0926) D03264 HYDROCHLOROTHIAZIDE-METOPROLOL'
                927='(0927) D03265 BENAZEPRIL-HYDROCHLOROTHIAZIDE'
                928='(0928) D03266 HYDROCHLOROTHIAZIDE-LISINOPRIL'
                929='(0929) D03267 CHLORTHALIDONE-CLONIDINE'
                930='(0930) D03271 PHENIRAMINE-PHENYLEPHRINE NASAL'
                931='(0931) D03273 GUAIFENESIN-THEOPHYLLINE'
                932='(0932) D03274 AMINOPHYLLINE-GUAIFENESIN' 933='(0933) D03276 DYPHYLLINE-GUAIFENESIN'
                934='(0934) D03277 POTASSIUM IODIDE-THEOPHYLLINE'
                935='(0935) D03280 EPHEDRINE/PHENOBARBITAL/THEOPHYLLINE'
                936='(0936) D03283 EPHEDRINE/HYDROXYZINE/THEOPHYLLINE'
                937='(0937) D03289 ACETAMINOPHEN-PSEUDOEPHEDRINE'
                938='(0938) D03292 IBUPROFEN-PSEUDOEPHEDRINE' 939='(0939) D03293 APAP/ASA/PPA'
                940='(0940) D03296 ACETAMINOPHEN-CHLORPHENIRAMINE'
                941='(0941) D03297 ACETAMINOPHEN-PHENYLTOLOXAMINE'
                942='(0942) D03298 CHLORPHENIRAMINE-PSEUDOEPHEDRINE'
                943='(0943) D03299 CHLORPHENIRAMINE-PHENYLPROPANOLAMINE'
                944='(0944) D03300 CHLORPHENIRAMINE-PHENYLEPHRINE'
                945='(0945) D03301 BROMPHENIRAMINE-PSEUDOEPHEDRINE'
                946='(0946) D03302 BROMPHENIRAMINE-PHENYLPROPANOLAMINE'
                947='(0947) D03303 CLEMASTINE-PHENYLPROPANOLAMINE'
                948='(0948) D03306 CHLORPHENIRAMINE/PE/PHENYLTOLOXAMINE'
                949='(0949) D03307 CHLORPHENIRAMINE/PHENINDAMINE/PPA'
                950='(0950) D03308 PHENIRAMINE/PPA/PHENYLTOLOXAMINE/PYRILAMINE'
                951='(0951) D03310 CHLORPHENIRAMINE/PE/PPA/PHENYLTOLOXAMINE'
                952='(0952) D03311 BROMPHENIRAMINE-PHENYLEPHRINE'
                953='(0953) D03312 DIPHENHYDRAMINE-PSEUDOEPHEDRINE'
                954='(0954) D03313 CHLORPHENIRAMINE/PHENYLEPHRINE/PYRILAMINE'
                955='(0955) D03316 PSEUDOEPHEDRINE-TRIPROLIDINE'
                956='(0956) D03317 PHENYLEPHRINE-PROMETHAZINE'
                957='(0957) D03318 PHENIRAMINE/PPA/PYRILAMINE'
                958='(0958) D03319 APAP/CHLORPHENIRAMINE/PHENYLPROPANOLAMINE'
                959='(0959) D03320 APAP/CHLORPHENIRAMINE/PSEUDOEPHEDRINE'
                960='(0960) D03321 APAP/BROMPHENIRAMINE/PSEUDOEPHEDRINE'
                961='(0961) D03322 ASA/CHLORPHENIRAMINE/PHENYLPROPANOLAMINE'
                962='(0962) D03329 ASA/DIPHENHYDRAMINE/PPA'
                963='(0963) D03330 APAP/PSEUDOEPHEDRINE/TRIPROLIDINE'
                964='(0964) D03331 APAP/CHLORPHENIRAMINE/PHENYLEPHRINE'
                965='(0965) D03336 APAP/CPM/PHENYLEPHRINE/PPA/PYRILAMINE'
                966='(0966) D03338 CHLORPHENIRAMINE/METHSCOPOLAMINE/PE'
                967='(0967) D03340 HOMATROPINE-HYDROCODONE' 968='(0968) D03341 CODEINE-PSEUDOEPHEDRINE'
                969='(0969) D03342 APAP/DEXTROMETHORPHAN/PSEUDOEPHEDRINE'
                970='(0970) D03347 APAP/CHLORPHENIRAMINE/DEXTROMETHORPHAN/PSE'
                971='(0971) D03349 APAP/DEXTROMETHORPHAN/DOXYLAMINE/PSE'
                972='(0972) D03351 ASA/BROMPHENIRAMINE/DEXTROMETHORPHAN/PPA'
                973='(0973) D03352 HYDROCODONE-PSEUDOEPHEDRINE'
                974='(0974) D03353 HYDROCODONE-PHENYLPROPANOLAMINE'
                975='(0975) D03354 DEXTROMETHORPHAN-PSEUDOEPHEDRINE'
                976='(0976) D03355 DEXTROMETHORPHAN-PHENYLPROPANOLAMINE'
                977='(0977) D03356 CHLORPHENIRAMINE-HYDROCODONE' 978='(0978) D03357 CODEINE-PROMETHAZINE'
                979='(0979) D03359 CHLORPHENIRAMINE-DEXTROMETHORPHAN'
                980='(0980) D03360 DEXTROMETHORPHAN-PROMETHAZINE'
                981='(0981) D03361 CHLORPHENIRAMINE/HYDROCODONE/PHENYLEPHRINE'
                982='(0982) D03362 CHLORPHENIRAMINE/CODEINE/PSEUDOEPHEDRINE'
                983='(0983) D03364 CODEINE/PHENYLEPHRINE/PROMETHAZINE'
                984='(0984) D03366 HYDROCODONE/PHENYLEPHRINE/PYRILAMINE'
                985='(0985) D03368 BROMPHENIRAMINE/DEXTROMETHORPHAN/PSE'
                986='(0986) D03369 CHLORPHENIRAMINE/DEXTROMETHORP/PHENYLEPHRINE'
                987='(0987) D03370 CHLORPHENIRAMINE/DEXTROMETHORPHAN/PSE'
                988='(0988) D03371 DEXTROMETHORPHAN/PHENYLEPHRINE/PYRILAMINE'
                989='(0989) D03372 BROMPHENIRAMINE/DEXTROMETHORPHAN/PPA'
                990='(0990) D03378 ACETAMINOPHEN-DEXTROMETHORPHAN'
                991='(0991) D03379 GUAIFENESIN-PSEUDOEPHEDRINE' 992='(0992) D03380 EPHEDRINE-GUAIFENESIN'
                993='(0993) D03381 GUAIFENESIN-PHENYLEPHRINE'
                994='(0994) D03382 GUAIFENESIN-PHENYLPROPANOLAMINE'
                995='(0995) D03383 GUAIFENESIN/PHENYLEPHRINE/PPA'
                996='(0996) D03388 ETHINYL ESTRADIOL-ETHYNODIOL'
                997='(0997) D03389 ESTRADIOL-TESTOSTERONE'
                998='(0998) D03392 CHLORPHENIRAMINE/GUAIFENESIN/PHENYLEPHRINE'
                999='(0999) D03393 CODEINE-GUAIFENESIN' 1000='(1000) D03396 GUAIFENESIN-HYDROCODONE'
                1001='(1001) D03397 GUAIFENESIN-HYDROMORPHONE'
                1002='(1002) D03398 CODEINE/GUAIFENESIN/PSE'
                1003='(1003) D03400 DEXTROMETHORPHAN-GUAIFENESIN'
                1004='(1004) D03403 GUAIFENESIN/HYDROCODONE/PHENYLEPHRINE'
                1005='(1005) D03404 GUAIFENESIN/HYDROCODONE/PSEUDOEPHEDRINE'
                1006='(1006) D03407 CODEINE/GUAIFENESIN/PHENYLPROPANOLAMINE'
                1007='(1007) D03408 DEXTROMETHORPHAN/GUAIFENESIN/PHENYLEPHRINE'
                1008='(1008) D03409 DEXTROMETHORPHAN/GUAIFENESIN/PSEUDOEPHEDRINE'
                1009='(1009) D03411 DEXTROMETHORPHAN/GUAIFENESIN/PPA'
                1010='(1010) D03416 CHLORPHENIRAMINE/HYDROCODONE/PSE'
                1011='(1011) D03419 CHLORPHENIRAMINE/DM/GUAIFENESIN/PHENYLEPHRINE'
                1012='(1012) D03423 ACETAMINOPHEN-CODEINE' 1013='(1013) D03424 ASPIRIN-CODEINE'
                1014='(1014) D03425 APAP/BUTALBITAL/CAFFEINE/CODEINE'
                1015='(1015) D03426 ASA/BUTALBITAL/CAFFEINE/CODEINE'
                1016='(1016) D03428 ACETAMINOPHEN-HYDROCODONE'
                1017='(1017) D03430 ASA/CAFFEINE/DIHYDROCODEINE'
                1018='(1018) D03431 ACETAMINOPHEN-OXYCODONE' 1019='(1019) D03432 ASPIRIN-OXYCODONE'
                1020='(1020) D03433 MEPERIDINE-PROMETHAZINE'
                1021='(1021) D03434 ACETAMINOPHEN-PROPOXYPHENE'
                1022='(1022) D03435 ASA/CAFFEINE/PROPOXYPHENE' 1023='(1023) D03436 BELLADONNA-OPIUM'
                1024='(1024) D03437 APAP/ASA/CAFFEINE/SALICYLAMIDE'
                1025='(1025) D03439 APAP/ASA/CAFFEINE'
                1026='(1026) D03443 APAP/AL HYDROXIDE/ASA/CAFFEINE/MG HYDROXIDE'
                1027='(1027) D03445 ACETAMINOPHEN-DIPHENHYDRAMINE'
                1028='(1028) D03447 ASA/CAFFEINE/SALICYLAMIDE' 1029='(1029) D03448 ASPIRIN-MEPROBAMATE'
                1030='(1030) D03449 ASPIRIN-CAFFEINE' 1031='(1031) D03453 ASPIRIN-PHENYLTOLOXAMINE'
                1032='(1032) D03454 MAGNESIUM SALICYLATE-PHENYLTOLOXAMINE'
                1033='(1033) D03455 APAP/BUTALBITAL/CAFFEINE'
                1034='(1034) D03456 ACETAMINOPHEN-BUTALBITAL'
                1035='(1035) D03457 ASA/BUTALBITAL/CAFFEINE'
                1036='(1036) D03459 APAP/DICHLORALPHENAZONE/ISOMETHEPTENE'
                1037='(1037) D03462 AMITRIPTYLINE-CHLORDIAZEPOXIDE'
                1038='(1038) D03463 AMITRIPTYLINE-PERPHENAZINE' 1039='(1039) D03464 DROPERIDOL-FENTANYL'
                1040='(1040) D03468 ASPIRIN-METHOCARBAMOL' 1041='(1041) D03469 ASPIRIN-CARISOPRODOL'
                1042='(1042) D03470 ASA/CARISOPRODOL/CODEINE'
                1043='(1043) D03472 ASA/CAFFEINE/ORPHENADRINE' 1044='(1044) D03473 CARBIDOPA-LEVODOPA'
                1045='(1045) D03474 ALUMINUM HYDROXIDE-MAGNESIUM HYDROXIDE'
                1046='(1046) D03478 AL HYDROXIDE/MG HYDROXIDE/SIMETHICONE'
                1047='(1047) D03480 CA CARBONATE/MG HYDROXIDE/SIMETHICONE'
                1048='(1048) D03485 ATROPINE/HYOSCYAMINE/PB/SCOPOLAMINE'
                1049='(1049) D03486 BELLADONNA-BUTABARBITAL'
                1050='(1050) D03492 CHLORDIAZEPOXIDE-CLIDINIUM'
                1051='(1051) D03495 BELLADONNA/ERGOTAMINE/PHENOBARBITAL'
                1052='(1052) D03496 DOCUSATE-SENNA' 1053='(1053) D03497 DOCUSATE-PHENOLPHTHALEIN'
                1054='(1054) D03498 CASANTHRANOL-DOCUSATE' 1055='(1055) D03505 ATROPINE-DIFENOXIN'
                1056='(1056) D03506 ATROPINE-DIPHENOXYLATE' 1057='(1057) D03508 ISONIAZID-RIFAMPIN'
                1058='(1058) D03509 ERYTHROMYCIN-SULFISOXAZOLE'
                1059='(1059) D03511 PHENAZOPYRIDINE-SULFAMETHOXAZOLE'
                1060='(1060) D03513 METHENAMINE-SODIUM ACID PHOSPHATE'
                1061='(1061) D03517 BENZOIC ACID/METHENAMINE/SODIUM SALICYLATE'
                1062='(1062) D03520 NAPHAZOLINE-PHENIRAMINE OPHTHALMIC'
                1063='(1063) D03521 CYCLOPENTOLATE-PHENYLEPHRINE OPHTHALMIC'
                1064='(1064) D03523 HYDROXYAMPHETAMINE-TROPICAMIDE OPHTHALMIC'
                1065='(1065) D03524 BACITRACIN/NEOMYCIN/POLYMYXIN B TOPICAL'
                1066='(1066) D03525 GRAMICIDIN/NEOMYCIN/POLYMYXIN B OPHTHALMIC'
                1067='(1067) D03526 NEOMYCIN-POLYMYXIN B SULFATE TOPICAL'
                1068='(1068) D03527 BACITRACIN-POLYMYXIN B TOPICAL'
                1069='(1069) D03529 POLYMYXIN B-TRIMETHOPRIM OPHTHALMIC'
                1070='(1070) D03533 NEOMYCIN/POLYMYXIN B/PREDNISOLONE OPHTHALMIC'
                1071='(1071) D03536 DEXAMETHASONE-TOBRAMYCIN OPHTHALMIC'
                1072='(1072) D03537 DEXAMETHASONE/NEOMYCIN/POLYMYXIN B OPHTHALMIC'
                1073='(1073) D03541 PREDNISOLONE-SULFACETAMIDE SODIUM OPHTHALMIC'
                1074='(1074) D03542 FLUORESCEIN-PROPARACAINE OPHTHALMIC'
                1075='(1075) D03543 HYDROCORTISONE/NEOMYCIN/POLYMYXIN B OTIC'
                1076='(1076) D03544 HYDROCORTISONE-POLYMYXIN B OTIC'
                1077='(1077) D03546 HYDROCORTISONE-PRAMOXINE TOPICAL'
                1078='(1078) D03552 CLIOQUINOL-HYDROCORTISONE TOPICAL'
                1079='(1079) D03553 CLIOQUINOL/HYDROCORTISONE/PRAMOXINE TOPICAL'
                1080='(1080) D03561 BETAMETHASONE-CLOTRIMAZOLE TOPICAL'
                1081='(1081) D03562 NYSTATIN-TRIAMCINOLONE TOPICAL'
                1082='(1082) D03566 CAPTOPRIL-HYDROCHLOROTHIAZIDE' 1083='(1083) D03569 CARBINOXAMINE'
                1084='(1084) D03570 CARBINOXAMINE-PSEUDOEPHEDRINE'
                1085='(1085) D03572 CARAMIPHEN-PHENYLPROPANOLAMINE'
                1086='(1086) D03576 BROMODIPHENHYDRAMINE-CODEINE'
                1087='(1087) D03577 CARBINOXAMINE/DEXTROMETHORPHAN/PSE'
                1088='(1088) D03584 CODEINE/PHENIRAMINE/PHENYLEPHRINE/NA CITRATE'
                1089='(1089) D03585 PAMABROM' 1090='(1090) D03586 APAP/PAMABROM/PYRILAMINE'
                1091='(1091) D03588 MAGNESIUM CARBONATE'
                1092='(1092) D03591 ALGINIC ACID/AL HYDROXIDE/MG CARBONATE'
                1093='(1093) D03596 ALGINIC ACID/AL HYDROXIDE/MG TRISILICATE'
                1094='(1094) D03600 POTASSIUM BICARBONATE' 1095='(1095) D03613 PSYLLIUM-SENNA'
                1096='(1096) D03618 HYOSCYAMINE/METHENAM/M-BLUE/PHENYL SALICYL'
                1097='(1097) D03620 ANTAZOLINE-NAPHAZOLINE OPHTHALMIC'
                1098='(1098) D03622 BENOXINATE-FLUORESCEIN OPHTHALMIC'
                1099='(1099) D03623 ACETIC ACID TOPICAL' 1100='(1100) D03624 ANTIPYRINE OTIC'
                1101='(1101) D03625 ACETIC ACID-HYDROCORTISONE OTIC'
                1102='(1102) D03627 ANTIPYRINE-BENZOCAINE OTIC'
                1103='(1103) D03628 ANTIPYRINE/BENZOCAINE/PHENYLEPHRINE OTIC'
                1104='(1104) D03630 ANHYDROUS CALCIUM IODIDE-CODEINE'
                1105='(1105) D03632 CETYLPYRIDINIUM TOPICAL'
                1106='(1106) D03634 BENZOCAINE-CETYLPYRIDINIUM TOPICAL'
                1107='(1107) D03640 BUDESONIDE NASAL' 1108='(1108) D03641 PETROLATUM TOPICAL'
                1109='(1109) D03644 LACTOBACILLUS ACIDOPHILUS'
                1110='(1110) D03646 LACTOBACILLUS ACIDOPHILUS AND BULGARICUS'
                1111='(1111) D03647 ISOPROPYL ALCOHOL TOPICAL'
                1112='(1112) D03648 OPHTHALMIC IRRIGATION, INTRAOCULAR'
                1113='(1113) D03649 BENZOIN TOPICAL' 1114='(1114) D03650 CANDIDA ALBICANS EXTRACT'
                1115='(1115) D03651 CHOLINE SALICYLATE-MAGNESIUM SALICYLATE'
                1116='(1116) D03652 COLCHICINE-PROBENECID' 1117='(1117) D03653 CALAMINE TOPICAL'
                1118='(1118) D03655 LIDOCAINE-PRILOCAINE TOPICAL'
                1119='(1119) D03656 ETHYL CHLORIDE TOPICAL'
                1120='(1120) D03659 FIBRINOLYSIN AND DESOXYRIBONUCLEASE TOPICAL'
                1121='(1121) D03660 MULTIVITAMIN WITH IRON AND FLUORIDE'
                1122='(1122) D03661 DOCUSATE-FERROUS FUMARATE' 1123='(1123) D03663 LECITHIN'
                1124='(1124) D03664 PHENOL TOPICAL' 1125='(1125) D03665 MENTHOL TOPICAL'
                1126='(1126) D03666 MENTHOL-PHENOL TOPICAL' 1127='(1127) D03667 METHACHOLINE'
                1128='(1128) D03668 METHYL SALICYLATE TOPICAL' 1129='(1129) D03674 PECTIN'
                1130='(1130) D03676 NALOXONE-PENTAZOCINE'
                1131='(1131) D03678 NAPHAZOLINE-ZINC OPHTHALMIC'
                1132='(1132) D03680 ASA/CITRIC ACID/NA BICARB'
                1133='(1133) D03681 OPHTHALMIC IRRIGATION, EXTRAOCULAR'
                1134='(1134) D03682 ACETAMINOPHEN-PENTAZOCINE' 1135='(1135) D03684 THROMBIN TOPICAL'
                1136='(1136) D03686 UNDECYLENIC ACID TOPICAL'
                1137='(1137) D03687 ALUMINUM ACETATE TOPICAL'
                1138='(1138) D03688 ALUMINUM SULFATE TOPICAL' 1139='(1139) D03689 CALCIUM ACETATE'
                1140='(1140) D03690 ALUMINUM SULFATE-CALCIUM ACETATE TOPICAL'
                1141='(1141) D03691 BENZOCAINE/PHENOL/POVIDONE IODINE TOPICAL'
                1142='(1142) D03693 ICHTHAMMOL TOPICAL' 1143='(1143) D03694 MEDRYSONE OPHTHALMIC'
                1144='(1144) D03695 PRAMOXINE-ZINC OXIDE TOPICAL'
                1145='(1145) D03696 BENZYL BENZOATE TOPICAL' 1146='(1146) D03701 CORN STARCH TOPICAL'
                1147='(1147) D03702 SULFUR TOPICAL' 1148='(1148) D03703 COAL TAR TOPICAL'
                1149='(1149) D03705 SALICYLIC ACID-SULFUR TOPICAL' 1150='(1150) D03707 ALOE VERA TOPICAL'
                1151='(1151) D03708 LANOLIN-MINERAL OIL TOPICAL'
                1152='(1152) D03710 ALLANTOIN/CAMPHOR/PHENOL TOPICAL'
                1153='(1153) D03712 CAMPHOR TOPICAL' 1154='(1154) D03713 CAMPHOR-PHENOL TOPICAL'
                1155='(1155) D03716 CITRIC ACID/GLUCONODELTA-LACTONE/MG CARBONATE'
                1156='(1156) D03721 SODIUM IODIDE' 1157='(1157) D03724 FAT EMULSION, INTRAVENOUS'
                1158='(1158) D03725 INTRAVENOUS ELECTROLYTE SOLUTION'
                1159='(1159) D03735 TRIETHANOLAMINE POLYPEPTIDE OLEATE OTIC'
                1160='(1160) D03738 TETRACYCLINE TOPICAL' 1161='(1161) D03739 NIACINAMIDE'
                1162='(1162) D03740 ENALAPRIL-HYDROCHLOROTHIAZIDE'
                1163='(1163) D03743 PYRIMETHAMINE-SULFADOXINE'
                1164='(1164) D03744 BISOPROLOL-HYDROCHLOROTHIAZIDE'
                1165='(1165) D03750 DEXBROMPHENIRAMINE'
                1166='(1166) D03751 DEXBROMPHENIRAMINE-PSEUDOEPHEDRINE' 1167='(1167) D03752 TACROLIMUS'
                1168='(1168) D03754 ACRIVASTINE-PSEUDOEPHEDRINE' 1169='(1169) D03756 BACITRACIN TOPICAL'
                1170='(1170) D03759 SALMETEROL' 1171='(1171) D03760 DIPHENHYDRAMINE TOPICAL'
                1172='(1172) D03761 LANOLIN TOPICAL' 1173='(1173) D03762 WITCH HAZEL TOPICAL'
                1174='(1174) D03763 GLYCERIN-PHENOL TOPICAL'
                1175='(1175) D03764 GLYCERIN-WITCH HAZEL TOPICAL' 1176='(1176) D03766 ROCURONIUM'
                1177='(1177) D03767 IRON DEXTRAN' 1178='(1178) D03768 OCULAR LUBRICANT'
                1179='(1179) D03770 EMOLLIENTS, TOPICAL' 1180='(1180) D03773 STAVUDINE'
                1181='(1181) D03774 DOXEPIN TOPICAL' 1182='(1182) D03775 FAMCICLOVIR'
                1183='(1183) D03777 POTASSIUM ACETATE' 1184='(1184) D03780 DESOGESTREL'
                1185='(1185) D03781 ETHINYL ESTRADIOL-NORGESTIMATE'
                1186='(1186) D03782 DESOGESTREL-ETHINYL ESTRADIOL'
                1187='(1187) D03783 BUPIVACAINE-EPINEPHRINE' 1188='(1188) D03784 EPINEPHRINE-LIDOCAINE'
                1189='(1189) D03788 CALCIPOTRIENE TOPICAL' 1190='(1190) D03789 POTASSIUM GLUCONATE'
                1191='(1191) D03790 POTASSIUM PHOSPHATE' 1192='(1192) D03796 MAGNESIUM CHLORIDE'
                1193='(1193) D03797 MAGNESIUM OXIDE' 1194='(1194) D03798 MAGNESIUM GLUCONATE'
                1195='(1195) D03799 CALCIUM CHLORIDE' 1196='(1196) D03800 CALCIUM GLUCONATE'
                1197='(1197) D03802 CALCIUM LACTATE' 1198='(1198) D03803 CALCIUM PHOSPHATE, TRIBASIC'
                1199='(1199) D03804 FLUVOXAMINE' 1200='(1200) D03805 DORZOLAMIDE OPHTHALMIC'
                1201='(1201) D03806 ALBENDAZOLE' 1202='(1202) D03807 METFORMIN'
                1203='(1203) D03808 NEFAZODONE' 1204='(1204) D03809 LAMOTRIGINE'
                1205='(1205) D03810 VINORELBINE' 1206='(1206) D03811 ABCIXIMAB'
                1207='(1207) D03812 DALTEPARIN' 1208='(1208) D03818 LORATADINE-PSEUDOEPHEDRINE'
                1209='(1209) D03819 CONJUGATED ESTROGENS-MEDROXYPROGESTERONE'
                1210='(1210) D03821 LOSARTAN' 1211='(1211) D03822 FERROUS GLUCONATE'
                1212='(1212) D03823 IRON POLYSACCHARIDE' 1213='(1213) D03824 FERROUS SULFATE'
                1214='(1214) D03825 NISOLDIPINE' 1215='(1215) D03826 TRAMADOL'
                1216='(1216) D03827 CETIRIZINE' 1217='(1217) D03828 LANSOPRAZOLE'
                1218='(1218) D03829 AMLODIPINE-BENAZEPRIL'
                1219='(1219) D03830 HYDROCHLOROTHIAZIDE-LOSARTAN' 1220='(1220) D03831 NILUTAMIDE'
                1221='(1221) D03832 VARICELLA VIRUS VACCINE' 1222='(1222) D03833 DIVALPROEX SODIUM'
                1223='(1223) D03834 NALMEFENE' 1224='(1224) D03835 MOEXIPRIL'
                1225='(1225) D03836 ACITRETIN' 1226='(1226) D03838 VALACYCLOVIR'
                1227='(1227) D03839 MYCOPHENOLATE MOFETIL' 1228='(1228) D03840 IOPROMIDE'
                1229='(1229) D03841 DEXRAZOXANE' 1230='(1230) D03842 EPOPROSTENOL'
                1231='(1231) D03843 GADOTERIDOL' 1232='(1232) D03844 DIRITHROMYCIN'
                1233='(1233) D03845 SEVOFLURANE' 1234='(1234) D03846 ACARBOSE'
                1235='(1235) D03847 CARVEDILOL' 1236='(1236) D03848 AZELAIC ACID TOPICAL'
                1237='(1237) D03849 ALENDRONATE' 1238='(1238) D03850 BICALUTAMIDE'
                1239='(1239) D03857 BENZOYL PEROXIDE-ERYTHROMYCIN TOPICAL'
                1240='(1240) D03858 LAMIVUDINE' 1241='(1241) D03860 SAQUINAVIR'
                1242='(1242) D03862 MAGNESIUM AMINO ACIDS CHELATE' 1243='(1243) D03863 TRETINOIN'
                1244='(1244) D03864 GLIMEPIRIDE' 1245='(1245) D03866 CALCIUM CITRATE'
                1246='(1246) D03867 CALCIUM CARBONATE-SODIUM FLUORIDE' 1247='(1247) D03868 AMIFOSTINE'
                1248='(1248) D03869 RILUZOLE' 1249='(1249) D03870 AMPHOTERICIN B LIPID COMPLEX'
                1250='(1250) D03872 PORFIMER' 1251='(1251) D03873 ANASTROZOLE'
                1252='(1252) D03874 CEFTIBUTEN' 1253='(1253) D03877 HEROIN' 1254='(1254) D03878 COCAINE'
                1255='(1255) D03879 MARIJUANA' 1256='(1256) D03880 PHENCYCLIDINE'
                1257='(1257) D03881 RESPIRATORY SYNCYTIAL VIRUS IMMUNE GLOBULIN'
                1258='(1258) D03882 CEFEPIME'
                1259='(1259) D03883 AL HYDROXIDE/ASA/CA CARBONATE/MG HYDROXIDE'
                1260='(1260) D03884 TROLAMINE SALICYLATE TOPICAL'
                1261='(1261) D03888 BENZOCAINE/BUTAMBEN/TETRACAINE TOPICAL'
                1262='(1262) D03892 HISTAMINE PHOSPHATE' 1263='(1263) D03894 KAOLIN-PECTIN'
                1264='(1264) D03895 SINCALIDE' 1265='(1265) D03897 LACTASE'
                1266='(1266) D03898 SODIUM CHLORIDE, HYPERTONIC, OPHTHALMIC'
                1267='(1267) D03904 BALSAM PERU/CASTOR OIL/TRYPSIN TOPICAL'
                1268='(1268) D03905 ISOPROTERENOL-PHENYLEPHRINE'
                1269='(1269) D03906 PHENIRAMINE/PHENYLTOLOXAMINE/PYRILAMINE'
                1270='(1270) D03908 APAP/CHLORPHENIRAMINE/DEXTROMETHORPHAN/PPA'
                1271='(1271) D03911 CHLORPHENIRAMINE/METHSCOPOLAMINE/PSE'
                1272='(1272) D03913 APAP/DEXTROMETHORPHAN/PSE/PYRILAMINE'
                1273='(1273) D03915 HYDROCODONE-POTASSIUM GUAIACOLSULFONATE'
                1274='(1274) D03920 FERROUS FUMARATE' 1275='(1275) D03922 ACETAMINOPHEN-CAFFEINE'
                1276='(1276) D03923 ACETAMINOPHEN-PHENYLEPHRINE'
                1277='(1277) D03926 APAP/CAFFEINE/PYRILAMINE' 1278='(1278) D03927 BACITRACIN OPHTHALMIC'
                1279='(1279) D03929 AMINOPHYLLINE/AMOBARBITAL/EPHEDRINE'
                1280='(1280) D03946 ASCORBIC ACID-FERROUS FUMARATE'
                1281='(1281) D03951 CITRIC ACID/K CITRATE/NA CITRATE'
                1282='(1282) D03952 CITRIC ACID-SODIUM CITRATE'
                1283='(1283) D03953 ELECTROLYTE REPLACEMENT SOLUTIONS, ORAL'
                1284='(1284) D03954 FERROUS FUMARATE-FOLIC ACID'
                1285='(1285) D03957 CALCIUM/FERROUS FUMARATE/VITAMIN D'
                1286='(1286) D03962 POTASSIUM BICARBONATE-POTASSIUM CITRATE'
                1287='(1287) D03963 BACITRACIN/HC/NEOMYCIN/POLYMYXIN B OPHTHALMIC'
                1288='(1288) D03964 BACITRACIN/NEOMYCIN/POLYMYXIN B OPHTHALMIC'
                1289='(1289) D03965 BACITRACIN-POLYMYXIN B OPHTHALMIC'
                1290='(1290) D03966 BENZOYL PEROXIDE-SULFUR TOPICAL'
                1291='(1291) D03968 DEXAMETHASONE OPHTHALMIC' 1292='(1292) D03971 EPINEPHRINE OPHTHALMIC'
                1293='(1293) D03973 ERYTHROMYCIN OPHTHALMIC' 1294='(1294) D03974 GENTAMICIN OPHTHALMIC'
                1295='(1295) D03975 GLYCERIN OPHTHALMIC' 1296='(1296) D03976 HYDROCORTISONE OTIC'
                1297='(1297) D03977 OFLOXACIN OPHTHALMIC' 1298='(1298) D03978 OXYMETAZOLINE OPHTHALMIC'
                1299='(1299) D03979 SCOPOLAMINE OPHTHALMIC' 1300='(1300) D03980 SULFISOXAZOLE OPHTHALMIC'
                1301='(1301) D03981 TETRACAINE OPHTHALMIC' 1302='(1302) D03982 TETRACAINE TOPICAL'
                1303='(1303) D03984 RITONAVIR' 1304='(1304) D03985 INDINAVIR'
                1305='(1305) D03989 BORIC ACID OPHTHALMIC' 1306='(1306) D03990 CARBAMIDE PEROXIDE OTIC'
                1307='(1307) D03992 CHLORAMPHENICOL OPHTHALMIC'
                1308='(1308) D03993 CHLORTETRACYCLINE OPHTHALMIC'
                1309='(1309) D03994 COLLOIDAL OATMEAL TOPICAL' 1310='(1310) D03998 STERILE WATER'
                1311='(1311) D04002 PIPERONYL BUTOXIDE-PYRETHRINS TOPICAL'
                1312='(1312) D04003 HYDROGEN PEROXIDE TOPICAL' 1313='(1313) D04004 DOXORUBICIN LIPOSOMAL'
                1314='(1314) D04005 AMOBARBITAL-SECOBARBITAL' 1315='(1315) D04006 DEXFENFLURAMINE'
                1316='(1316) D04008 TRANDOLAPRIL' 1317='(1317) D04009 DOCETAXEL'
                1318='(1318) D04010 GEMCITABINE' 1319='(1319) D04011 INTERFERON BETA-1A'
                1320='(1320) D04012 TERBINAFINE' 1321='(1321) D04014 TOPOTECAN'
                1322='(1322) D04015 ADAPALENE TOPICAL' 1323='(1323) D04016 IODIXANOL'
                1324='(1324) D04017 LATANOPROST OPHTHALMIC'
                1325='(1325) D04021 BENZOIC ACID-SALICYLIC ACID TOPICAL' 1326='(1326) D04025 MIRTAZAPINE'
                1327='(1327) D04026 IRINOTECAN' 1328='(1328) D04027 MEROPENEM'
                1329='(1329) D04028 CIDOFOVIR' 1330='(1330) D04029 NEVIRAPINE'
                1331='(1331) D04031 PILOCARPINE' 1332='(1332) D04032 SULFACETAMIDE SODIUM-SULFUR TOPICAL'
                1333='(1333) D04034 REMIFENTANIL' 1334='(1334) D04035 AMPHETAMINE-DEXTROAMPHETAMINE'
                1335='(1335) D04036 CAFFEINE-SODIUM BENZOATE' 1336='(1336) D04037 TIMOLOL OPHTHALMIC'
                1337='(1337) D04038 BETAXOLOL OPHTHALMIC' 1338='(1338) D04039 CARTEOLOL OPHTHALMIC'
                1339='(1339) D04040 FEXOFENADINE' 1340='(1340) D04041 FOSPHENYTOIN'
                1341='(1341) D04043 FOLLICLE STIMULATING HORMONE' 1342='(1342) D04044 RESORCINOL TOPICAL'
                1343='(1343) D04045 RESORCINOL-SULFUR TOPICAL' 1344='(1344) D04047 MIDODRINE'
                1345='(1345) D04048 BRIMONIDINE OPHTHALMIC' 1346='(1346) D04049 AMMONIUM LACTATE TOPICAL'
                1347='(1347) D04050 OLANZAPINE' 1348='(1348) D04051 ROPIVACAINE'
                1349='(1349) D04052 PENTOSAN POLYSULFATE SODIUM' 1350='(1350) D04053 ZAFIRLUKAST'
                1351='(1351) D04054 PENCICLOVIR TOPICAL' 1352='(1352) D04056 ZINC GLUCONATE'
                1353='(1353) D04057 ZINC SULFATE' 1354='(1354) D04058 MELATONIN'
                1355='(1355) D04059 HAEMOPHILUS B-HEPATITIS B VACCINE'
                1356='(1356) D04060 DILTIAZEM-ENALAPRIL'
                1357='(1357) D04061 BISMUTH SUBSALICYLATE/METRONIDAZOLE/TCN'
                1358='(1358) D04062 BENTOQUATAM TOPICAL' 1359='(1359) D04063 BUTENAFINE TOPICAL'
                1360='(1360) D04065 TRANDOLAPRIL-VERAPAMIL' 1361='(1361) D04066 ALBUTEROL-IPRATROPIUM'
                1362='(1362) D04067 RETEPLASE' 1363='(1363) D04068 AZELASTINE NASAL'
                1364='(1364) D04070 SODIUM PHENYLBUTYRATE' 1365='(1365) D04075 CHLOROXYLENOL TOPICAL'
                1366='(1366) D04076 CHLOROXYLENOL/HYDROCORTISONE/PRAMOXINE OTIC'
                1367='(1367) D04083 GADODIAMIDE' 1368='(1368) D04084 GLYCINE IRRIGATION'
                1369='(1369) D04090 LACTIC ACID TOPICAL'
                1370='(1370) D04093 HYDROCORTISONE-IODOQUINOL TOPICAL'
                1371='(1371) D04095 HYDROCORTISONE/NEOMYCIN/POLYMYXIN B OPHTH'
                1372='(1372) D04096 IMIGLUCERASE' 1373='(1373) D04099 DONEPEZIL'
                1374='(1374) D04100 AMPHOTERICIN B CHOLESTERYL SULFATE' 1375='(1375) D04101 IVERMECTIN'
                1376='(1376) D04102 TIZANIDINE' 1377='(1377) D04103 ZILEUTON'
                1378='(1378) D04105 ATORVASTATIN' 1379='(1379) D04106 FOSFOMYCIN'
                1380='(1380) D04107 AMLEXANOX TOPICAL' 1381='(1381) D04109 LEVOFLOXACIN'
                1382='(1382) D04110 MIGLITOL' 1383='(1383) D04111 GLATIRAMER'
                1384='(1384) D04112 CABERGOLINE' 1385='(1385) D04113 VALSARTAN'
                1386='(1386) D04115 TOPIRAMATE' 1387='(1387) D04116 ENALAPRIL-FELODIPINE'
                1388='(1388) D04117 OLOPATADINE OPHTHALMIC' 1389='(1389) D04118 NELFINAVIR'
                1390='(1390) D04119 DELAVIRDINE' 1391='(1391) D04120 CAFFEINE-ERGOTAMINE'
                1392='(1392) D04121 TAMSULOSIN' 1393='(1393) D04122 TROGLITAZONE'
                1394='(1394) D04123 ZINC ACETATE' 1395='(1395) D04125 IMIQUIMOD TOPICAL'
                1396='(1396) D04126 ANAGRELIDE' 1397='(1397) D04128 LVP SOLUTION'
                1398='(1398) D04130 LVP SOLUTION WITH HYPERTONIC SALINE'
                1399='(1399) D04131 PARENTERAL NUTRITION SOLUTION'
                1400='(1400) D04132 PARENTERAL NUTRITION SOLUTION W/ELECTROLYTES'
                1401='(1401) D04133 NEOMYCIN OPHTHALMIC' 1402='(1402) D04134 POLYMYXIN B OPHTHALMIC'
                1403='(1403) D04135 PHENYLEPHRINE OPHTHALMIC' 1404='(1404) D04137 TOREMIFENE'
                1405='(1405) D04138 TAZAROTENE TOPICAL' 1406='(1406) D04139 MIBEFRADIL'
                1407='(1407) D04141 HYDROCHLOROTHIAZIDE-MOEXIPRIL'
                1408='(1408) D04142 CHROMIUM PICOLINATE' 1409='(1409) D04143 ACETAMINOPHEN-PAMABROM'
                1410='(1410) D04145 PRAMIPEXOLE' 1411='(1411) D04147 NAPHAZOLINE NASAL'
                1412='(1412) D04150 BROMFENAC' 1413='(1413) D04151 BENZOCAINE-TRIMETHOBENZAMIDE'
                1414='(1414) D04152 HYDROCODONE-PHENYLEPHRINE'
                1415='(1415) D04153 PHENAZOPYRIDINE-SULFISOXAZOLE'
                1416='(1416) D04155 ASPIRIN-DIPHENHYDRAMINE' 1417='(1417) D04156 LETROZOLE'
                1418='(1418) D04157 LOPERAMIDE-SIMETHICONE' 1419='(1419) D04159 SORBITOL'
                1420='(1420) D04160 SODIUM BIPHOSPHATE-SODIUM PHOSPHATE' 1421='(1421) D04161 SECRETIN'
                1422='(1422) D04163 FERROUS SULFATE-FOLIC ACID'
                1423='(1423) D04166 APAP/DEXTROMETHORPHAN/GUAIFENESIN/PSE'
                1424='(1424) D04168 APAP/DIPHENHYDRAMINE/PSEUDOEPHEDRINE'
                1425='(1425) D04172 CALAMINE-PRAMOXINE TOPICAL'
                1426='(1426) D04175 DIPHENHYDRAMINE-MAGNESIUM SALICYLATE'
                1427='(1427) D04177 FAT SUPPLEMENT, ORAL' 1428='(1428) D04178 CALCIUM HYDROXIDE TOPICAL'
                1429='(1429) D04184 POTASSIUM AMINOBENZOATE'
                1430='(1430) D04185 POTASSIUM BICARBONATE-SODIUM BICARBONATE'
                1431='(1431) D04186 PHENYLEPHRINE NASAL' 1432='(1432) D04189 TRIPELENNAMINE TOPICAL'
                1433='(1433) D04190 PAPAIN TOPICAL' 1434='(1434) D04191 PAPAIN-UREA TOPICAL'
                1435='(1435) D04192 COLISTIN/HC/NEOMYCIN/THONZONIUM OTIC'
                1436='(1436) D04193 LEVMETAMFETAMINE NASAL' 1437='(1437) D04194 PROPYLHEXEDRINE NASAL'
                1438='(1438) D04195 CHLOROPHYLLIN'
                1439='(1439) D04196 BACITRACIN/HC/NEOMYCIN/POLYMYXIN B TOPICAL'
                1440='(1440) D04197 HYDROCORTISONE/NEOMYCIN/POLYMYXIN B TOPICAL'
                1441='(1441) D04204 COPPER SULFATE' 1442='(1442) D04205 POVIDONE IODINE OPHTHALMIC'
                1443='(1443) D04206 TETRAHYDROZOLINE NASAL' 1444='(1444) D04208 SILVER NITRATE TOPICAL'
                1445='(1445) D04209 METHOXSALEN TOPICAL' 1446='(1446) D04210 ESTRADIOL TOPICAL'
                1447='(1447) D04214 DOLASETRON' 1448='(1448) D04215 ROPINIROLE'
                1449='(1449) D04217 EPINEPHRINE-PRILOCAINE' 1450='(1450) D04219 LAMIVUDINE-ZIDOVUDINE'
                1451='(1451) D04220 QUETIAPINE' 1452='(1452) D04221 TIAGABINE'
                1453='(1453) D04222 IRBESARTAN' 1454='(1454) D04223 MOMETASONE NASAL'
                1455='(1455) D04224 INTERFERON ALFACON-1' 1456='(1456) D04225 HYDROCODONE-IBUPROFEN'
                1457='(1457) D04226 AMINOSALICYLIC ACID' 1458='(1458) D04228 ACETIC ACID OTIC'
                1459='(1459) D04229 GLYCERIN OTIC' 1460='(1460) D04231 VITAMIN A OPHTHALMIC'
                1461='(1461) D04233 TRIAMCINOLONE NASAL' 1462='(1462) D04235 IPRATROPIUM NASAL'
                1463='(1463) D04236 ETHANOL TOPICAL' 1464='(1464) D04238 AMPHOTERICIN B LIPOSOMAL'
                1465='(1465) D04240 HYLAN G-F 20' 1466='(1466) D04241 POTASSIUM CHLORIDE-SODIUM CHLORIDE'
                1467='(1467) D04242 SODIUM CHLORIDE NASAL' 1468='(1468) D04243 LIDOCAINE-OXYTETRACYCLINE'
                1469='(1469) D04245 HYDROCHLOROTHIAZIDE-IRBESARTAN' 1470='(1470) D04247 PEGASPARGASE'
                1471='(1471) D04248 METHYLCELLULOSE' 1472='(1472) D04249 CELLULOSE'
                1473='(1473) D04253 ZOLMITRIPTAN' 1474='(1474) D04255 RITUXIMAB'
                1475='(1475) D04256 CEFDINIR' 1476='(1476) D04258 CLOPIDOGREL'
                1477='(1477) D04260 SIBUTRAMINE' 1478='(1478) D04261 RALOXIFENE'
                1479='(1479) D04263 TROVAFLOXACIN' 1480='(1480) D04264 BECAPLERMIN TOPICAL'
                1481='(1481) D04265 OFLOXACIN OTIC' 1482='(1482) D04266 EPROSARTAN'
                1483='(1483) D04267 REPAGLINIDE' 1484='(1484) D04269 APAP/CAFFEINE/DIHYDROCODEINE'
                1485='(1485) D04270 FEXOFENADINE-PSEUDOEPHEDRINE'
                1486='(1486) D04271 DICLOFENAC-MISOPROSTOL'
                1487='(1487) D04272 AMOXICILLIN/CLARITHROMYCIN/LANSOPRAZOLE'
                1488='(1488) D04274 FOMEPIZOLE' 1489='(1489) D04275 BECLOMETHASONE NASAL'
                1490='(1490) D04276 BUDESONIDE' 1491='(1491) D04279 FLUNISOLIDE NASAL'
                1492='(1492) D04282 TOLCAPONE' 1493='(1493) D04283 FLUTICASONE NASAL'
                1494='(1494) D04284 FLUTICASONE TOPICAL' 1495='(1495) D04285 NARATRIPTAN'
                1496='(1496) D04286 FENOFIBRATE' 1497='(1497) D04287 CIPROFLOXACIN OTIC'
                1498='(1498) D04288 CIPROFLOXACIN-HYDROCORTISONE OTIC' 1499='(1499) D04289 MONTELUKAST'
                1500='(1500) D04290 CALCIUM CARBONATE-MAGNESIUM HYDROXIDE' 1501='(1501) D04291 LEPIRUDIN'
                1502='(1502) D04292 LOTEPREDNOL OPHTHALMIC'
                1503='(1503) D04293 HYDROCHLOROTHIAZIDE-VALSARTAN' 1504='(1504) D04294 TOLTERODINE'
                1505='(1505) D04295 OXYMETHOLONE' 1506='(1506) D04296 STARCH TOPICAL'
                1507='(1507) D04297 PHENYLEPHRINE-PRAMOXINE TOPICAL'
                1508='(1508) D04298 PHENYLEPHRINE TOPICAL' 1509='(1509) D04299 SILDENAFIL'
                1510='(1510) D04300 RISEDRONATE' 1511='(1511) D04301 BRINZOLAMIDE OPHTHALMIC'
                1512='(1512) D04303 DORZOLAMIDE-TIMOLOL OPHTHALMIC' 1513='(1513) D04305 SACROSIDASE'
                1514='(1514) D04311 CAPECITABINE' 1515='(1515) D04312 PARICALCITOL'
                1516='(1516) D04314 BASILIXIMAB' 1517='(1517) D04315 TIROFIBAN'
                1518='(1518) D04316 EPTIFIBATIDE'
                1519='(1519) D04320 DIPHTHERIA/HAEMOPHILUS/PERTUSSIS,ACEL/TETANUS'
                1520='(1520) D04321 INTERFERON ALFA-2B-RIBAVIRIN' 1521='(1521) D04322 CANDESARTAN'
                1522='(1522) D04323 PALIVIZUMAB' 1523='(1523) D04328 RIZATRIPTAN'
                1524='(1524) D04329 SODIUM HYALURONATE' 1525='(1525) D04331 THALIDOMIDE'
                1526='(1526) D04332 CITALOPRAM' 1527='(1527) D04334 EPHEDRINE-POTASSIUM IODIDE'
                1528='(1528) D04339 DEXTROMETHORPHAN-POTASSIUM GUAIACOLSULFONATE'
                1529='(1529) D04342 INFLIXIMAB' 1530='(1530) D04344 ROTAVIRUS VACCINE'
                1531='(1531) D04345 APAP/CAFFEINE/GUAIFENESIN/PHENYLEPHRINE'
                1532='(1532) D04347 DOXYCYCLINE TOPICAL' 1533='(1533) D04349 LEFLUNOMIDE'
                1534='(1534) D04351 COAL TAR/LACTIC ACID/SALICYLIC ACID TOPICAL'
                1535='(1535) D04355 EFAVIRENZ' 1536='(1536) D04357 TRASTUZUMAB'
                1537='(1537) D04360 HEMIN' 1538='(1538) D04363 SEVELAMER'
                1539='(1539) D04364 TELMISARTAN' 1540='(1540) D04365 ETANERCEPT'
                1541='(1541) D04366 SIMETHICONE COATED CELLULOSE'
                1542='(1542) D04368 TANNIC ACID TOPICAL' 1543='(1543) D04369 INSULIN REGULAR'
                1544='(1544) D04370 INSULIN ISOPHANE' 1545='(1545) D04371 INSULIN ZINC'
                1546='(1546) D04372 INSULIN ZINC EXTENDED' 1547='(1547) D04373 INSULIN LISPRO'
                1548='(1548) D04374 INSULIN ISOPHANE-INSULIN REGULAR'
                1549='(1549) D04375 ESTRADIOL-NORETHINDRONE' 1550='(1550) D04376 ABACAVIR'
                1551='(1551) D04377 THYROTROPIN ALPHA' 1552='(1552) D04378 MODAFINIL'
                1553='(1553) D04379 LYME DISEASE VACCINE' 1554='(1554) D04380 CELECOXIB'
                1555='(1555) D04382 CILOSTAZOL' 1556='(1556) D04386 DENILEUKIN DIFTITOX'
                1557='(1557) D04387 SODIUM FERRIC GLUCONATE COMPLEX' 1558='(1558) D04389 PENTASTARCH'
                1559='(1559) D04391 LIVER DERIVATIVE COMPLEX'
                1560='(1560) D04393 BUTABARBITAL/HYOSCYAMINE/PHENAZOPYRIDINE'
                1561='(1561) D04394 CROMOLYN NASAL' 1562='(1562) D04395 CLOTRIMAZOLE TOPICAL'
                1563='(1563) D04396 CONJUGATED ESTROGENS TOPICAL' 1564='(1564) D04397 FLUORIDE TOPICAL'
                1565='(1565) D04399 NYSTATIN TOPICAL' 1566='(1566) D04402 CILASTATIN'
                1567='(1567) D04406 TYPHOID VACCINE, LIVE' 1568='(1568) D04407 ECHINACEA'
                1569='(1569) D04408 ST. JOHN''S WORT' 1570='(1570) D04409 CHAMOMILE'
                1571='(1571) D04410 FEVERFEW' 1572='(1572) D04411 GARLIC' 1573='(1573) D04412 GINSENG'
                1574='(1574) D04413 GINKGO' 1575='(1575) D04414 GINGER' 1576='(1576) D04415 SAW PALMETTO'
                1577='(1577) D04416 VALERIAN' 1578='(1578) D04417 CREATINE'
                1579='(1579) D04418 GLUCOSAMINE' 1580='(1580) D04419 CHONDROITIN'
                1581='(1581) D04420 CHONDROITIN-GLUCOSAMINE' 1582='(1582) D04421 EVENING PRIMROSE'
                1583='(1583) D04422 KAVA' 1584='(1584) D04423 GOLDENSEAL'
                1585='(1585) D04425 DEHYDROEPIANDROSTERONE' 1586='(1586) D04426 RED YEAST RICE'
                1587='(1587) D04427 LEVALBUTEROL' 1588='(1588) D04429 ORLISTAT'
                1589='(1589) D04430 BACITRACIN/NEOMYCIN/POLYMYXIN B/PRAMOXINE TOP'
                1590='(1590) D04431 NEOMYCIN/POLYMYXIN B/PRAMOXINE TOPICAL'
                1591='(1591) D04432 CARBONYL IRON' 1592='(1592) D04433 ROFECOXIB'
                1593='(1593) D04434 ROSIGLITAZONE' 1594='(1594) D04435 DOXERCALCIFEROL'
                1595='(1595) D04436 MALATHION TOPICAL' 1596='(1596) D04440 PERINDOPRIL'
                1597='(1597) D04441 KETOTIFEN OPHTHALMIC' 1598='(1598) D04442 PIOGLITAZONE'
                1599='(1599) D04443 ZANAMIVIR'
                1600='(1600) D04445 CARBETAPENTANE/CHLORPHENIRAMINE/PHENYLEPHRINE'
                1601='(1601) D04446 PHENYLEPHRINE-PYRILAMINE' 1602='(1602) D04447 GANIRELIX'
                1603='(1603) D04448 RABEPRAZOLE' 1604='(1604) D04451 TEMOZOLOMIDE'
                1605='(1605) D04452 ZALEPLON' 1606='(1606) D04453 SIROLIMUS'
                1607='(1607) D04454 EPIRUBICIN' 1608='(1608) D04457 DALFOPRISTIN-QUINUPRISTIN'
                1609='(1609) D04458 PEMIROLAST OPHTHALMIC' 1610='(1610) D04459 DOFETILIDE'
                1611='(1611) D04460 ENTACAPONE' 1612='(1612) D04461 EXEMESTANE'
                1613='(1613) D04462 OSELTAMIVIR' 1614='(1614) D04463 GRAPE SEED OIL'
                1615='(1615) D04464 DONG QUAI' 1616='(1616) D04466 MILK THISTLE'
                1617='(1617) D04467 CAT''S CLAW' 1618='(1618) D04469 BEE POLLEN'
                1619='(1619) D04470 CRANBERRY' 1620='(1620) D04472 BLACK COHOSH'
                1621='(1621) D04473 BLUE COHOSH' 1622='(1622) D04478 WILD YAM'
                1623='(1623) D04479 PENNYROYAL' 1624='(1624) D04481 ROYAL JELLY'
                1625='(1625) D04482 DAMIANA' 1626='(1626) D04483 DANDELION'
                1627='(1627) D04484 SHARK CARTILAGE' 1628='(1628) D04491 FLAX'
                1629='(1629) D04492 FENUGREEK' 1630='(1630) D04497 ASPIRIN-DIPYRIDAMOLE'
                1631='(1631) D04498 NAPROXEN-PSEUDOEPHEDRINE' 1632='(1632) D04499 LEVETIRACETAM'
                1633='(1633) D04500 MOXIFLOXACIN' 1634='(1634) D04501 AMINOLEVULINIC ACID TOPICAL'
                1635='(1635) D04503 NEDOCROMIL OPHTHALMIC' 1636='(1636) D04504 GATIFLOXACIN'
                1637='(1637) D04505 DEXMEDETOMIDINE' 1638='(1638) D04506 ESTRADIOL-NORGESTIMATE'
                1639='(1639) D04507 BEXAROTENE' 1640='(1640) D04508 NITRIC OXIDE'
                1641='(1641) D04509 HYDROCHLOROTHIAZIDE-QUINAPRIL'
                1642='(1642) D04510 INSULIN LISPRO-INSULIN LISPRO PROTAMINE'
                1643='(1643) D04512 CEVIMELINE' 1644='(1644) D04513 OXCARBAZEPINE'
                1645='(1645) D04514 PANTOPRAZOLE' 1646='(1646) D04515 GADOVERSETAMIDE'
                1647='(1647) D04516 ALOSETRON' 1648='(1648) D04523 UBIQUINONE'
                1649='(1649) D04524 S-ADENOSYLMETHIONINE' 1650='(1650) D04527 ZONISAMIDE'
                1651='(1651) D04530 STRONTIUM-89 CHLORIDE'
                1652='(1652) D04531 SAMARIUM SM 153 LEXIDRONAM' 1653='(1653) D04532 MELOXICAM'
                1654='(1654) D04533 VERTEPORFIN' 1655='(1655) D04534 LINEZOLID'
                1656='(1656) D04535 ARTICAINE-EPINEPHRINE' 1657='(1657) D04536 ARTICAINE'
                1658='(1658) D04537 RIVASTIGMINE' 1659='(1659) D04538 INSULIN GLARGINE'
                1660='(1660) D04539 FOSINOPRIL-HYDROCHLOROTHIAZIDE' 1661='(1661) D04540 GEMTUZUMAB'
                1662='(1662) D04541 AZELASTINE OPHTHALMIC' 1663='(1663) D04547 ATOVAQUONE-PROGUANIL'
                1664='(1664) D04557 CLOBAZAM' 1665='(1665) D04572 FORMOTEROL'
                1666='(1666) D04597 TETRABENAZINE' 1667='(1667) D04611 FLUTICASONE-SALMETEROL'
                1668='(1668) D04659 TINZAPARIN' 1669='(1669) D04669 VIGABATRIN'
                1670='(1670) D04674 DIPHTH/HAEMOPHILUS/PERTUSSIS/TETANUS/POLIO'
                1671='(1671) D04675 DIPHTHERIA/PERTUSSIS,ACEL/TETANUS/POLIO'
                1672='(1672) D04685 HEPATITIS A-HEPATITIS B VACCINE'
                1673='(1673) D04689 CALAMINE-DIPHENHYDRAMINE TOPICAL' 1674='(1674) D04694 TENECTEPLASE'
                1675='(1675) D04695 COLESEVELAM' 1676='(1676) D04697 INSULIN ASPART'
                1677='(1677) D04698 ARGATROBAN' 1678='(1678) D04700 BALSALAZIDE'
                1679='(1679) D04702 DOCOSANOL TOPICAL' 1680='(1680) D04703 GLYBURIDE-METFORMIN'
                1681='(1681) D04704 EFLORNITHINE TOPICAL' 1682='(1682) D04705 FLUDEOXYGLUCOSE F18'
                1683='(1683) D04707 LEVOFLOXACIN OPHTHALMIC' 1684='(1684) D04708 ZOLEDRONIC ACID'
                1685='(1685) D04711 CANDESARTAN-HYDROCHLOROTHIAZIDE' 1686='(1686) D04716 LOPINAVIR'
                1687='(1687) D04717 LOPINAVIR-RITONAVIR' 1688='(1688) D04718 MIFEPRISTONE'
                1689='(1689) D04720 ARSENIC TRIOXIDE' 1690='(1690) D04722 DICLOFENAC TOPICAL'
                1691='(1691) D04723 CALCIUM CARBONATE/FAMOTIDINE/MG HYDROXIDE'
                1692='(1692) D04725 IRON SUCROSE' 1693='(1693) D04726 5-HYDROXYTRYPTOPHAN'
                1694='(1694) D04727 ABACAVIR/LAMIVUDINE/ZIDOVUDINE'
                1695='(1695) D04737 HYDROCHLOROTHIAZIDE-TELMISARTAN'
                1696='(1696) D04738 APAP/DOXYLAMINE/PSEUDOEPHEDRINE'
                1697='(1697) D04740 TACROLIMUS TOPICAL'
                1698='(1698) D04741 CARBETAPENTANE/GUAIFENESIN/PHENYLEPHRINE'
                1699='(1699) D04742 BENZOYL PEROXIDE-CLINDAMYCIN TOPICAL'
                1700='(1700) D04743 NATEGLINIDE' 1701='(1701) D04744 BIVALIRUDIN'
                1702='(1702) D04746 PEGINTERFERON ALFA-2B' 1703='(1703) D04747 ZIPRASIDONE'
                1704='(1704) D04748 CASPOFUNGIN' 1705='(1705) D04749 ESOMEPRAZOLE'
                1706='(1706) D04750 GALANTAMINE'
                1707='(1707) D04752 CARBINOXAMINE/HYDROCODONE/PSEUDOEPHEDRINE'
                1708='(1708) D04753 TRAVOPROST OPHTHALMIC' 1709='(1709) D04754 BIMATOPROST OPHTHALMIC'
                1710='(1710) D04755 VALGANCICLOVIR' 1711='(1711) D04756 ALEMTUZUMAB'
                1712='(1712) D04757 ALMOTRIPTAN' 1713='(1713) D04758 IMATINIB'
                1714='(1714) D04760 DROSPIRENONE-ETHINYL ESTRADIOL'
                1715='(1715) D04761 MINOCYCLINE TOPICAL'
                1716='(1716) D04762 METHSCOPOLAMINE-PSEUDOEPHEDRINE' 1717='(1717) D04763 NESIRITIDE'
                1718='(1718) D04764 CETIRIZINE-PSEUDOEPHEDRINE'
                1719='(1719) D04765 HYDROCORTISONE-LIDOCAINE TOPICAL'
                1720='(1720) D04766 ACETAMINOPHEN-TRAMADOL' 1721='(1721) D04767 CEFDITOREN'
                1722='(1722) D04770 CARBETAPENTANE-CHLORPHENIRAMINE'
                1723='(1723) D04771 DARBEPOETIN ALFA' 1724='(1724) D04772 ETONOGESTREL'
                1725='(1725) D04773 ETHINYL ESTRADIOL-ETONOGESTREL' 1726='(1726) D04774 TENOFOVIR'
                1727='(1727) D04775 ANAKINRA' 1728='(1728) D04776 FROVATRIPTAN'
                1729='(1729) D04777 DEXMETHYLPHENIDATE' 1730='(1730) D04778 VALDECOXIB'
                1731='(1731) D04779 ETHINYL ESTRADIOL-NORELGESTROMIN' 1732='(1732) D04782 BOSENTAN'
                1733='(1733) D04783 ERTAPENEM' 1734='(1734) D04784 PIMECROLIMUS TOPICAL'
                1735='(1735) D04785 DESLORATADINE' 1736='(1736) D04786 FONDAPARINUX'
                1737='(1737) D04787 LOVASTATIN-NIACIN' 1738='(1738) D04788 DUTASTERIDE'
                1739='(1739) D04789 NITISINONE' 1740='(1740) D04790 PEGFILGRASTIM'
                1741='(1741) D04791 FLUOCINOLONE/HYDROQUINONE/TRETINOIN TOPICAL'
                1742='(1742) D04792 ASA/CHLORPHENIRAMINE/DEXTROMETHORPHAN'
                1743='(1743) D04793 APAP/DEXTROMETHORPHAN/DOXYLAMINE/PE'
                1744='(1744) D04794 CARBINOXAMINE/METHSCOPOLAMINE/PSEUDOEPHEDRINE'
                1745='(1745) D04795 BUDESONIDE-FORMOTEROL' 1746='(1746) D04796 PERFLUTREN'
                1747='(1747) D04797 ALFUZOSIN' 1748='(1748) D04798 TEGASEROD'
                1749='(1749) D04799 FULVESTRANT' 1750='(1750) D04800 IFOSFAMIDE-MESNA'
                1751='(1751) D04801 OLMESARTAN' 1752='(1752) D04802 TREPROSTINIL'
                1753='(1753) D04803 VORICONAZOLE' 1754='(1754) D04805 RASBURICASE'
                1755='(1755) D04806 SODIUM OXYBATE' 1756='(1756) D04811 OXALIPLATIN'
                1757='(1757) D04812 ESCITALOPRAM' 1758='(1758) D04814 ADEFOVIR'
                1759='(1759) D04815 EPLERENONE' 1760='(1760) D04817 DEXCHLORPHENIRAMINE-PSEUDOEPHEDRINE'
                1761='(1761) D04818 DEXCHLORPHENIRAMINE/DEXTROMETHORPHAN/PSE'
                1762='(1762) D04819 BUPRENORPHINE-NALOXONE' 1763='(1763) D04820 METFORMIN-ROSIGLITAZONE'
                1764='(1764) D04821 PEGINTERFERON ALFA-2A' 1765='(1765) D04823 GLIPIZIDE-METFORMIN'
                1766='(1766) D04824 EZETIMIBE' 1767='(1767) D04825 ARIPIPRAZOLE'
                1768='(1768) D04826 NITAZOXANIDE' 1769='(1769) D04827 ATOMOXETINE'
                1770='(1770) D04828 TERIPARATIDE' 1771='(1771) D04829 TIOTROPIUM'
                1772='(1772) D04831 SMALLPOX VACCINE'
                1773='(1773) D04832 DIPHTHERIA/HEPB/PERTUSSIS,ACEL/POLIO/TETANUS'
                1774='(1774) D04834 CYTARABINE LIPOSOMAL' 1775='(1775) D04835 ADALIMUMAB'
                1776='(1776) D04836 CYCLOSPORINE OPHTHALMIC'
                1777='(1777) D04838 INSULIN ASPART PROTAMINE'
                1778='(1778) D04839 INSULIN ASPART-INSULIN ASPART PROTAMINE'
                1779='(1779) D04843 ALEFACEPT' 1780='(1780) D04844 CAMPHOR-MENTHOL TOPICAL'
                1781='(1781) D04845 IBRITUMOMAB' 1782='(1782) D04849 ELETRIPTAN'
                1783='(1783) D04850 CARBETAPENTANE/PHENYLEPHRINE/PYRILAMINE'
                1784='(1784) D04851 ROSUVASTATIN' 1785='(1785) D04852 BUPIVACAINE-FENTANYL'
                1786='(1786) D04853 ENFUVIRTIDE' 1787='(1787) D04854 PEGVISOMANT'
                1788='(1788) D04855 APREPITANT' 1789='(1789) D04856 BOTULISM ANTITOXIN'
                1790='(1790) D04857 GATIFLOXACIN OPHTHALMIC'
                1791='(1791) D04858 ANTHRAX VACCINE ADSORBED' 1792='(1792) D04859 GEMIFLOXACIN'
                1793='(1793) D04860 MOXIFLOXACIN OPHTHALMIC'
                1794='(1794) D04861 DIPHENHYDRAMINE-PHENYLEPHRINE'
                1795='(1795) D04862 BROMPHENIRAMINE/DM/GUAIFENESIN/PSE'
                1796='(1796) D04863 CHLORPHENIRAMINE/IBUPROFEN/PSEUDOEPHEDRINE'
                1797='(1797) D04864 CARBETAPENTANE-PSEUDOEPHEDRINE' 1798='(1798) D04866 AGALSIDASE BETA'
                1799='(1799) D04868 GEFITINIB' 1800='(1800) D04869 CHLORPHENIRAMINE/DIHYDROCODEINE/PSE'
                1801='(1801) D04870 DIHYDROCODEINE/GUAIFENESIN/PSEUDOEPHEDRINE'
                1802='(1802) D04871 BORTEZOMIB' 1803='(1803) D04875 BETAINE'
                1804='(1804) D04877 CARBIDOPA/ENTACAPONE/LEVODOPA'
                1805='(1805) D04878 HYDROCHLOROTHIAZIDE-OLMESARTAN'
                1806='(1806) D04879 PHENYLEPHRINE-POTASSIUM GUAIACOLSULFONATE'
                1807='(1807) D04880 BROMPHENIRAMINE/HYDROCODONE/PSEUDOEPHEDRINE'
                1808='(1808) D04881 OMALIZUMAB' 1809='(1809) D04882 ATAZANAVIR'
                1810='(1810) D04884 EMTRICITABINE' 1811='(1811) D04885 TOSITUMOMAB'
                1812='(1812) D04886 IODINE I 131 TOSITUMOMAB'
                1813='(1813) D04887 BUPIVACAINE-HYDROMORPHONE' 1814='(1814) D04888 PALONOSETRON'
                1815='(1815) D04890 CIPROFLOXACIN-DEXAMETHASONE OTIC'
                1816='(1816) D04892 INFLUENZA VIRUS VACCINE, LIVE, TRIVALENT'
                1817='(1817) D04893 VARDENAFIL' 1818='(1818) D04894 DAPTOMYCIN'
                1819='(1819) D04895 CARBETAPENTANE/DIPHENHYDRAMINE/PHENYLEPHRINE'
                1820='(1820) D04896 TADALAFIL' 1821='(1821) D04897 TETRAHYDROZOLINE-ZINC OPHTHALMIC'
                1822='(1822) D04898 EPINASTINE OPHTHALMIC' 1823='(1823) D04899 MEMANTINE'
                1824='(1824) D04900 SALICYLIC ACID-UREA TOPICAL' 1825='(1825) D04901 FOSAMPRENAVIR'
                1826='(1826) D04902 EFALIZUMAB'
                1827='(1827) D04905 BROMPHENIRAMINE/DEXTROMETHORPH/PHENYLEPHRINE'
                1828='(1828) D04913 LANSOPRAZOLE-NAPROXEN' 1829='(1829) D04914 ESTRADIOL-LEVONORGESTREL'
                1830='(1830) D04915 SERTACONAZOLE TOPICAL' 1831='(1831) D04916 CAPSICUM'
                1832='(1832) D04917 FLUOXETINE-OLANZAPINE'
                1833='(1833) D04920 PNEUMOCOCCAL 7-VALENT CONJUGATE VACCINE'
                1834='(1834) D04921 TETANUS-DIPHTH TOXOIDS (TD) ADULT/ADOL'
                1835='(1835) D04925 DIPHENHYDRAMINE/HYDROCODONE/PHENYLEPHRINE'
                1836='(1836) D04929 TROSPIUM' 1837='(1837) D04933 TELITHROMYCIN'
                1838='(1838) D04935 TINIDAZOLE' 1839='(1839) D04986 ACAMPROSATE'
                1840='(1840) D04991 APOMORPHINE' 1841='(1841) D05029 LUTROPIN ALFA'
                1842='(1842) D05044 BETAMETHASONE-CALCIPOTRIENE TOPICAL' 1843='(1843) D05047 PEMETREXED'
                1844='(1844) D05048 AMLODIPINE-ATORVASTATIN' 1845='(1845) D05101 CETUXIMAB'
                1846='(1846) D05117 GUAIFENESIN-POTASSIUM GUAIACOLSULFONATE'
                1847='(1847) D05119 DEXTROMETHORPHAN/GG/K GUAIACOLSULFONATE'
                1848='(1848) D05145 ARTEMETHER-LUMEFANTRINE'
                1849='(1849) D05150 CARBINOXAMINE/DEXTROMETHORPHAN/PHENYLEPHRINE'
                1850='(1850) D05214 BEVACIZUMAB' 1851='(1851) D05215 ZINC ACETATE TOPICAL'
                1852='(1852) D05216 DIPHENHYDRAMINE-ZINC ACETATE TOPICAL'
                1853='(1853) D05217 MYCOPHENOLIC ACID' 1854='(1854) D05218 CINACALCET'
                1855='(1855) D05232 ILOPROST' 1856='(1856) D05234 HYALURONAN'
                1857='(1857) D05238 BENZOYL PEROXIDE-UREA TOPICAL' 1858='(1858) D05262 MOMETASONE'
                1859='(1859) D05265 NEBIVOLOL' 1860='(1860) D05269 CADEXOMER IODINE TOPICAL'
                1861='(1861) D05278 INSULIN GLULISINE'
                1862='(1862) D05283 BRIMONIDINE-TIMOLOL OPHTHALMIC'
                1863='(1863) D05292 APAP/CAFFEINE/PHENYLTOLOXAMINE/SALICYLAMIDE'
                1864='(1864) D05293 AZACITIDINE' 1865='(1865) D05294 RIFAXIMIN'
                1866='(1866) D05303 CHLORPHENIRAMINE-CODEINE' 1867='(1867) D05332 PITCHER PLANT'
                1868='(1868) D05334 BROMPHENIRAMINE/CODEINE/PHENYLEPHRINE'
                1869='(1869) D05337 PNEUMOCOCCAL 23-POLYVALENT VACCINE'
                1870='(1870) D05338 DIPHTHERIA-TETANUS TOXOIDS (DT) PED'
                1871='(1871) D05339 HEPATITIS A PEDIATRIC VACCINE'
                1872='(1872) D05340 HEPATITIS A ADULT VACCINE'
                1873='(1873) D05341 HAEMOPHILUS B CONJUGATE (HBOC) VACCINE'
                1874='(1874) D05343 HAEMOPHILUS B CONJUGATE (PRP-T) VACCINE'
                1875='(1875) D05346 GADOBUTROL' 1876='(1876) D05348 EZETIMIBE-SIMVASTATIN'
                1877='(1877) D05349 BISACODYL-PEG 3350 WITH ELECTROLYTES'
                1878='(1878) D05350 POLYETHYLENE GLYCOL 3350'
                1879='(1879) D05351 APAP/PHENYLTOLOXAMINE/SALICYLAMIDE'
                1880='(1880) D05352 EMTRICITABINE-TENOFOVIR' 1881='(1881) D05354 ABACAVIR-LAMIVUDINE'
                1882='(1882) D05355 DULOXETINE' 1883='(1883) D05357 IBANDRONATE'
                1884='(1884) D05361 CARBETAPENTANE-GUAIFENESIN'
                1885='(1885) D05366 APAP/DEXTROMETHORPHAN/DOXYLAMINE'
                1886='(1886) D05383 APAP/CHLORPHENIRAMINE/DEXTROMETHORPHAN'
                1887='(1887) D05384 DEXTROMETHORPHAN/PHENIRAMINE/PHENYLEPHRINE'
                1888='(1888) D05389 BISACODYL-MAGNESIUM CITRATE' 1889='(1889) D05395 LANTHANUM CARBONATE'
                1890='(1890) D05411 CHLORPHENIRAMINE-METHSCOPOLAMINE' 1891='(1891) D05412 ERLOTINIB'
                1892='(1892) D05413 SOLIFENACIN' 1893='(1893) D05414 NATALIZUMAB'
                1894='(1894) D05415 IBUPROFEN-OXYCODONE'
                1895='(1895) D05416 CHLORDIAZEPOXIDE-METHSCOPOLAMINE' 1896='(1896) D05417 PALIFERMIN'
                1897='(1897) D05418 PEGAPTANIB OPHTHALMIC'
                1898='(1898) D05420 ALOH/DIPHENHYD/LIDOCAINE/MGOH/SIMETH TOPICAL'
                1899='(1899) D05421 ESZOPICLONE' 1900='(1900) D05422 DARIFENACIN'
                1901='(1901) D05423 CLOFARABINE' 1902='(1902) D05424 ZICONOTIDE'
                1903='(1903) D05425 LOTEPREDNOL-TOBRAMYCIN OPHTHALMIC'
                1904='(1904) D05426 BROMPHENIRAMINE/HYDROCODONE/PHENYLEPHRINE'
                1905='(1905) D05427 PACLITAXEL PROTEIN-BOUND' 1906='(1906) D05428 GADOBENATE DIMEGLUMINE'
                1907='(1907) D05432 MENINGOCOCCAL CONJUGATE VACCINE'
                1908='(1908) D05433 DIGESTIVE ENZYMES/HYOSCYAMINE/PHENYLTOLOXAMIN'
                1909='(1909) D05434 BROMPHENIRAMINE/CARBETAPENTANE/PHENYLEPHRINE'
                1910='(1910) D05436 INSULIN DETEMIR'
                1911='(1911) D05459 POVIDONE-TETRAHYDROZOLINE OPHTHALMIC'
                1912='(1912) D05461 SODIUM BENZOATE-SODIUM PHENYLACETATE'
                1913='(1913) D05465 CICLESONIDE' 1914='(1914) D05470 ASCORBIC ACID-IRON POLYSACCHARIDE'
                1915='(1915) D05471 ALPHA-D-GALACTOSIDASE'
                1916='(1916) D05473 DESLORATADINE-PSEUDOEPHEDRINE' 1917='(1917) D05487 MICAFUNGIN'
                1918='(1918) D05488 PRAMLINTIDE' 1919='(1919) D05508 PREGABALIN'
                1920='(1920) D05518 BROMFENAC OPHTHALMIC' 1921='(1921) D05525 ENTECAVIR'
                1922='(1922) D05526 ALENDRONATE-CHOLECALCIFEROL'
                1923='(1923) D05527 FLUOCINOLONE OPHTHALMIC' 1924='(1924) D05528 TRICHOPHYTON SKIN TEST'
                1925='(1925) D05529 EXENATIDE' 1926='(1926) D05530 DROSPIRENONE-ESTRADIOL'
                1927='(1927) D05535 HEME IRON POLYPEPTIDE'
                1928='(1928) D05536 APAP/GUAIFENESIN/PSEUDOEPHEDRINE' 1929='(1929) D05537 TIGECYCLINE'
                1930='(1930) D05538 TIPRANAVIR'
                1931='(1931) D05539 DEXCHLORPHENIRAMINE/METHSCOPOLAMINE/PSE'
                1932='(1932) D05540 HYDRALAZINE-ISOSORBIDE DINITRATE'
                1933='(1933) D05543 DAPSONE TOPICAL' 1934='(1934) D05544 APAP/GUAIFENESIN/PHENYLEPHRINE'
                1935='(1935) D05578 RAMELTEON' 1936='(1936) D05583 APAP/DEXTROMETHORPHAN/PHENYLEPHRINE'
                1937='(1937) D05612 RASAGILINE' 1938='(1938) D05626 EVEROLIMUS'
                1939='(1939) D05630 CALCIUM CARBONATE-RISEDRONATE'
                1940='(1940) D05632 BISACODYL/SODIUM BIPHOSPHATE/SODIUM PHOSPHATE'
                1941='(1941) D05633 NEPAFENAC OPHTHALMIC' 1942='(1942) D05635 METFORMIN-PIOGLITAZONE'
                1943='(1943) D05636 MECASERMIN' 1944='(1944) D05637 LACTOBACILLUS RHAMNOSUS GG'
                1945='(1945) D05644 APAP/CAFFEINE/ISOMETHEPTENE MUCATE'
                1946='(1946) D05645 MEASLES/MUMPS/RUBELLA/VARICELLA VIRUS VACCINE'
                1947='(1947) D05646 SACCHAROMYCES BOULARDII LYO'
                1948='(1948) D05647 FERRIC SUBSULFATE TOPICAL' 1949='(1949) D05649 CEFTRIAXONE-LIDOCAINE'
                1950='(1950) D05651 SODIUM HYALURONATE TOPICAL'
                1951='(1951) D05654 APAP/DIPHENHYDRAMINE/PHENYLEPHRINE' 1952='(1952) D05659 DEFERASIROX'
                1953='(1953) D05661 ACETAMINOPHEN-GUAIFENESIN'
                1954='(1954) D05674 GLIMEPIRIDE-ROSIGLITAZONE' 1955='(1955) D05691 SORAFENIB'
                1956='(1956) D05692 MECASERMIN RINFABATE' 1957='(1957) D05694 ABATACEPT'
                1958='(1958) D05696 LENALIDOMIDE' 1959='(1959) D05702 METHYLSULFONYLMETHANE'
                1960='(1960) D05703 CHONDROITIN/GLUCOSAMINE/METHYLSULFONYLMETHANE'
                1961='(1961) D05704 IMMUNE GLOBULIN SUBCUTANEOUS' 1962='(1962) D05717 SUNITINIB'
                1963='(1963) D05719 RANOLAZINE' 1964='(1964) D05722 GALLIUM CITRATE GA-67'
                1965='(1965) D05736 LUBIPROSTONE' 1966='(1966) D05753 MICONAZOLE-ZINC OXIDE TOPICAL'
                1967='(1967) D05757 APAP/CHLORPHENIRAMINE/DEXTROMETHORPHAN/PE'
                1968='(1968) D05765 INSULIN INHALATION, RAPID ACTING'
                1969='(1969) D05768 APAP/PHENIRAMINE/PHENYLEPHRINE'
                1970='(1970) D05770 OMEPRAZOLE-SODIUM BICARBONATE' 1971='(1971) D05773 L-METHYLFOLATE'
                1972='(1972) D05774 AMMONIUM LACTATE-UREA TOPICAL' 1973='(1973) D05776 IODINE'
                1974='(1974) D05777 IODINE-POTASSIUM IODIDE'
                1975='(1975) D05778 APAP/DEXTROMETHORPHAN/GUAIFENESIN/PE'
                1976='(1976) D05781 TETANUS/DIPHTH/PERTUSS (TDAP) ADULT/ADOL'
                1977='(1977) D05782 DIPHTHERIA/TETANUS/PERTUSSIS (DTAP) PED'
                1978='(1978) D05785 RABIES VACCINE, HUMAN DIPLOID CELL'
                1979='(1979) D05786 RABIES VACCINE, PURIFIED CHICK EMBRYO CELL'
                1980='(1980) D05788 DECITABINE'
                1981='(1981) D05806 FERROUS FUMARATE/FA/IRON POLYSACCHARIDE'
                1982='(1982) D05807 VARENICLINE' 1983='(1983) D05813 ZOSTER VACCINE LIVE'
                1984='(1984) D05814 DEXTROMETHORPHAN-PHENYLEPHRINE' 1985='(1985) D05815 FLUORESCEIN'
                1986='(1986) D05817 HUMAN PAPILLOMAVIRUS VACCINE'
                1987='(1987) D05819 DIPHENHYDRAMINE-IBUPROFEN' 1988='(1988) D05825 DARUNAVIR'
                1989='(1989) D05830 FERUMOXSIL' 1990='(1990) D05831 DASATINIB'
                1991='(1991) D05835 RANIBIZUMAB OPHTHALMIC'
                1992='(1992) D05847 EFAVIRENZ/EMTRICITABINE/TENOFOVIR' 1993='(1993) D05848 ROTIGOTINE'
                1994='(1994) D05851 LEVOCETIRIZINE' 1995='(1995) D05853 POSACONAZOLE'
                1996='(1996) D05855 IDURSULFASE' 1997='(1997) D05856 GLIMEPIRIDE-PIOGLITAZONE'
                1998='(1998) D05864 COMPLEMENT C1 ESTERASE INHIBITOR' 1999='(1999) D05866 GUAR GUM'
                2000='(2000) D05874 ANTIHEMOPHILIC FACTOR-VON WILLEBRAND FACTOR'
                2001='(2001) D05877 DEXTROMETHORPHAN/DIPHENHYDRAMINE/PE'
                2002='(2002) D05878 BENZALKONIUM CHLORIDE-BENZOCAINE TOPICAL'
                2003='(2003) D05879 PANITUMUMAB' 2004='(2004) D05891 VORINOSTAT'
                2005='(2005) D05892 DEXCHLORPHENIRAMINE/DEXTROMETHO/PE/PYRILAMINE'
                2006='(2006) D05893 ARFORMOTEROL' 2007='(2007) D05894 CALAMINE-ZINC OXIDE TOPICAL'
                2008='(2008) D05896 SITAGLIPTIN'
                2009='(2009) D05897 BENZOYL PEROXIDE-SALICYLIC ACID TOPICAL'
                2010='(2010) D05899 CICLESONIDE NASAL' 2011='(2011) D05963 COAGULATION FACTOR IX'
                2012='(2012) D05964 ALOE VERA' 2013='(2013) D05973 CLINDAMYCIN-TRETINOIN TOPICAL'
                2014='(2014) D05974 ANTIHEMOPHILIC FACTOR' 2015='(2015) D06008 BENZYL ALCOHOL TOPICAL'
                2016='(2016) D06032 FLUOCINOLONE OTIC'
                2017='(2017) D06058 DEXBROMPHENIRAMINE/HYDROCODONE/PHENYLEPHRINE'
                2018='(2018) D06080 APAP/CAFFEINE/MAGNESIUM SALICYLATE' 2019='(2019) D06214 COLLAGEN'
                2020='(2020) D06227 IOXILAN' 2021='(2021) D06272 DIENOGEST-ESTRADIOL'
                2022='(2022) D06297 PALIPERIDONE' 2023='(2023) D06370 TURMERIC'
                2024='(2024) D06392 WHEAT DEXTRIN' 2025='(2025) D06507 CINNAMON'
                2026='(2026) D06635 MILNACIPRAN'
                2027='(2027) D06648 ATROPINE/CPM/HYOSCYAMINE/PSE/SCOPOLAMINE'
                2028='(2028) D06655 ALPHA-LIPOIC ACID' 2029='(2029) D06662 AMLODIPINE-VALSARTAN'
                2030='(2030) D06663 LISDEXAMFETAMINE' 2031='(2031) D06665 ALISKIREN'
                2032='(2032) D06672 LAPATINIB' 2033='(2033) D06673 ECULIZUMAB'
                2034='(2034) D06720 METFORMIN-SITAGLIPTIN' 2035='(2035) D06831 RETAPAMULIN TOPICAL'
                2036='(2036) D06833 ACETAMINOPHEN-ASPIRIN'
                2037='(2037) D06834 BISMUTH SUBCITRATE POTASSIUM/METRONIDAZO/TCN'
                2038='(2038) D06835 DEXCHLORPHENIRAMINE/METHSCOPOLAMINE/PE'
                2039='(2039) D06836 TEMSIROLIMUS' 2040='(2040) D06841 AMBRISENTAN'
                2041='(2041) D06842 ARMODAFINIL' 2042='(2042) D06848 LUTEIN'
                2043='(2043) D06851 AZITHROMYCIN OPHTHALMIC' 2044='(2044) D06852 MARAVIROC'
                2045='(2045) D06857 ACETIC/ANTIPYRINE/BENZOCAINE/POLYCOS OTIC'
                2046='(2046) D06862 HELIUM' 2047='(2047) D06864 HELIUM-OXYGEN'
                2048='(2048) D06867 BIOTIN' 2049='(2049) D06868 MENTHOL-ZINC OXIDE TOPICAL'
                2050='(2050) D06872 APAP/CHLORPHENIRAMINE/PE/PHENYLTOLOXAMINE'
                2051='(2051) D06891 CHLOROPHYLLIN COPPER COM/PAPAIN/UREA TOPICAL'
                2052='(2052) D06900 COLLAGEN TOPICAL' 2053='(2053) D06905 AMLODIPINE-OLMESARTAN'
                2054='(2054) D06976 ASA/CHLORPHENIRAMINE/PHENYLEPHRINE' 2055='(2055) D07048 RALTEGRAVIR'
                2056='(2056) D07049 DORIPENEM' 2057='(2057) D07051 IXABEPILONE'
                2058='(2058) D07055 CHLORPHENIRAMINE/GUAIFENESIN/METHSCOPOLAMI/PE'
                2059='(2059) D07057 NILOTINIB'
                2060='(2060) D07058 SULFACETAMIDE SODIUM/SULFUR/UREA TOPICAL'
                2061='(2061) D07059 CITRIC ACID-POTASSIUM BICARBONATE'
                2062='(2062) D07063 BROMPHENIRAMINE-DIPHENHYDRAMINE'
                2063='(2063) D07065 BENZYL ALCOHOL-ZINC ACETATE TOPICAL' 2064='(2064) D07068 SAPROPTERIN'
                2065='(2065) D07069 RUFINAMIDE'
                2066='(2066) D07075 PERMETHRIN/PIPERONYL BUTOXIDE/PYRETHR TOPICAL'
                2067='(2067) D07076 ETRAVIRINE' 2068='(2068) D07077 ALISKIREN-HYDROCHLOROTHIAZIDE'
                2069='(2069) D07110 NIACIN-SIMVASTATIN' 2070='(2070) D07113 DESVENLAFAXINE'
                2071='(2071) D07121 BENDAMUSTINE' 2072='(2072) D07130 NAPROXEN-SUMATRIPTAN'
                2073='(2073) D07131 REGADENOSON' 2074='(2074) D07132 OLOPATADINE NASAL'
                2075='(2075) D07134 CERTOLIZUMAB' 2076='(2076) D07135 METHYLNALTREXONE'
                2077='(2077) D07137 DABIGATRAN' 2078='(2078) D07162 FESOTERODINE'
                2079='(2079) D07292 METFORMIN-REPAGLINIDE' 2080='(2080) D07298 DIFLUPREDNATE OPHTHALMIC'
                2081='(2081) D07300 CHLOPHEDIANOL/DEXCHLORPHENIRAMINE/PSE'
                2082='(2082) D07302 CHLOPHEDIANOL/GUAIFENESIN/PSEUDOEPHEDRINE'
                2083='(2083) D07306 BENZOCAINE-MENTHOL TOPICAL' 2084='(2084) D07309 GENISTEIN'
                2085='(2085) D07312 CLEVIDIPINE' 2086='(2086) D07315 GLUTAMINE'
                2087='(2087) D07320 ROMIPLOSTIM' 2088='(2088) D07347 BIFIDOBACTERIUM INFANTIS'
                2089='(2089) D07349 LACOSAMIDE'
                2090='(2090) D07351 CARBETAPENTANE/PSEUDOEPHEDRINE/PYRILAMINE'
                2091='(2091) D07354 SILODOSIN' 2092='(2092) D07356 RIVAROXABAN'
                2093='(2093) D07357 ELTROMBOPAG' 2094='(2094) D07371 FENOFIBRIC ACID'
                2095='(2095) D07374 BIMATOPROST TOPICAL OPHTHALMIC'
                2096='(2096) D07382 ADAPALENE-BENZOYL PEROXIDE TOPICAL'
                2097='(2097) D07385 HEPARIN FLUSH'
                2098='(2098) D07387 HYDROCORTISONE/SALICYLIC ACID/SULFUR TOPICAL'
                2099='(2099) D07395 DEXLANSOPRAZOLE' 2100='(2100) D07396 USTEKINUMAB'
                2101='(2101) D07397 FEBUXOSTAT'
                2102='(2102) D07405 CARBETAPENTANE/PE/POTASSIUM GUAIACOLSULFONATE'
                2103='(2103) D07409 PRASUGREL' 2104='(2104) D07411 DEGARELIX'
                2105='(2105) D07418 BENZOCAINE-RESORCINOL TOPICAL' 2106='(2106) D07435 GOLIMUMAB'
                2107='(2107) D07440 AMLODIPINE/HYDROCHLOROTHIAZIDE/VALSARTAN'
                2108='(2108) D07441 ILOPERIDONE' 2109='(2109) D07447 TOLVAPTAN'
                2110='(2110) D07453 TAPENTADOL' 2111='(2111) D07458 DRONEDARONE'
                2112='(2112) D07459 FERUMOXYTOL'
                2113='(2113) D07464 INFLUENZA VIRUS VACCINE, H1N1, INACTIVATED'
                2114='(2114) D07466 LIRAGLUTIDE' 2115='(2115) D07467 SAXAGLIPTIN'
                2116='(2116) D07472 MORPHINE-NALTREXONE' 2117='(2117) D07473 ASENAPINE'
                2118='(2118) D07481 POLY-L-LACTIC ACID' 2119='(2119) D07482 BEPOTASTINE OPHTHALMIC'
                2120='(2120) D07483 TELAVANCIN' 2121='(2121) D07485 INFLUENZA VIRUS VACCINE, H1N1, LIVE'
                2122='(2122) D07486 ALISKIREN-VALSARTAN'
                2123='(2123) D07491 DIPHENHYDRAMINE/LIDOCAINE/NYSTATIN TOPICAL'
                2124='(2124) D07492 PRALATREXATE' 2125='(2125) D07496 TOCILIZUMAB'
                2126='(2126) D07498 AMLODIPINE-TELMISARTAN' 2127='(2127) D07499 PAZOPANIB'
                2128='(2128) D07505 COPPER' 2129='(2129) D07509 OFATUMUMAB'
                2130='(2130) D07518 SILVER TOPICAL' 2131='(2131) D07546 DALFAMPRIDINE'
                2132='(2132) D07550 DEXTROMETHORPHAN-DOXYLAMINE' 2133='(2133) D07565 IPILIMUMAB'
                2134='(2134) D07586 PNEUMOCOCCAL 13-VALENT CONJUGATE VACCINE'
                2135='(2135) D07589 BIOFLAVONOIDS-ZINC GLYCINATE'
                2136='(2136) D07631 ESOMEPRAZOLE-NAPROXEN' 2137='(2137) D07634 DUTASTERIDE-TAMSULOSIN'
                2138='(2138) D07637 PITAVASTATIN' 2139='(2139) D07638 SIPULEUCEL-T'
                2140='(2140) D07640 DENOSUMAB' 2141='(2141) D07642 ANTI-THYMOCYTE GLOBULIN (RABBIT)'
                2142='(2142) D07644 HEPATITIS B ADULT VACCINE' 2143='(2143) D07645 ONABOTULINUMTOXINA'
                2144='(2144) D07646 ABOBOTULINUMTOXINA' 2145='(2145) D07647 RACEPINEPHRINE'
                2146='(2146) D07658 CABAZITAXEL' 2147='(2147) D07659 CAFFEINE-MAGNESIUM SALICYLATE'
                2148='(2148) D07660 FORMOTEROL-MOMETASONE'
                2149='(2149) D07668 AMLODIPINE/HYDROCHLOROTHIAZIDE/OLMESARTAN'
                2150='(2150) D07670 ALCAFTADINE OPHTHALMIC' 2151='(2151) D07684 ROFLUMILAST'
                2152='(2152) D07688 PEGLOTICASE' 2153='(2153) D07691 MAGNESIUM/POTASSIUM/SODIUM SULFATES'
                2154='(2154) D07692 FINGOLIMOD'
                2155='(2155) D07697 DROSPIRENONE/ETHINYL ESTRADIOL/LEVOMEFOLATE'
                2156='(2156) D07705 LURASIDONE' 2157='(2157) D07706 CEFTAROLINE'
                2158='(2158) D07709 METFORMIN-SAXAGLIPTIN' 2159='(2159) D07715 TESAMORELIN'
                2160='(2160) D07716 ERIBULIN' 2161='(2161) D07727 PENICILLIN G BENZATHINE'
                2162='(2162) D07729 PENICILLIN G POTASSIUM' 2163='(2163) D07730 PENICILLIN V POTASSIUM'
                2164='(2164) D07738 BROMPHENIRAMINE/CHLOPHEDIANOL/PSE' 2165='(2165) D07740 VILAZODONE'
                2166='(2166) D07754 AZILSARTAN' 2167='(2167) D07756 BELIMUMAB'
                2168='(2168) D07757 LIDOCAINE-SODIUM BICARBONATE' 2169='(2169) D07761 VANDETANIB'
                2170='(2170) D07766 ABIRATERONE' 2171='(2171) D07767 LINAGLIPTIN'
                2172='(2172) D07774 BOCEPREVIR' 2173='(2173) D07777 TELAPREVIR'
                2174='(2174) D07796 EMTRICITABINE/RILPIVIRINE/TENOFOVIR' 2175='(2175) D07798 VEMURAFENIB'
                2176='(2176) I00031 XYLENE' 2177='(2177) I00035 TURPENTINE'
                2178='(2178) I00039 TRICHLOROETHANE' 2179='(2179) I00040 TOLUENE'
                2180='(2180) I00081 NAPHTHALENE' 2181='(2181) I00084 METHYLENE CHLORIDE'
                2182='(2182) I00088 METHANOL' 2183='(2183) I00102 FORMALDEHYDE'
                2184='(2184) I00106 ETHYLENE GLYCOL' 2185='(2185) I00108 ETHYL ETHER'
                2186='(2186) I00162 ACETONE' 2187='(2187) I00173 CYANOACRYLATE'
                2188='(2188) I00176 ISOBUTYL NITRITE' 2189='(2189) I00190 AEROSOL SPRAY-NOS'
                2190='(2190) I00196 BUTANE' 2191='(2191) I00198 TRICHLOROFLUOROMETHANE'
                2192='(2192) I00200 METHANE' 2193='(2193) I00201 PETROLEUM HYDROCARBONS'
                2194='(2194) I00203 CARBON TETRACHLORIDE' 2195='(2195) I00207 BUTYL ALCOHOL'
                2196='(2196) I00209 ALPHA TERPINEOL' 2197='(2197) I00210 FREON'
                2198='(2198) I00211 DICHLOROBENZENE' 2199='(2199) I00212 PROPOXUR'
                2200='(2200) I00216 PROPANE' 2201='(2201) I00219 PHENOLIC DISINFECTANTS'
                2202='(2202) I00221 MINERAL SEAL OIL' 2203='(2203) I00238 FLUORINE'
                2204='(2204) I00240 HYDROCARBON' 2205='(2205) I00247 CHLORINATED HYDROCARBONS'
                2206='(2206) I00251 CRESOL' 2207='(2207) I00256 BUTYL ACETATE'
                2208='(2208) I00343 CLEANER/UNKNOWN COMPOSITION'
                2209='(2209) I00345 COSMETIC/UNKNOWN COMPOSITION'
                2210='(2210) I00348 PESTICIDE/UNKNOWN COMPOSITION'
                2211='(2211) I00349 VOLATILE/UNKNOWN COMPONENTS'
                2212='(2212) I00350 PAINT/UNKNOWN COMPOSITION'
                2213='(2213) I00543 TRICHLOROETHANE/TRICHLOROETHYLENE'
                2214='(2214) I00556 PETROLEUM HYDROCARBONS/TRICHLOROETHANE'
                2215='(2215) I01283 ETHANOL-NP' 2216='(2216) I01328 TRICHLOROMETHANE'
                2217='(2217) I01336 FLUORINATED HYDROCARBONS' 2218='(2218) I01337 ISOBUTANE'
                2219='(2219) I01400 CHLORODIFLUOROMETHANE' 2220='(2220) I01425 ETHYL ACETATE'
                2221='(2221) J00001 LYSERGIC ACID DIETHYLAMIDE'
                2222='(2222) J00002 METHYLENEDIOXYMETHAMPHETAMINE' 2223='(2223) J00004 FLUNITRAZEPAM'
                2224='(2224) J00020 BROMELAIN' 2225='(2225) J00023 NOMIFENSINE MALEATE'
                2226='(2226) J00027 MECLOZINE HCL' 2227='(2227) J00028 NITRAZEPAM'
                2228='(2228) J00030 ZOMEPIRAC' 2229='(2229) J00032 XYLAZINE'
                2230='(2230) J00033 VITAMIN K' 2231='(2231) J00036 L-TRYPTOPHAN'
                2232='(2232) J00049 SULFORIDAZINE' 2233='(2233) J00050 SULFADINE'
                2234='(2234) J00053 SALINE' 2235='(2235) J00061 PRAZEPAM'
                2236='(2236) J00064 PHENMETRAZINE HCL' 2237='(2237) J00066 PHENACETIN'
                2238='(2238) J00089 METHACYCLINE' 2239='(2239) J00090 MERBROMIN'
                2240='(2240) J00092 LUTREXIN' 2241='(2241) J00093 LORMETAZEPAM'
                2242='(2242) J00094 LACTOSE' 2243='(2243) J00095 KETOTIFEN FUMARATE'
                2244='(2244) J00096 INFANT FORMULA' 2245='(2245) J00097 HYDROXY-N-METHYLMORPHINAN'
                2246='(2246) J00104 FENPROPOREX' 2247='(2247) J00110 ERYTHRITYL TETRANITRATE'
                2248='(2248) J00114 DYPYRONE' 2249='(2249) J00120 DIHYDROMORPHINONE'
                2250='(2250) J00122 ALDOSTERONE' 2251='(2251) J00129 CHLOROPYRAMINE'
                2252='(2252) J00148 CARBAMATE' 2253='(2253) J00150 BROMAZEPAM'
                2254='(2254) J00164 ACEPROMAZINE' 2255='(2255) J00168 METHCATHINONE'
                2256='(2256) J00171 CATHINONE' 2257='(2257) J00174 METHYLENEDIOXYAMPHETAMINE'
                2258='(2258) J00177 METHAQUALONE' 2259='(2259) J00178 MESCALINE'
                2260='(2260) J00179 PSILOCYBIN' 2261='(2261) J00180 MORNING GLORY SEEDS'
                2262='(2262) J00192 DATURA SAUVEOLENS' 2263='(2263) J00215 GAMMA BUTYROLACTONE'
                2264='(2264) J00248 EUCALYPTUS OIL' 2265='(2265) J00249 PEPPER'
                2266='(2266) J00263 DIMETHOXYMETHAMPHETAMINE' 2267='(2267) J00264 DATURA STRAMONIUM'
                2268='(2268) J00265 CANTHARIDINE' 2269='(2269) J00278 ISOPROPAMIDE IODIDE'
                2270='(2270) J00280 ALLOBARBITAL' 2271='(2271) J00290 CLOBENZOREX'
                2272='(2272) J00293 AMBROXOL' 2273='(2273) J00294 TETRAMYCIN'
                2274='(2274) J00295 RHODOMYCIN' 2275='(2275) J00331 ZOPICLONE'
                2276='(2276) J00336 MYCADRINE' 2277='(2277) J00337 POTASSIUM'
                2278='(2278) J00339 PYRETHRUM' 2279='(2279) J00356 ARECOLINE'
                2280='(2280) J00358 PHOSPHATIDYLETHANOLAMINE' 2281='(2281) J00360 CHLORPHENTERMINE'
                2282='(2282) J00362 BARBITURIC ACID' 2283='(2283) J00364 BARBITAL'
                2284='(2284) J00369 BROMO-DIMETHOXYPHENETHYLAMINE'
                2285='(2285) J00500 MARIJUANA/METHAMPHETAMINE'
                2286='(2286) J00501 FORMALDEHYDE/MARIJUANA' 2287='(2287) J00502 COCAINE/METHAMPHETAMINE'
                2288='(2288) J00504 COCAINE/MARIJUANA' 2289='(2289) J00507 COCAINE/HEROIN'
                2290='(2290) J00510 MARIJUANA/PHENCYCLIDINE' 2291='(2291) J00511 COCAINE/PHENCYCLIDINE'
                2292='(2292) J00512 LYSERGIC ACID DIETHYLAMIDE/METHAMPHETAMINE'
                2293='(2293) J00513 LYSERGIC ACID DIETHYLAMIDE/PHENCYCLIDINE'
                2294='(2294) J00514 HEROIN/MARIJUANA'
                2295='(2295) J00531 AMOBARBITAL/DEXTROAMPHETAMINE/THYROID DESICCATED'
                2296='(2296) J00533 PENTOBARBITAL/PHENOBARBITAL' 2297='(2297) J00539 CAFFEINE/EPHEDRINE'
                2298='(2298) J00540 ACETAMINOPHEN/CHLORZOXAZONE'
                2299='(2299) J00558 ASPIRIN/CAFFEINE/CODEINE/PHENACETIN'
                2300='(2300) J00566 APAP/CHLORPHENIRAMINE/PHENYLEPHRINE/DEXTROMETHORPHAN/GUAIFENESIN'
                2301='(2301) J00568 COCAINE/ETHANOL' 2302='(2302) J00572 SALICYLAMIDE/SCOPOLAMINE'
                2303='(2303) J00577 CODEINE/TERPIN HYDRATE'
                2304='(2304) J00591 ACETAMINOPHEN/CAFFEINE/CODEINE' 2305='(2305) J00593 AMYLASE/PROTEASE'
                2306='(2306) J00594 ASPIRIN/CAFFEINE/CODEINE' 2307='(2307) J01003 ANTIFUNGALS-NOS'
                2308='(2308) J01004 ANTIMALARIAL AGENTS-NOS'
                2309='(2309) J01005 ANTITUBERCULOSIS AGENTS-NOS'
                2310='(2310) J01006 ANTIVIRAL AGENTS-NOS' 2311='(2311) J01008 CEPHALOSPORINS-NOS'
                2312='(2312) J01010 MACROLIDES-NOS' 2313='(2313) J01011 ANTIBIOTICS-NOS'
                2314='(2314) J01012 PENICILLINS-NOS' 2315='(2315) J01013 QUINOLONES-NOS'
                2316='(2316) J01014 SULFONAMIDES-NOS' 2317='(2317) J01015 TETRACYCLINES-NOS'
                2318='(2318) J01016 URINARY ANTI-INFECTIVES-NOS' 2319='(2319) J01017 AMINOGLYCOSIDES-NOS'
                2320='(2320) J01018 ANTIHYPERLIPIDEMIC AGENTS-NOS'
                2321='(2321) J01026 RADIOPHARMACEUTICALS-NOS'
                2322='(2322) J01028 ANTITOXINS AND ANTIVENINS-NOS'
                2323='(2323) J01029 BACTERIAL VACCINES-NOS'
                2324='(2324) J01030 COLONY STIMULATING FACTORS-NOS'
                2325='(2325) J01031 IMMUNE GLOBULINS-NOS'
                2326='(2326) J01033 RECOMBINANT HUMAN ERYTHROPOIETINS-NOS'
                2327='(2327) J01034 TOXOIDS-NOS' 2328='(2328) J01035 VIRAL VACCINES-NOS'
                2329='(2329) J01037 CARDIOVASCULAR AGENTS-NOS'
                2330='(2330) J01039 ANGIOTENSIN CONVERTING ENZYME INHIBITORS-NOS'
                2331='(2331) J01040 ANTIADRENERGIC AGENTS, PERIPHERALLY ACTING-NOS'
                2332='(2332) J01042 ANTIANGINAL AGENTS-NOS'
                2333='(2333) J01043 ANTIARRHYTHMIC AGENTS-NOS'
                2334='(2334) J01044 BETA-ADRENERGIC BLOCKING AGENTS-NOS'
                2335='(2335) J01045 CALCIUM CHANNEL BLOCKING AGENTS-NOS'
                2336='(2336) J01047 INOTROPIC AGENTS-NOS'
                2337='(2337) J01049 PERIPHERAL VASODILATORS-NOS' 2338='(2338) J01050 VASODILATORS-NOS'
                2339='(2339) J01051 VASOPRESSORS-NOS'
                2340='(2340) J01052 ANTIHYPERTENSIVE COMBINATIONS-NOS'
                2341='(2341) J01053 ANGIOTENSIN II INHIBITORS-NOS' 2342='(2342) J01056 ANALGESICS-NOS'
                2343='(2343) J01057 NARCOTIC ANALGESICS-NOS'
                2344='(2344) J01058 NONSTEROIDAL ANTI-INFLAMMATORY AGENTS-NOS'
                2345='(2345) J01059 SALICYLATES-NOS' 2346='(2346) J01061 ANTICONVULSANTS-NOS'
                2347='(2347) J01063 ANTIPARKINSON AGENTS-NOS' 2348='(2348) J01065 BARBITURATES-NOS'
                2349='(2349) J01066 BENZODIAZEPINES-NOS'
                2350='(2350) J01067 ANXIOLYTICS, SEDATIVES AND HYPNOTICS-NOS'
                2351='(2351) J01068 CNS STIMULANTS-NOS' 2352='(2352) J01069 GENERAL ANESTHETICS-NOS'
                2353='(2353) J01073 ANTIPSYCHOTICS-NOS' 2354='(2354) J01077 ANTICOAGULANTS-NOS'
                2355='(2355) J01078 ANTIPLATELET AGENTS-NOS' 2356='(2356) J01081 THROMBOLYTICS-NOS'
                2357='(2357) J01082 GASTROINTESTINAL AGENTS-NOS' 2358='(2358) J01083 ANTACIDS-NOS'
                2359='(2359) J01084 ANTICHOLINERGICS/ANTISPASMODICS-NOS'
                2360='(2360) J01085 ANTIDIARRHEALS-NOS' 2361='(2361) J01086 DIGESTIVE ENZYMES-NOS'
                2362='(2362) J01088 GI STIMULANTS-NOS' 2363='(2363) J01089 H2 ANTAGONISTS-NOS'
                2364='(2364) J01090 LAXATIVES-NOS' 2365='(2365) J01092 HORMONES-NOS'
                2366='(2366) J01093 ADRENAL CORTICAL STEROIDS-NOS'
                2367='(2367) J01094 ANTIDIABETIC AGENTS-NOS' 2368='(2368) J01096 SEX HORMONES-NOS'
                2369='(2369) J01098 THYROID DRUGS-NOS' 2370='(2370) J01099 IMMUNOSUPPRESSIVE AGENTS-NOS'
                2371='(2371) J01101 ANTIDOTES-NOS' 2372='(2372) J01102 CHELATING AGENTS-NOS'
                2373='(2373) J01103 CHOLINERGIC MUSCLE STIMULANTS-NOS'
                2374='(2374) J01104 LOCAL INJECTABLE ANESTHETICS-NOS' 2375='(2375) J01106 PSORALENS-NOS'
                2376='(2376) J01107 RADIOCONTRAST AGENTS-NOS'
                2377='(2377) J01108 GENITOURINARY TRACT AGENTS-NOS'
                2378='(2378) J01111 IRON PRODUCTS-NOS' 2379='(2379) J01112 MINERALS AND ELECTROLYTES-NOS'
                2380='(2380) J01113 ORAL NUTRITIONAL SUPPLEMENTS-NOS'
                2381='(2381) J01115 VITAMIN AND MINERAL COMBINATIONS-NOS'
                2382='(2382) J01116 INTRAVENOUS NUTRITIONAL PRODUCTS-NOS'
                2383='(2383) J01118 ANTIHISTAMINES-NOS' 2384='(2384) J01119 ANTITUSSIVES-NOS'
                2385='(2385) J01120 BRONCHODILATORS-NOS' 2386='(2386) J01122 DECONGESTANTS-NOS'
                2387='(2387) J01123 EXPECTORANTS-NOS' 2388='(2388) J01124 RESPIRATORY AGENTS-NOS'
                2389='(2389) J01125 RESPIRATORY INHALANT PRODUCTS-NOS'
                2390='(2390) J01126 ANTIASTHMATIC COMBINATIONS-NOS'
                2391='(2391) J01127 UPPER RESPIRATORY COMBINATIONS-NOS'
                2392='(2392) J01129 ANORECTAL PREPARATIONS-NOS'
                2393='(2393) J01130 ANTISEPTIC AND GERMICIDES-NOS'
                2394='(2394) J01131 DERMATOLOGICAL AGENTS-NOS'
                2395='(2395) J01134 TOPICAL ANESTHETICS-NOS'
                2396='(2396) J01139 MOUTH AND THROAT PRODUCTS-NOS'
                2397='(2397) J01143 STERILE IRRIGATING SOLUTIONS-NOS'
                2398='(2398) J01145 PLASMA EXPANDERS-NOS'
                2399='(2399) J01165 HMG-COA REDUCTASE INHIBITORS-NOS'
                2400='(2400) J01170 MUSCLE RELAXANTS-NOS'
                2401='(2401) J01174 ANDROGENS AND ANABOLIC STEROIDS-NOS'
                2402='(2402) J01180 NARCOTIC ANALGESIC COMBINATIONS-NOS'
                2403='(2403) J01181 ANTIRHEUMATICS-NOS' 2404='(2404) J01182 ANTIMIGRAINE AGENTS-NOS'
                2405='(2405) J01183 ANTIGOUT AGENTS-NOS' 2406='(2406) J01206 BISPHOSPHONATES-NOS'
                2407='(2407) J01208 NUTRACEUTICAL PRODUCTS-NOS' 2408='(2408) J01209 HERBAL PRODUCTS-NOS'
                2409='(2409) J01229 FIBRIC ACID DERIVATIVES-NOS'
                2410='(2410) J01231 LEUKOTRIENE MODIFIERS-NOS'
                2411='(2411) J01235 NASAL PREPARATIONS-NOS' 2412='(2412) J01237 ANTIDEPRESSANTS-NOS'
                2413='(2413) J01241 ANOREXIANTS-NOS' 2414='(2414) J01243 INTERFERONS-NOS'
                2415='(2415) J01244 MONOCLONAL ANTIBODIES-NOS' 2416='(2416) J01247 IMPOTENCE AGENTS-NOS'
                2417='(2417) J01253 VAGINAL PREPARATIONS-NOS' 2418='(2418) J01254 ANTIPSORIATICS-NOS'
                2419='(2419) J01256 PROTON PUMP INHIBITORS-NOS' 2420='(2420) J01261 DRUG UNKNOWN'
                2421='(2421) J01262 GAMMA HYDROXY BUTYRATE' 2422='(2422) J01271 PASSION FLOWER'
                2423='(2423) J01276 METHAPHENILENE' 2424='(2424) J01292 CODEINE COMBINATION-NOS'
                2425='(2425) J01294 HALLUCINOGEN-NOS' 2426='(2426) J01295 POLY-DRUGS'
                2427='(2427) J01298 ANTINEOPLASTICS-NOS'
                2428='(2428) J01300 ANTIBIOTICS/ANTINEOPLASTICS-NOS'
                2429='(2429) J01301 HORMONES/ANTINEOPLASTICS-NOS' 2430='(2430) J01302 DIURETICS-NOS'
                2431='(2431) J01303 ANTIEMETIC/ANTIVERTIGO AGENTS-NOS' 2432='(2432) J01305 VITAMINS-NOS'
                2433='(2433) J01306 OPHTHALMIC PREPARATIONS-NOS'
                2434='(2434) J01307 OTIC PREPARATIONS-NOS'
                2435='(2435) J01308 ANALGESIC COMBINATIONS-NOS' 2436='(2436) J01309 COX-2 INHIBITOR-NOS'
                2437='(2437) J01310 SSRI ANTIDEPRESSANTS-NOS'
                2438='(2438) J01311 TRICYCLIC ANTIDEPRESSANTS-NOS'
                2439='(2439) J01312 MONOAMINE OXIDASE INHIBITORS-NOS'
                2440='(2440) J01313 PSYCHOTHERAPEUTIC COMBINATIONS-NOS'
                2441='(2441) J01314 PHENOTHIAZINE ANTIPSYCHOTICS-NOS' 2442='(2442) J01315 ISOSORBIDE-NOS'
                2443='(2443) J01316 IMMUNIZATION-NOS' 2444='(2444) J01317 PHENCYCLIDINE COMBINATIONS-NOS'
                2445='(2445) J01318 PNEUMOCOCCAL VACCINE' 2446='(2446) J01319 FOLATE'
                2447='(2447) J01320 PENTOBARBITAL/PHENYTOIN' 2448='(2448) J01322 BARBITAL SODIUM'
                2449='(2449) J01323 GADOLINIUM' 2450='(2450) J01324 HEPATITIS A VACCINE INACTIVATED'
                2451='(2451) J01327 ZINC' 2452='(2452) J01328 4-BROMO-2,5-DIMETHOXYPHENETHYLAMINE'
                2453='(2453) J01329 2,5-DIMETHOXY-4-IODOPHENETHYLAMINE'
                2454='(2454) J01330 AMPHETAMINE/COCAINE' 2455='(2455) J01331 METHANDROSTENLONE'
                2456='(2456) J01332 MARIJUANA/OPIUM'
                2457='(2457) J01333 ALPROSTADIL/PAPAVERINE/PHENTOLAMINE'
                2458='(2458) J01334 CYANIDE/HEROIN/STRYCHNINE' 2459='(2459) J01338 HYDROXYCODEINONE'
                2460='(2460) J01340 2,5-DIMETHOXY-4-ETHYL-PHENETHYLAMINE'
                2461='(2461) J01341 2,5-DIMETHOXY-4-(N)-PROPYLTHIOPHENETHYLAMINE'
                2462='(2462) J01342 ANTI-RETROVIRAL AGENTS-NOS' 2463='(2463) J01343 AROPLATIN'
                2464='(2464) J01344 IDRAPARINUX' 2465='(2465) J01345 COCAINE/LYSERGIC ACID DIETHYLAMIDE'
                2466='(2466) J01346 SALVIA DIVINORUM' 2467='(2467) J01348 TIPIFARNIB'
                2468='(2468) J01350 FLUOROURACIL-LEUCOVORIN'
                2469='(2469) J01353 IFOSFAMIDE/CARBOPLATIN/ETOPOSIDE' 2470='(2470) J01354 CARPROFEN'
                2471='(2471) J01355 RIFAMPIN/ISONIAZID/PYRAZINAMIDE/ETHAMBUTOL'
                2472='(2472) J01356 THALLIUM' 2473='(2473) J01357 POLYMYXIN B OTIC'
                2474='(2474) J01358 ALLANTOIN/PRAMOXINE'
                2475='(2475) J01359 COCAINE/MARIJUANA/FORMALDEHYDE' 2476='(2476) J01360 COCAINE/OPIUM'
                2477='(2477) J01361 CYCLOPHOSPHAMIDE/DOXORUBICIN/VINCRISTINE/PREDNISONE'
                2478='(2478) J01362 DIPHTHERIA/PERTUSISIS/POLIO/HAEMOPHILUS/TETANUS'
                2479='(2479) J01363 ETORICOXIB' 2480='(2480) J01365 FLUPENTHIXOL'
                2481='(2481) J01366 FUSIDIC ACID' 2482='(2482) J01367 HEROIN/METHAMPHETAMINE'
                2483='(2483) J01368 IODINE CONTRAST AGENT'
                2484='(2484) J01369 MARIJUANA/LYSERGIC ACID DIETHYLAMIDE'
                2485='(2485) J01370 METHYLENEDIOXYMETHAMPHETAMINE/PSILOCYBIN'
                2486='(2486) J01371 NEOMYCIN-POLYMYXIN B SULFATE OTIC'
                2487='(2487) J01372 OXALIPLATIN/FLUOROURACIL/LEUCOVORIN' 2488='(2488) J01373 PHOSPHORUS'
                2489='(2489) J01375 ADRENERGIC BRONCHODILATORS-NOS'
                2490='(2490) J01379 OMEGA-6 POLYUNSATURATED FATTY ACIDS'
                2491='(2491) J01380 TOPICAL ANTIFUNGALS-NOS'
                2492='(2492) J01382 DEXTROMETHORPHAN COMBINATIONS-NOS' 2493='(2493) J01383 CLENBUTEROL'
                2494='(2494) J01386 FENTANYL/HEROIN' 2495='(2495) J01387 SULFONYLUREAS-NOS'
                2496='(2496) J01388 COCAINE/FORMALDEHYDE'
                2497='(2497) J01389 COCAINE/METHYLENEDIOXYMETHAMPHETAMINE'
                2498='(2498) J01390 CYPROTEREONE ACETATE-ETHINYL ESTRADIOL'
                2499='(2499) J01391 FAT DISSOLVING AGENTS-NOS'
                2500='(2500) J01392 HEROIN/METHYLENEDIOXYMETHAMPHETAMINE' 2501='(2501) J01393 PROPOLIS'
                2502='(2502) J01394 SENNA COMBINATIONS-NOS' 2503='(2503) J01395 FENFLURAMINE/PHENTERMINE'
                2504='(2504) J01396 ACNE AGENTS-NOS' 2505='(2505) J01401 CLONIXIN'
                2506='(2506) J01404 PROGESTINS-NOS' 2507='(2507) J01405 RABIES VACCINE-NOS'
                2508='(2508) J01411 INFLUENZA VIRUS VACCINE, H1N1-NOS' 2509='(2509) J01412 ACAI BERRY'
                2510='(2510) J01413 ALUM' 2511='(2511) J01414 AMMONIA'
                2512='(2512) J01415 BENZYLPIPERAZINE' 2513='(2513) J01416 BLUE GREEN ALGAE'
                2514='(2514) J01417 CYCLOPHOSPHAMIDE/DOXORUBICIN/RITUXIMAB/VINCRISTINE/PREDNISONE'
                2515='(2515) J01418 HOODIA' 2516='(2516) J01419 HYALURONIC ACID'
                2517='(2517) J01420 PAPAVERINE/PHENTOLAMINE' 2518='(2518) J01421 STATIN-NOS'
                2519='(2519) J01422 TEA TREE OIL' 2520='(2520) J01423 TRIFLUOROMETHYLPHENYLPIPERAZINE'
                2521='(2521) J01424 4-METHYLMETHCATHINONE' 2522='(2522) J01426 PHENAZEPAM'
                2523='(2523) J01427 4-BROMO-3,6-DIMETHOXYBENZOCYCLOBUTEN'
                2524='(2524) J01428 SYNTHETIC CANNABINOID' 2525='(2525) J01429 AFATINIB'
                2526='(2526) J01430 AMPHETAMINE/MARIJUANA' 2527='(2527) J01431 AXITINIB'
                2528='(2528) J01432 BLEOMYCIN/DACARBAZINE/DOXORUBICIN/VINBLASTINE'
                2529='(2529) J01433 CAFFEINE COMBINATIONS-NOS'
                2530='(2530) J01434 CAPECITABINE/OXALIPLATIN' 2531='(2531) J01435 COLLOIDAL SILVER'
                2532='(2532) J01436 DOCETAXEL/FLUOROURACIL/OXALIPLATIN' 2533='(2533) J01437 DOMPERIDONE'
                2534='(2534) J01438 FLUOROURACIL/IRINOTECAN/LEUCOVORIN'
                2535='(2535) J01439 IFOSFAMIDE/CARBOPLATIN/ETOPOSIDE/RITUXIMAB'
                2536='(2536) J01440 KETAMINE/MARIJUANA' 2537='(2537) J01441 L-TRYPTOPHAN/MELATONIN'
                2538='(2538) J01442 MARIJUANA/OXYCODONE' 2539='(2539) J01443 METAMIZOLE'
                2540='(2540) J01444 3,4-METHYLENEDIOXYPYROVALERONE' 2541='(2541) J01445 PANOBINOSTAT'
                2542='(2542) J01446 PROBIOTICS-NOS' 2543='(2543) J01447 SPERMICIDES-NOS'
                2544='(2544) J01448 TILMICOSIN' 2545='(2545) J01449 AMPHETAMINES-NOS'
                2546='(2546) J01450 ILLICIT COMBINATIONS-NOS' 2547='(2547) J01451 VITAMIN D'
                2548='(2548) J01454 TRENBOLONE' 2549='(2549) J01455 H. PYLORI ERADICATION AGENTS-NOS'
                2550='(2550) J01456 SMOKING CESSATION AGENTS-NOS'
                2551='(2551) J01457 4-BROMO-2,5-DIMETHOXYAMPHETAMINE'
                2552='(2552) J01458 PROTEASE INHIBITORS-NOS' 2553='(2553) J01459 4-METHOXYMETHCATHINONE'
                2554='(2554) J01460 ELASTIN' 2555='(2555) J01461 TALCUM POWDER TOPICAL'
                2556='(2556) J01462 METHYLENEDIOXYMETHAMPHETAMINE/CAFFEINE'
                2557='(2557) J01463 ENERGY DRINK' 2558='(2558) J01464 CAFFEINE/MULTIVITAMIN NTA';
VALUE sdled_6f  -7='(-00007) NOT APPLICABLE:(-7)'
                37.5005='(000037) BUPRENORPHINE/COMBINATIONS:(37.5005)'
                37.501='(000037) CODEINE/COMBINATIONS:(37.501)'
                37.502='(000037) DIHYDROCODEINE/COMBINATIONS:(37.502)'
                37.503='(000037) FENTANYL/COMBINATIONS:(37.503)'
                37.504='(000037) HYDROCODONE/COMBINATIONS:(37.504)'
                37.5045='(000037) HYDROMORPHONE/COMBINATIONS:(37.5045)'
                37.505='(000037) MEPERIDINE/COMBINATIONS:(37.505)' 37.506='(000037) METHADONE:(37.506)'
                37.507='(000037) MORPHINE/COMBINATIONS:(37.507)'
                37.508='(000037) OPIUM/COMBINATIONS:(37.508)'
                37.509='(000037) OXYCODONE/COMBINATIONS:(37.509)'
                37.51='(000037) PENTAZOCINE/COMBINATIONS:(37.51)'
                37.511='(000037) PHENACETIN/COMBINATIONS:(37.511)'
                37.512='(000037) PROPOXYPHENE/COMBINATIONS:(37.512)'
                37.514='(000037) ALL OTHER NARCOTIC ANALGESICS/COMBINATIONS NTA:(37.514)'
                41.503='(000041) TRAMADOL:(41.503)' 41.504='(000041) ACETAMINOPHEN-TRAMADOL:(41.504)';
VALUE raceffff  -8='(-8) NOT DOCUMENTED:(-8)' 1='(1) WHITE ONLY:(1)'
                2='(2) BLACK OR AFRICAN AMERICAN ONLY:(2)' 3='(3) ANY HISPANIC OR LATINO:(3)'
                4='(4) ALL OTHER RACES:(4)';
VALUE nonalcif  0='(0) EPISODE DOES NOT INVOLVE ILLICIT DRUGS (EXCLUDING ALCOHOL):(0)'
                1='(1) EPISODE INVOLVES ILLICIT DRUGS (EXCLUDING ALCOHOL):(1)';
VALUE sdled_3f  -7='(-0007) NOT APPLICABLEL:(-7.00)' 3='(00003) COCAINE:(3)'
                4='(00004) HEROIN:(4)' 5='(00005) CANNABINOIDS:(5)' 5.5='(00005) STIMULANTS:(5.5)'
                8='(00008) MDMA (ECSTASY):(8)' 8.1='(00008) GHB:(8.1)'
                8.2='(00008) FLUNITRAZEPAM (ROHYPNOL):(8.2)' 9='(00009) KETAMINE:(9)'
                10='(00010) LSD:(10)' 11='(00011) PCP:(11)' 12='(00012) MISCELLANEOUS HALLUCINOGENS:(12)'
                15='(00015) INHALANTS:(15)' 16='(00016) COMBINATIONS NTA:(16)'
                19='(00019) ANTIDEPRESSANTS:(19)' 24='(00024) ANTIPSYCHOTICS:(24)'
                34='(00034) ANALGESICS:(34)' 43='(00043) ANOREXIANTS:(43)'
                44='(00044) ANTICONVULSANTS:(44)' 45='(00045) ANTIEMETIC/ANTIVERTIGO AGENTS:(45)'
                46='(00046) ANTIPARKINSON AGENTS:(46)'
                46.3='(00046) ANXIOLYTICS, SEDATIVES, AND HYPNOTICS:(46.3)'
                46.5='(00046) CNS STIMULANTS:(46.5)'
                46.7='(00046) DRUGS USED IN ALCOHOL DEPENDENCE:(46.7)'
                47='(00047) GENERAL ANESTHETICS:(47)' 48='(00048) MUSCLE RELAXANTS:(48)'
                49='(00049) MISCELLANEOUS CNS AGENTS:(49)' 51='(00051) ANTIHISTAMINES:(51)'
                52='(00052) BRONCHODILATORS:(52)' 53='(00053) DECONGESTANTS:(53)'
                54='(00054) EXPECTORANTS:(54)'
                54.5='(00054) SELECTIVE PHOSPHODIESTERASE-4 INHIBITORS:(54.5)'
                55='(00055) UPPER RESPIRATORY COMBINATIONS:(55)' 56='(00056) RESPIRATORY AGENTS NTA:(56)'
                58='(00058) ANTIADRENERGIC AGENTS, CENTRALLY ACTING:(58)'
                59='(00059) BETA-ADRENERGIC BLOCKING AGENTS:(59)'
                60='(00060) CALCIUM CHANNEL BLOCKING AGENTS:(60)' 61='(00061) DIURETICS:(61)'
                61.3='(00061) RENIN INHIBITORS:(61.3)' 61.5='(00061) VASOPRESSIN ANTAGONISTS:(61.5)'
                62='(00062) CARDIOVASCULAR AGENTS NTA:(62)' 63.1='(00063) HERBAL PRODUCTS:(63.1)'
                63.2='(00063) NUTRACEUTICAL PRODUCTS:(63.2)' 63.3='(00063) PROBIOTICS:(63.3)'
                64.01='(00064) AMEBICIDES:(64.01)' 64.02='(00064) AMINOGLYCOSIDES:(64.02)'
                64.03='(00064) ANTHELMINTICS:(64.03)' 64.04='(00064) ANTIFUNGALS:(64.04)'
                64.05='(00064) ANTIMALARIAL AGENTS:(64.05)'
                64.06='(00064) ANTITUBERCULOSIS AGENTS:(64.06)' 64.07='(00064) ANTIVIRAL AGENTS:(64.07)'
                64.08='(00064) CARBAPENEMS:(64.08)' 64.09='(00064) CEPHALOSPORINS:(64.09)'
                64.1='(00064) GLYCOPEPTIDE ANTIBIOTICS:(64.1)' 64.11='(00064) GLYCYLCYCLINES:(64.11)'
                64.12='(00064) LEPROSTATICS:(64.12)' 64.13='(00064) LINCOMYCIN DERIVATIVES:(64.13)'
                64.14='(00064) MACROLIDE DERIVATIVES:(64.14)' 64.15='(00064) PENICILLINS:(64.15)'
                64.16='(00064) QUINOLONES:(64.16)' 64.17='(00064) SULFONAMIDES:(64.17)'
                64.18='(00064) TETRACYCLINES:(64.18)' 64.19='(00064) URINARY ANTI-INFECTIVES:(64.19)'
                64.99='(00064) MISCELLANEOUS ANTIBIOTICS:(64.99)'
                65.01='(00065) ALKYLATING AGENTS:(65.01)'
                65.02='(00065) ANTI-CTLA-4 MONOCLONAL ANTIBODIES:(65.02)'
                65.03='(00065) ANTIMETABOLITES:(65.03)'
                65.04='(00065) ANTINEOPLASTIC ANTIBIOTICS:(65.04)'
                65.05='(00065) ANTINEOPLASTIC DETOXIFYING AGENTS:(65.05)'
                65.06='(00065) ANTINEOPLASTIC HORMONES:(65.06)'
                65.07='(00065) ANTINEOPLASTIC INTERFERONS:(65.07)'
                65.08='(00065) BCR-ABL TYROSINE KINASE INHIBITORS:(65.08)'
                65.09='(00065) CD20 MONOCLONAL ANTIBODIES:(65.09)'
                65.11='(00065) CD33 MONOCLONAL ANTIBODIES:(65.11)'
                65.12='(00065) CD52 MONOCLONAL ANTIBODIES:(65.12)'
                65.13='(00065) EGFR INHIBITORS:(65.13)' 65.14='(00065) HER2 INHIBITORS:(65.14)'
                65.15='(00065) HISTONE DEACETYLASE INHIBITORS:(65.15)'
                65.16='(00065) MITOTIC INHIBITORS:(65.16)' 65.17='(00065) MTOR INHIBITORS:(65.17)'
                65.18='(00065) MULTIKINASE INHIBITORS:(65.18)'
                65.2='(00065) VEGF/VEGFR INHIBITORS:(65.2)'
                65.99='(00065) MISCELLANEOUS ANTINEOPLASTICS:(65.99)'
                66.01='(00066) ANTITOXINS AND ANTIVENINS:(66.01)'
                66.04='(00066) IN VIVO DIAGNOSTIC BIOLOGICALS:(66.04)'
                66.05='(00066) RECOMBINANT HUMAN ERYTHROPOIETINS:(66.05)'
                67.01='(00067) ANTICOAGULANTS:(67.01)' 67.02='(00067) ANTIPLATELET AGENTS:(67.02)'
                67.03='(00067) HEPARIN ANTAGONISTS:(67.03)'
                67.04='(00067) PLATELET-STIMULATING AGENTS:(67.04)' 67.05='(00067) THROMBOLYTICS:(67.05)'
                67.06='(00067) MISCELLANEOUS COAGULATION MODIFIERS:(67.06)'
                68.01='(00068) 5-AMINOSALICYLATES:(68.01)' 68.02='(00068) ANTACIDS:(68.02)'
                68.04='(00068) ANTIDIARRHEALS:(68.04)' 68.05='(00068) DIGESTIVE ENZYMES:(68.05)'
                68.06='(00068) FUNCTIONAL BOWEL DISORDER AGENTS:(68.06)'
                68.07='(00068) GALLSTONE SOLUBILIZING AGENTS:(68.07)'
                68.08='(00068) GI STIMULANTS:(68.08)'
                68.09='(00068) H. PYLORI ERADICATION AGENTS:(68.09)' 68.1='(00068) H2 ANTAGONISTS:(68.1)'
                68.11='(00068) LAXATIVES:(68.11)' 68.12='(00068) PROTON PUMP INHIBITORS:(68.12)'
                68.13='(00068) MISCELLANEOUS GI AGENTS:(68.13)' 69.01='(00069) IMPOTENCE AGENTS:(69.01)'
                69.02='(00069) TOCOLYTIC AGENTS:(69.02)' 69.03='(00069) URINARY ANTISPASMODICS:(69.03)'
                69.04='(00069) URINARY PH MODIFIERS:(69.04)' 69.05='(00069) UTEROTONIC AGENTS:(69.05)'
                69.99='(00069) MISCELLANEOUS GENITOURINARY TRACT AGENTS:(69.99)'
                70.01='(00070) 5-ALPHA-REDUCTASE INHIBITORS:(70.01)'
                70.02='(00070) ADRENAL CORTICAL STEROIDS:(70.02)'
                70.05='(00070) ANTIDIURETIC HORMONES:(70.05)'
                70.06='(00070) ANTIGONADOTROPIC AGENTS:(70.06)'
                70.07='(00070) ANTITHYROID AGENTS:(70.07)' 70.09='(00070) CALCITONIN:(70.09)'
                70.11='(00070) GONADOTROPIN-RELEASING HORMONE ANTAGONISTS:(70.11)'
                70.12='(00070) GROWTH HORMONE RECEPTOR BLOCKERS:(70.12)'
                70.13='(00070) GROWTH HORMONES:(70.13)'
                70.15='(00070) INSULIN-LIKE GROWTH FACTOR:(70.15)'
                70.16='(00070) PARATHYROID HORMONE AND ANALOGS:(70.16)'
                70.17='(00070) PROGESTERONE RECEPTOR MODULATORS:(70.17)'
                70.18='(00070) PROLACTIN INHIBITORS:(70.18)'
                70.19='(00070) SELECTIVE ESTROGEN RECEPTOR MODULATORS:(70.19)'
                70.2='(00070) SEX HORMONES:(70.2)'
                70.21='(00070) SOMATOSTATIN AND SOMATOSTATIN ANALOGS:(70.21)'
                70.22='(00070) SYNTHETIC OVULATION STIMULANTS:(70.22)'
                70.23='(00070) THYROID HORMONES:(70.23)' 70.99='(00070) MISCELLANEOUS HORMONES:(70.99)'
                71.01='(00071) IMMUNE GLOBULINS:(71.01)' 71.02='(00071) IMMUNOSTIMULANTS:(71.02)'
                71.03='(00071) IMMUNOSUPPRESSIVE AGENTS:(71.03)'
                71.99='(00071) MISCELLANEOUS IMMUNOLOGIC AGENTS:(71.99)'
                73.01='(00073) ANTIDIABETIC AGENTS:(73.01)' 73.02='(00073) ANTIGOUT AGENTS:(73.02)'
                73.03='(00073) ANTIHYPERLIPIDEMIC AGENTS:(73.03)'
                73.04='(00073) ANTIHYPERURICEMIC AGENTS:(73.04)'
                73.05='(00073) BONE RESORPTION INHIBITORS:(73.05)'
                73.06='(00073) GLUCOSE ELEVATING AGENTS:(73.06)'
                73.07='(00073) LYSOSOMAL ENZYMES:(73.07)'
                73.08='(00073) PERIPHERALLY ACTING ANTIOBESITY AGENTS:(73.08)'
                73.99='(00073) MISCELLANEOUS METABOLIC AGENTS:(73.99)' 74.01='(00074) ANTIDOTES:(74.01)'
                74.04='(00074) ANTIPSORIATICS:(74.04)' 74.05='(00074) ANTIRHEUMATICS:(74.05)'
                74.06='(00074) CHELATING AGENTS:(74.06)'
                74.07='(00074) CHOLINERGIC MUSCLE STIMULANTS:(74.07)'
                74.11='(00074) LOCAL INJECTABLE ANESTHETICS:(74.11)' 74.13='(00074) PSORALENS:(74.13)'
                74.17='(00074) SMOKING CESSATION AGENTS:(74.17)'
                74.18='(00074) VISCOSUPPLEMENTATION AGENTS:(74.18)'
                74.19='(00074) MISCELLANEOUS UNCATEGORIZED AGENTS:(74.19)'
                75.01='(00075) INTRAVENOUS NUTRITIONAL PRODUCTS:(75.01)'
                75.02='(00075) IRON PRODUCTS:(75.02)' 75.03='(00075) MINERALS AND ELECTROLYTES:(75.03)'
                75.04='(00075) ORAL NUTRITIONAL SUPPLEMENTS:(75.04)'
                75.05='(00075) VITAMIN AND MINERAL COMBINATIONS:(75.05)' 75.06='(00075) VITAMINS:(75.06)'
                77.01='(00077) RADIOCONTRAST AGENTS:(77.01)' 77.02='(00077) RADIOLOGIC ADJUNCTS:(77.02)'
                77.03='(00077) RADIOPHARMACEUTICALS:(77.03)'
                78.01='(00078) ANORECTAL PREPARATIONS:(78.01)'
                78.02='(00078) ANTISEPTIC AND GERMICIDES:(78.02)'
                78.03='(00078) DERMATOLOGICAL AGENTS:(78.03)'
                78.04='(00078) MOUTH AND THROAT PRODUCTS:(78.04)'
                78.05='(00078) NASAL PREPARATIONS:(78.05)'
                78.06='(00078) OPHTHALMIC PREPARATIONS:(78.06)' 78.07='(00078) OTIC PREPARATIONS:(78.07)'
                78.08='(00078) STERILE IRRIGATING SOLUTIONS:(78.08)'
                78.09='(00078) VAGINAL PREPARATIONS:(78.09)';
VALUE allabusf  0='(0) NOT AN ''ALL MISUSE AND ABUSE'' EPISODE:(0)'
                1='(1) IS AN ''ALL MISUSE AND ABUSE'' EPISODE:(1)';
VALUE agecatff  -8='(-8) NOT DOCUMENTED:(-8)' 1='(01) AGE 5 OR YOUNGER:(1)'
                2='(02) 6 TO 11:(2)' 3='(03) 12 TO 17:(3)' 4='(04) 18 TO 20:(4)' 5='(05) 21 TO 24:(5)'
                6='(06) 25 TO 29:(6)' 7='(07) 30 TO 34:(7)' 8='(08) 35 TO 44:(8)' 9='(09) 45 TO 54:(9)'
                10='(10) 55 TO 64:(10)' 11='(11) AGE 65 OR OLDER:(11)';
VALUE alcoholf  0='(0) NO MENTION OF ALCOHOL (SDLED <>2):(0)'
                1='(1) ALCOHOL MENTIONED (SDLED=2):(1)';
VALUE disposif  -8='(-8) NOT DOCUMENTED:(-8)' 1='(01) DISCHARGED HOME:(1)'
                2='(02) RELEASED TO POLICE/JAIL:(2)' 3='(03) REFERRED TO DETOX/TREATMENT:(3)'
                4='(04) ICU/CRITICAL CARE:(4)' 5='(05) SURGERY:(5)'
                6='(06) CHEMICAL DEPENDENCY/DETOX, PSYCHIATRIC UNIT:(6)'
                7='(07) OTHER INPATIENT UNIT:(7)' 8='(08) TRANSFERRED:(8)'
                9='(09) LEFT AGAINST MEDICAL ADVICE:(9)' 10='(10) DIED:(10)' 96='(96) OTHER:(96)';
VALUE daypartf  1='(1) EARLY MORNING (12:00 - 5:59 A.M.):(1)'
                2='(2) MORNING (6:00 - 11:59 A.M.):(2)' 3='(3) AFTERNOON (12:00 - 5:59 P.M.):(3)'
                4='(4) EVENING/NIGHT (6:00 - 11:59 P.M.):(4)';
VALUE catid_1f  -7='(-007) NOT APPLICABLE:(-7)' 1='(0001) ANTI-INFECTIVES:(1)'
                20='(0020) ANTINEOPLASTICS:(20)' 28='(0028) BIOLOGICALS:(28)'
                40='(0040) CARDIOVASCULAR AGENTS:(40)' 57='(0057) CENTRAL NERVOUS SYSTEM AGENTS:(57)'
                81='(0081) COAGULATION MODIFIERS:(81)' 87='(0087) GASTROINTESTINAL AGENTS:(87)'
                97='(0097) HORMONES/HORMONE MODIFIERS:(97)' 105='(0105) MISCELLANEOUS AGENTS:(105)'
                113='(0113) GENITOURINARY TRACT AGENTS:(113)' 115='(0115) NUTRITIONAL PRODUCTS:(115)'
                122='(0122) RESPIRATORY AGENTS:(122)' 133='(0133) TOPICAL AGENTS:(133)'
                153='(0153) PLASMA EXPANDERS:(153)' 218='(0218) ALTERNATIVE MEDICINES:(218)'
                242='(0242) PSYCHOTHERAPEUTIC AGENTS:(242)' 254='(0254) IMMUNOLOGIC AGENTS:(254)'
                331='(0331) RADIOLOGIC AGENTS:(331)' 358='(0358) METABOLIC AGENTS:(358)'
                365='(0365) MEDICAL GAS:(365)' 2006='(2006) DRUG UNKNOWN:(2006)'
                2041='(2041) NON-PHARMACEUTICAL:(2041)';
VALUE pharmaff  0='(0) EPISODE DOES NOT INVOLVE PHARMACEUTICALS:(0)'
                1='(1) EPISODE INVOLVES PHARMACEUTICALS:(1)';
VALUE catid_2f  -7='(-007) NOT APPLICABLE:(-7)' 2='(0002) AMEBICIDES:(2)'
                3='(0003) ANTHELMINTICS:(3)' 4='(0004) ANTIFUNGALS:(4)'
                5='(0005) ANTIMALARIAL AGENTS:(5)' 6='(0006) ANTITUBERCULOSIS AGENTS:(6)'
                7='(0007) ANTIVIRAL AGENTS:(7)' 8='(0008) CARBAPENEMS:(8)' 9='(0009) CEPHALOSPORINS:(9)'
                10='(0010) LEPROSTATICS:(10)' 11='(0011) MACROLIDE DERIVATIVES:(11)'
                12='(0012) MISCELLANEOUS ANTIBIOTICS:(12)' 13='(0013) PENICILLINS:(13)'
                14='(0014) QUINOLONES:(14)' 15='(0015) SULFONAMIDES:(15)' 16='(0016) TETRACYCLINES:(16)'
                17='(0017) URINARY ANTI-INFECTIVES:(17)' 18='(0018) AMINOGLYCOSIDES:(18)'
                19='(0019) ANTIHYPERLIPIDEMIC AGENTS:(19)' 21='(0021) ALKYLATING AGENTS:(21)'
                22='(0022) ANTINEOPLASTIC ANTIBIOTICS:(22)' 23='(0023) ANTIMETABOLITES:(23)'
                24='(0024) ANTINEOPLASTIC HORMONES:(24)' 25='(0025) MISCELLANEOUS ANTINEOPLASTICS:(25)'
                26='(0026) MITOTIC INHIBITORS:(26)' 27='(0027) RADIOPHARMACEUTICALS:(27)'
                30='(0030) ANTITOXINS AND ANTIVENINS:(30)' 33='(0033) IMMUNE GLOBULINS:(33)'
                34='(0034) IN VIVO DIAGNOSTIC BIOLOGICALS:(34)'
                36='(0036) RECOMBINANT HUMAN ERYTHROPOIETINS:(36)'
                41='(0041) AGENTS FOR HYPERTENSIVE EMERGENCIES:(41)'
                42='(0042) ANGIOTENSIN CONVERTING ENZYME INHIBITORS:(42)'
                43='(0043) ANTIADRENERGIC AGENTS, PERIPHERALLY ACTING:(43)'
                44='(0044) ANTIADRENERGIC AGENTS, CENTRALLY ACTING:(44)'
                45='(0045) ANTIANGINAL AGENTS:(45)' 46='(0046) ANTIARRHYTHMIC AGENTS:(46)'
                47='(0047) BETA-ADRENERGIC BLOCKING AGENTS:(47)'
                48='(0048) CALCIUM CHANNEL BLOCKING AGENTS:(48)' 49='(0049) DIURETICS:(49)'
                50='(0050) INOTROPIC AGENTS:(50)' 51='(0051) MISCELLANEOUS CARDIOVASCULAR AGENTS:(51)'
                52='(0052) PERIPHERAL VASODILATORS:(52)' 53='(0053) VASODILATORS:(53)'
                54='(0054) VASOPRESSORS:(54)' 55='(0055) ANTIHYPERTENSIVE COMBINATIONS:(55)'
                56='(0056) ANGIOTENSIN II INHIBITORS:(56)' 58='(0058) ANALGESICS:(58)'
                64='(0064) ANTICONVULSANTS:(64)' 65='(0065) ANTIEMETIC/ANTIVERTIGO AGENTS:(65)'
                66='(0066) ANTIPARKINSON AGENTS:(66)'
                67='(0067) ANXIOLYTICS, SEDATIVES, AND HYPNOTICS:(67)' 71='(0071) CNS STIMULANTS:(71)'
                72='(0072) GENERAL ANESTHETICS:(72)' 73='(0073) MUSCLE RELAXANTS:(73)'
                80='(0080) MISCELLANEOUS CENTRAL NERVOUS SYSTEM AGENTS:(80)'
                82='(0082) ANTICOAGULANTS:(82)' 83='(0083) ANTIPLATELET AGENTS:(83)'
                84='(0084) HEPARIN ANTAGONISTS:(84)' 85='(0085) MISCELLANEOUS COAGULATION MODIFIERS:(85)'
                86='(0086) THROMBOLYTICS:(86)' 88='(0088) ANTACIDS:(88)' 90='(0090) ANTIDIARRHEALS:(90)'
                91='(0091) DIGESTIVE ENZYMES:(91)' 92='(0092) GALLSTONE SOLUBILIZING AGENTS:(92)'
                93='(0093) GI STIMULANTS:(93)' 94='(0094) H2 ANTAGONISTS:(94)' 95='(0095) LAXATIVES:(95)'
                96='(0096) MISCELLANEOUS GI AGENTS:(96)' 98='(0098) ADRENAL CORTICAL STEROIDS:(98)'
                99='(0099) ANTIDIABETIC AGENTS:(99)' 100='(0100) MISCELLANEOUS HORMONES:(100)'
                101='(0101) SEX HORMONES:(101)' 103='(0103) THYROID HORMONES:(103)'
                104='(0104) IMMUNOSUPPRESSIVE AGENTS:(104)' 106='(0106) ANTIDOTES:(106)'
                107='(0107) CHELATING AGENTS:(107)' 108='(0108) CHOLINERGIC MUSCLE STIMULANTS:(108)'
                109='(0109) LOCAL INJECTABLE ANESTHETICS:(109)'
                110='(0110) MISCELLANEOUS UNCATEGORIZED AGENTS:(110)' 111='(0111) PSORALENS:(111)'
                112='(0112) RADIOCONTRAST AGENTS:(112)' 114='(0114) ILLICIT (STREET) DRUGS:(114)'
                116='(0116) IRON PRODUCTS:(116)' 117='(0117) MINERALS AND ELECTROLYTES:(117)'
                118='(0118) ORAL NUTRITIONAL SUPPLEMENTS:(118)' 119='(0119) VITAMINS:(119)'
                120='(0120) VITAMIN AND MINERAL COMBINATIONS:(120)'
                121='(0121) INTRAVENOUS NUTRITIONAL PRODUCTS:(121)' 123='(0123) ANTIHISTAMINES:(123)'
                124='(0124) ANTITUSSIVES:(124)' 125='(0125) BRONCHODILATORS:(125)'
                127='(0127) DECONGESTANTS:(127)' 128='(0128) EXPECTORANTS:(128)'
                129='(0129) MISCELLANEOUS RESPIRATORY AGENTS:(129)'
                130='(0130) RESPIRATORY INHALANT PRODUCTS:(130)'
                131='(0131) ANTIASTHMATIC COMBINATIONS:(131)'
                132='(0132) UPPER RESPIRATORY COMBINATIONS:(132)'
                134='(0134) ANORECTAL PREPARATIONS:(134)' 135='(0135) ANTISEPTIC AND GERMICIDES:(135)'
                136='(0136) DERMATOLOGICAL AGENTS:(136)' 146='(0146) MOUTH AND THROAT PRODUCTS:(146)'
                147='(0147) OPHTHALMIC PREPARATIONS:(147)' 148='(0148) OTIC PREPARATIONS:(148)'
                150='(0150) STERILE IRRIGATING SOLUTIONS:(150)' 151='(0151) VAGINAL PREPARATIONS:(151)'
                192='(0192) ANTIRHEUMATICS:(192)' 194='(0194) ANTIGOUT AGENTS:(194)'
                219='(0219) NUTRACEUTICAL PRODUCTS:(219)' 220='(0220) HERBAL PRODUCTS:(220)'
                240='(0240) LINCOMYCIN DERIVATIVES:(240)' 243='(0243) LEUKOTRIENE MODIFIERS:(243)'
                247='(0247) NASAL PREPARATIONS:(247)' 249='(0249) ANTIDEPRESSANTS:(249)'
                251='(0251) ANTIPSYCHOTICS:(251)' 253='(0253) ANOREXIANTS:(253)'
                263='(0263) IMPOTENCE AGENTS:(263)' 264='(0264) URINARY ANTISPASMODICS:(264)'
                265='(0265) URINARY PH MODIFIERS:(265)'
                266='(0266) MISCELLANEOUS GENITOURINARY TRACT AGENTS:(266)'
                270='(0270) ANTIPSORIATICS:(270)' 272='(0272) PROTON PUMP INHIBITORS:(272)'
                273='(0273) LUNG SURFACTANTS:(273)' 277='(0277) 5-AMINOSALICYLATES:(277)'
                284='(0284) VISCOSUPPLEMENTATION AGENTS:(284)'
                288='(0288) 5-ALPHA-REDUCTASE INHIBITORS:(288)'
                289='(0289) ANTIHYPERURICEMIC AGENTS:(289)' 293='(0293) GLUCOSE ELEVATING AGENTS:(293)'
                295='(0295) GROWTH HORMONES:(295)' 303='(0303) AGENTS FOR PULMONARY HYPERTENSION:(303)'
                312='(0312) CHOLINERGIC AGONISTS:(312)' 313='(0313) CHOLINESTERASE INHIBITORS:(313)'
                315='(0315) GLYCYLCYCLINES:(315)' 318='(0318) INSULIN-LIKE GROWTH FACTOR:(318)'
                319='(0319) VASOPRESSIN ANTAGONISTS:(319)' 320='(0320) SMOKING CESSATION AGENTS:(320)'
                324='(0324) ANTINEOPLASTIC INTERFERONS:(324)' 325='(0325) SCLEROSING AGENTS:(325)'
                332='(0332) RADIOLOGIC ADJUNCTS:(332)'
                340='(0340) ALDOSTERONE RECEPTOR ANTAGONISTS:(340)' 342='(0342) RENIN INHIBITORS:(342)'
                354='(0354) H. PYLORI ERADICATION AGENTS:(354)'
                355='(0355) FUNCTIONAL BOWEL DISORDER AGENTS:(355)'
                357='(0357) GROWTH HORMONE RECEPTOR BLOCKERS:(357)'
                359='(0359) PERIPHERALLY ACTING ANTIOBESITY AGENTS:(359)'
                360='(0360) LYSOSOMAL ENZYMES:(360)' 361='(0361) MISCELLANEOUS METABOLIC AGENTS:(361)'
                363='(0363) PROBIOTICS:(363)' 377='(0377) PROLACTIN INHIBITORS:(377)'
                378='(0378) DRUGS USED IN ALCOHOL DEPENDENCE:(378)'
                383='(0383) ANTINEOPLASTIC DETOXIFYING AGENTS:(383)'
                384='(0384) PLATELET-STIMULATING AGENTS:(384)'
                390='(0390) HEMATOPOIETIC STEM CELL MOBILIZER:(390)'
                397='(0397) MULTIKINASE INHIBITORS:(397)'
                398='(0398) BCR-ABL TYROSINE KINASE INHIBITORS:(398)'
                399='(0399) CD52 MONOCLONAL ANTIBODIES:(399)'
                400='(0400) CD33 MONOCLONAL ANTIBODIES:(400)'
                401='(0401) CD20 MONOCLONAL ANTIBODIES:(401)' 402='(0402) VEGF/VEGFR INHIBITORS:(402)'
                403='(0403) MTOR INHIBITORS:(403)' 404='(0404) EGFR INHIBITORS:(404)'
                405='(0405) HER2 INHIBITORS:(405)' 406='(0406) GLYCOPEPTIDE ANTIBIOTICS:(406)'
                408='(0408) HISTONE DEACETYLASE INHIBITORS:(408)'
                409='(0409) BONE RESORPTION INHIBITORS:(409)'
                410='(0410) ADRENAL CORTICOSTEROID INHIBITORS:(410)' 411='(0411) CALCITONIN:(411)'
                412='(0412) UTEROTONIC AGENTS:(412)' 413='(0413) ANTIGONADOTROPIC AGENTS:(413)'
                414='(0414) ANTIDIURETIC HORMONES:(414)'
                416='(0416) SOMATOSTATIN AND SOMATOSTATIN ANALOGS:(416)'
                417='(0417) SELECTIVE ESTROGEN RECEPTOR MODULATORS:(417)'
                418='(0418) PARATHYROID HORMONE AND ANALOGS:(418)'
                419='(0419) GONADOTROPIN-RELEASING HORMONE ANTAGONISTS:(419)'
                422='(0422) ANTITHYROID AGENTS:(422)' 426='(0426) SYNTHETIC OVULATION STIMULANTS:(426)'
                427='(0427) TOCOLYTIC AGENTS:(427)' 428='(0428) PROGESTERONE RECEPTOR MODULATORS:(428)'
                431='(0431) ANTI-CTLA-4 MONOCLONAL ANTIBODIES:(431)' 433='(0433) CATECHOLAMINES:(433)'
                435='(0435) SELECTIVE PHOSPHODIESTERASE-4 INHIBITORS:(435)'
                437='(0437) IMMUNOSTIMULANTS:(437)' 447='(0447) CD30 MONOCLONAL ANTIBODIES:(447)'
                2042='(2042) INHALANT:(2042)' 2051='(2051) MISCELLANEOUS IMMUNOLOGIC AGENTS:(2051)';
VALUE sdled_2f  -7='(-7) NOT APPLICABLE:(-7)' 2='(02) ALCOHOL:(2)'
                2.5='(02) NON-ALCOHOL ILLICITS:(2.5)' 18='(18) PSYCHOTHERAPEUTIC AGENTS:(18)'
                33='(33) CNS AGENTS:(33)' 50='(50) RESPIRATORY AGENTS:(50)'
                57='(57) CARDIOVASCULAR AGENTS:(57)' 63='(63) ALTERNATIVE MEDICINES:(63)'
                64='(64) ANTI-INFECTIVES:(64)' 65='(65) ANTINEOPLASTICS:(65)' 66='(66) BIOLOGICALS:(66)'
                67='(67) COAGULATION MODIFIERS:(67)' 68='(68) GASTROINTESTINAL AGENTS:(68)'
                69='(69) GENITOURINARY TRACT AGENTS:(69)' 70='(70) HORMONES:(70)'
                71='(71) IMMUNOLOGIC AGENTS:(71)' 72='(72) MEDICAL GAS:(72)'
                73='(73) METABOLIC AGENTS:(73)' 74='(74) MISCELLANEOUS AGENTS:(74)'
                75='(75) NUTRITIONAL PRODUCTS:(75)' 76='(76) PLASMA EXPANDERS:(76)'
                77='(77) RADIOLOGIC AGENTS:(77)' 78='(78) TOPICAL AGENTS:(78)'
                79='(79) DRUG UNKNOWN:(79)';
VALUE route_1f  -9='(-9) MISSING:(-9)' -8='(-8) NOT DOCUMENTED:(-8)'
                -7='(-7) NOT APPLICABLE:(-7)' 1='(01) ORAL:(1)' 2='(02) INJECTED:(2)'
                3='(03) INHALED, SNIFFED, SNORTED:(3)' 4='(04) SMOKED:(4)' 5='(05) OTHER:(5)'
                6='(06) TRANSDERMAL:(6)' 98='(98) MULTIPLE ROUTES FOR THIS DRUG:(98)';
VALUE metrofff  1='(01) BOSTON-CAMBRIDGE-QUINCY, MA-NH MSA:(1)'
                2='(02) NEW YORK CITY - 5 BUROUGHS (PART OF NEW YORK- NEWARK-EDISON, NY-NJ-PA MSA):(2)'
                3='(03) CHICAGO-NAPERVILLE-JOLIET, IL-IN-WI MSA:(3)'
                4='(04) DETROIT-WARREN-LIVONIA, MI MSA:(4)'
                5='(05) MINNEAPOLIS-ST. PAUL-BLOOMINGTON, MN-WI MSA:(5)'
                6='(06) FORT LAUNDERALE DIVISION OF MIAMI-FORT LAUDERDALE, FL MSA:(6)'
                7='(07) DADE COUNTY DIVISION OF MIAMI-FORT LAUDERDALE, FL MSA:(7)'
                8='(08) HOUSTON-BAYTOWN-SUGAR LAND, TX MSA:(8)' 9='(09) DENVER-AURORA, CO MSA:(9)'
                10='(10) PHOENIX-MESA-SCOTTSDALE, AZ MSA:(10)'
                11='(11) OAKLAND DIVISION OF SAN FRANCISCO-OAKLAND-FREMONT, CA MSA:(11)'
                12='(12) SAN FRANCISCO DIVISION OF SAN FRANCISCO-OAKLAND-FREMONT, CA MSA:(12)'
                13='(13) SEATTLE-TACOMA-BELLEVUE, WA MSA:(13)' 14='(14) ALL OTHER LOCATIONS:(14)';
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=1199;
INPUT
        CASEID 1-6              METRO 7-8               STRATA 9-10
        PSU 11-13               REPLICATE 14            CASEWGT 15-29 .10
        PSUFRAME 30-33          AGECAT 34-35            SEX 36-37
        RACE 38-39              YEAR 40-43              QUARTER 44
        DAYPART 45              NUMSUBS 46-47           DRUGID_1 48-51
        CATID_1_1 52-55         CATID_2_1 56-59         CATID_3_1 60-63
        ROUTE_1 64-65           TOXTEST_1 66-67         SDLED_1_1 68-69
        SDLED_2_1 70-73 .1      SDLED_3_1 74-78 .2      SDLED_4_1 79-85 .4
        SDLED_5_1 86-92 .4      SDLED_6_1 93-99 .4      DRUGID_2 100-103
        CATID_1_2 104-107       CATID_2_2 108-111       CATID_3_2 112-115
        ROUTE_2 116-117         TOXTEST_2 118-119       SDLED_1_2 120-121
        SDLED_2_2 122-125 .1    SDLED_3_2 126-130 .2    SDLED_4_2 131-137 .4
        SDLED_5_2 138-144 .4    SDLED_6_2 145-151 .4    DRUGID_3 152-155
        CATID_1_3 156-159       CATID_2_3 160-163       CATID_3_3 164-167
        ROUTE_3 168-169         TOXTEST_3 170-171       SDLED_1_3 172-173
        SDLED_2_3 174-177 .1    SDLED_3_3 178-182 .2    SDLED_4_3 183-189 .4
        SDLED_5_3 190-196 .4    SDLED_6_3 197-203 .4    DRUGID_4 204-207
        CATID_1_4 208-211       CATID_2_4 212-215       CATID_3_4 216-219
        ROUTE_4 220-221         TOXTEST_4 222-223       SDLED_1_4 224-225
        SDLED_2_4 226-229 .1    SDLED_3_4 230-234 .2    SDLED_4_4 235-241 .4
        SDLED_5_4 242-248 .4    SDLED_6_4 249-255 .4    DRUGID_5 256-259
        CATID_1_5 260-263       CATID_2_5 264-267       CATID_3_5 268-271
        ROUTE_5 272-273         TOXTEST_5 274-275       SDLED_1_5 276-277
        SDLED_2_5 278-281 .1    SDLED_3_5 282-286 .2    SDLED_4_5 287-293 .4
        SDLED_5_5 294-300 .4    SDLED_6_5 301-307 .4    DRUGID_6 308-311
        CATID_1_6 312-315       CATID_2_6 316-319       CATID_3_6 320-323
        ROUTE_6 324-325         TOXTEST_6 326-327       SDLED_1_6 328-329
        SDLED_2_6 330-333 .1    SDLED_3_6 334-338 .2    SDLED_4_6 339-345 .4
        SDLED_5_6 346-352 .4    SDLED_6_6 353-359 .4    DRUGID_7 360-363
        CATID_1_7 364-367       CATID_2_7 368-371       CATID_3_7 372-375
        ROUTE_7 376-377         TOXTEST_7 378-379       SDLED_1_7 380-381
        SDLED_2_7 382-385 .1    SDLED_3_7 386-390 .2    SDLED_4_7 391-397 .4
        SDLED_5_7 398-404 .4    SDLED_6_7 405-411 .4    DRUGID_8 412-415
        CATID_1_8 416-419       CATID_2_8 420-423       CATID_3_8 424-427
        ROUTE_8 428-429         TOXTEST_8 430-431       SDLED_1_8 432-433
        SDLED_2_8 434-437 .1    SDLED_3_8 438-442 .2    SDLED_4_8 443-449 .4
        SDLED_5_8 450-456 .4    SDLED_6_8 457-463 .4    DRUGID_9 464-467
        CATID_1_9 468-471       CATID_2_9 472-475       CATID_3_9 476-479
        ROUTE_9 480-481         TOXTEST_9 482-483       SDLED_1_9 484-485
        SDLED_2_9 486-489 .1    SDLED_3_9 490-494 .2    SDLED_4_9 495-501 .4
        SDLED_5_9 502-508 .4    SDLED_6_9 509-515 .4    DRUGID_10 516-519
        CATID_1_10 520-523      CATID_2_10 524-527      CATID_3_10 528-531
        ROUTE_10 532-533        TOXTEST_10 534-535      SDLED_1_10 536-537
        SDLED_2_10 538-541 .1   SDLED_3_10 542-546 .2   SDLED_4_10 547-553 .4
        SDLED_5_10 554-560 .4   SDLED_6_10 561-567 .4   DRUGID_11 568-571
        CATID_1_11 572-575      CATID_2_11 576-579      CATID_3_11 580-583
        ROUTE_11 584-585        TOXTEST_11 586-587      SDLED_1_11 588-589
        SDLED_2_11 590-593 .1   SDLED_3_11 594-598 .2   SDLED_4_11 599-605 .4
        SDLED_5_11 606-612 .4   SDLED_6_11 613-619 .4   DRUGID_12 620-623
        CATID_1_12 624-627      CATID_2_12 628-631      CATID_3_12 632-635
        ROUTE_12 636-637        TOXTEST_12 638-639      SDLED_1_12 640-641
        SDLED_2_12 642-645 .1   SDLED_3_12 646-650 .2   SDLED_4_12 651-657 .4
        SDLED_5_12 658-664 .4   SDLED_6_12 665-671 .4   DRUGID_13 672-675
        CATID_1_13 676-679      CATID_2_13 680-683      CATID_3_13 684-687
        ROUTE_13 688-689        TOXTEST_13 690-691      SDLED_1_13 692-693
        SDLED_2_13 694-697 .1   SDLED_3_13 698-702 .2   SDLED_4_13 703-709 .4
        SDLED_5_13 710-716 .4   SDLED_6_13 717-723 .4   DRUGID_14 724-727
        CATID_1_14 728-731      CATID_2_14 732-735      CATID_3_14 736-739
        ROUTE_14 740-741        TOXTEST_14 742-743      SDLED_1_14 744-745
        SDLED_2_14 746-749 .1   SDLED_3_14 750-754 .2   SDLED_4_14 755-761 .4
        SDLED_5_14 762-768 .4   SDLED_6_14 769-775 .4   DRUGID_15 776-779
        CATID_1_15 780-783      CATID_2_15 784-787      CATID_3_15 788-791
        ROUTE_15 792-793        TOXTEST_15 794-795      SDLED_1_15 796-797
        SDLED_2_15 798-801 .1   SDLED_3_15 802-806 .2   SDLED_4_15 807-813 .4
        SDLED_5_15 814-820 .4   SDLED_6_15 821-827 .4   DRUGID_16 828-831
        CATID_1_16 832-835      CATID_2_16 836-839      CATID_3_16 840-843
        ROUTE_16 844-845        TOXTEST_16 846-847      SDLED_1_16 848-849
        SDLED_2_16 850-853 .1   SDLED_3_16 854-858 .2   SDLED_4_16 859-865 .4
        SDLED_5_16 866-872 .4   SDLED_6_16 873-879 .4   DRUGID_17 880-883
        CATID_1_17 884-887      CATID_2_17 888-891      CATID_3_17 892-895
        ROUTE_17 896-897        TOXTEST_17 898-899      SDLED_1_17 900-901
        SDLED_2_17 902-905 .1   SDLED_3_17 906-910 .2   SDLED_4_17 911-917 .4
        SDLED_5_17 918-924 .4   SDLED_6_17 925-931 .4   DRUGID_18 932-935
        CATID_1_18 936-939      CATID_2_18 940-943      CATID_3_18 944-947
        ROUTE_18 948-949        TOXTEST_18 950-951      SDLED_1_18 952-953
        SDLED_2_18 954-957 .1   SDLED_3_18 958-962 .2   SDLED_4_18 963-969 .4
        SDLED_5_18 970-976 .4   SDLED_6_18 977-983 .4   DRUGID_19 984-987
        CATID_1_19 988-991      CATID_2_19 992-995      CATID_3_19 996-999
        ROUTE_19 1000-1001      TOXTEST_19 1002-1003    SDLED_1_19 1004-1005
        SDLED_2_19 1006-1009 .1 SDLED_3_19 1010-1014 .2 SDLED_4_19 1015-1021 .4
        SDLED_5_19 1022-1028 .4 SDLED_6_19 1029-1035 .4 DRUGID_20 1036-1039
        CATID_1_20 1040-1043    CATID_2_20 1044-1047    CATID_3_20 1048-1051
        ROUTE_20 1052-1053      TOXTEST_20 1054-1055    SDLED_1_20 1056-1057
        SDLED_2_20 1058-1061 .1 SDLED_3_20 1062-1066 .2 SDLED_4_20 1067-1073 .4
        SDLED_5_20 1074-1080 .4 SDLED_6_20 1081-1087 .4 DRUGID_21 1088-1091
        CATID_1_21 1092-1095    CATID_2_21 1096-1099    CATID_3_21 1100-1103
        ROUTE_21 1104-1105      TOXTEST_21 1106-1107    SDLED_1_21 1108-1109
        SDLED_2_21 1110-1113 .1 SDLED_3_21 1114-1118 .2 SDLED_4_21 1119-1125 .4
        SDLED_5_21 1126-1132 .4 SDLED_6_21 1133-1139 .4 DRUGID_22 1140-1143
        CATID_1_22 1144-1147    CATID_2_22 1148-1151    CATID_3_22 1152-1155
        ROUTE_22 1156-1157      TOXTEST_22 1158-1159    SDLED_1_22 1160-1161
        SDLED_2_22 1162-1165 .1 SDLED_3_22 1166-1170 .2 SDLED_4_22 1171-1177 .4
        SDLED_5_22 1178-1184 .4 SDLED_6_22 1185-1191 .4 CASETYPE 1192
        DISPOSITION 1193-1194   ALCOHOL 1195            NONALCILL 1196
        PHARMA 1197             NONMEDPHARMA 1198       ALLABUSE 1199
        ;


* SAS LABEL STATEMENT;

LABEL 
   CASEID  = 'CASE IDENTIFICATION NUMBER' 
   METRO   = 'OVERSAMPLED METROPOLITAN STATISTICAL AREA (MSA)' 
   STRATA  = 'VARIANCE ESTIMATION STRATUM' 
   PSU     = 'PRIMARY SAMPLING UNIT' 
   REPLICATE= 'REPLICATE' 
   CASEWGT = 'CASE WEIGHT' 
   PSUFRAME= 'PSU FRAME COUNT' 
   AGECAT  = 'AGE - CATEGORIZED' 
   SEX     = 'GENDER' 
   RACE    = 'RACE / ETHNICITY - RECODED' 
   YEAR    = 'YEAR OF ED VISIT' 
   QUARTER = 'QUARTER OF ED VISIT' 
   DAYPART = 'PART OF DAY OF ED VISIT' 
   NUMSUBS = 'UNIQUE NUMBER OF DRUGS REPORTED' 
   DRUGID_1= 'DRUG ID NUMBER MENTION 1' 
   CATID_1_1= 'MULTUM CATEGORY 1 CODE MENTION 1' 
   CATID_2_1= 'MULTUM CATEGORY 2 CODE MENTION 1' 
   CATID_3_1= 'MULTUM CATEGORY 3 CODE MENTION 1' 
   ROUTE_1 = 'ROUTE OF ADMINISTRATION MENTION 1' 
   TOXTEST_1= 'CONFIRMED BY TOXICOLOGY TEST MENTION 1' 
   SDLED_1_1= 'ED STANDARD DRUG LIST 1 CODE MENTION 1' 
   SDLED_2_1= 'ED STANDARD DRUG LIST 2 CODE MENTION 1' 
   SDLED_3_1= 'ED STANDARD DRUG LIST 3 CODE MENTION 1' 
   SDLED_4_1= 'ED STANDARD DRUG LIST 4 CODE MENTION 1' 
   SDLED_5_1= 'ED STANDARD DRUG LIST 5 CODE MENTION 1' 
   SDLED_6_1= 'ED STANDARD DRUG LIST 6 CODE MENTION 1' 
   DRUGID_2= 'DRUG ID NUMBER MENTION 2' 
   CATID_1_2= 'MULTUM CATEGORY 1 CODE MENTION 2' 
   CATID_2_2= 'MULTUM CATEGORY 2 CODE MENTION 2' 
   CATID_3_2= 'MULTUM CATEGORY 3 CODE MENTION 2' 
   ROUTE_2 = 'ROUTE OF ADMINISTRATION MENTION 2' 
   TOXTEST_2= 'CONFIRMED BY TOXICOLOGY TEST MENTION 2' 
   SDLED_1_2= 'ED STANDARD DRUG LIST 1 CODE MENTION 2' 
   SDLED_2_2= 'ED STANDARD DRUG LIST 2 CODE MENTION 2' 
   SDLED_3_2= 'ED STANDARD DRUG LIST 3 CODE MENTION 2' 
   SDLED_4_2= 'ED STANDARD DRUG LIST 4 CODE MENTION 2' 
   SDLED_5_2= 'ED STANDARD DRUG LIST 5 CODE MENTION 2' 
   SDLED_6_2= 'ED STANDARD DRUG LIST 6 CODE MENTION 2' 
   DRUGID_3= 'DRUG ID NUMBER MENTION 3' 
   CATID_1_3= 'MULTUM CATEGORY 1 CODE MENTION 3' 
   CATID_2_3= 'MULTUM CATEGORY 2 CODE MENTION 3' 
   CATID_3_3= 'MULTUM CATEGORY 3 CODE MENTION 3' 
   ROUTE_3 = 'ROUTE OF ADMINISTRATION MENTION 3' 
   TOXTEST_3= 'CONFIRMED BY TOXICOLOGY TEST MENTION 3' 
   SDLED_1_3= 'ED STANDARD DRUG LIST 1 CODE MENTION 3' 
   SDLED_2_3= 'ED STANDARD DRUG LIST 2 CODE MENTION 3' 
   SDLED_3_3= 'ED STANDARD DRUG LIST 3 CODE MENTION 3' 
   SDLED_4_3= 'ED STANDARD DRUG LIST 4 CODE MENTION 3' 
   SDLED_5_3= 'ED STANDARD DRUG LIST 5 CODE MENTION 3' 
   SDLED_6_3= 'ED STANDARD DRUG LIST 6 CODE MENTION 3' 
   DRUGID_4= 'DRUG ID NUMBER MENTION 4' 
   CATID_1_4= 'MULTUM CATEGORY 1 CODE MENTION 4' 
   CATID_2_4= 'MULTUM CATEGORY 2 CODE MENTION 4' 
   CATID_3_4= 'MULTUM CATEGORY 3 CODE MENTION 4' 
   ROUTE_4 = 'ROUTE OF ADMINISTRATION MENTION 4' 
   TOXTEST_4= 'CONFIRMED BY TOXICOLOGY TEST MENTION 4' 
   SDLED_1_4= 'ED STANDARD DRUG LIST 1 CODE MENTION 4' 
   SDLED_2_4= 'ED STANDARD DRUG LIST 2 CODE MENTION 4' 
   SDLED_3_4= 'ED STANDARD DRUG LIST 3 CODE MENTION 4' 
   SDLED_4_4= 'ED STANDARD DRUG LIST 4 CODE MENTION 4' 
   SDLED_5_4= 'ED STANDARD DRUG LIST 5 CODE MENTION 4' 
   SDLED_6_4= 'ED STANDARD DRUG LIST 6 CODE MENTION 4' 
   DRUGID_5= 'DRUG ID NUMBER MENTION 5' 
   CATID_1_5= 'MULTUM CATEGORY 1 CODE MENTION 5' 
   CATID_2_5= 'MULTUM CATEGORY 2 CODE MENTION 5' 
   CATID_3_5= 'MULTUM CATEGORY 3 CODE MENTION 5' 
   ROUTE_5 = 'ROUTE OF ADMINISTRATION MENTION 5' 
   TOXTEST_5= 'CONFIRMED BY TOXICOLOGY TEST MENTION 5' 
   SDLED_1_5= 'ED STANDARD DRUG LIST 1 CODE MENTION 5' 
   SDLED_2_5= 'ED STANDARD DRUG LIST 2 CODE MENTION 5' 
   SDLED_3_5= 'ED STANDARD DRUG LIST 3 CODE MENTION 5' 
   SDLED_4_5= 'ED STANDARD DRUG LIST 4 CODE MENTION 5' 
   SDLED_5_5= 'ED STANDARD DRUG LIST 5 CODE MENTION 5' 
   SDLED_6_5= 'ED STANDARD DRUG LIST 6 CODE MENTION 5' 
   DRUGID_6= 'DRUG ID NUMBER MENTION 6' 
   CATID_1_6= 'MULTUM CATEGORY 1 CODE MENTION 6' 
   CATID_2_6= 'MULTUM CATEGORY 2 CODE MENTION 6' 
   CATID_3_6= 'MULTUM CATEGORY 3 CODE MENTION 6' 
   ROUTE_6 = 'ROUTE OF ADMINISTRATION MENTION 6' 
   TOXTEST_6= 'CONFIRMED BY TOXICOLOGY TEST MENTION 6' 
   SDLED_1_6= 'ED STANDARD DRUG LIST 1 CODE MENTION 6' 
   SDLED_2_6= 'ED STANDARD DRUG LIST 2 CODE MENTION 6' 
   SDLED_3_6= 'ED STANDARD DRUG LIST 3 CODE MENTION 6' 
   SDLED_4_6= 'ED STANDARD DRUG LIST 4 CODE MENTION 6' 
   SDLED_5_6= 'ED STANDARD DRUG LIST 5 CODE MENTION 6' 
   SDLED_6_6= 'ED STANDARD DRUG LIST 6 CODE MENTION 6' 
   DRUGID_7= 'DRUG ID NUMBER MENTION 7' 
   CATID_1_7= 'MULTUM CATEGORY 1 CODE MENTION 7' 
   CATID_2_7= 'MULTUM CATEGORY 2 CODE MENTION 7' 
   CATID_3_7= 'MULTUM CATEGORY 3 CODE MENTION 7' 
   ROUTE_7 = 'ROUTE OF ADMINISTRATION MENTION 7' 
   TOXTEST_7= 'CONFIRMED BY TOXICOLOGY TEST MENTION 7' 
   SDLED_1_7= 'ED STANDARD DRUG LIST 1 CODE MENTION 7' 
   SDLED_2_7= 'ED STANDARD DRUG LIST 2 CODE MENTION 7' 
   SDLED_3_7= 'ED STANDARD DRUG LIST 3 CODE MENTION 7' 
   SDLED_4_7= 'ED STANDARD DRUG LIST 4 CODE MENTION 7' 
   SDLED_5_7= 'ED STANDARD DRUG LIST 5 CODE MENTION 7' 
   SDLED_6_7= 'ED STANDARD DRUG LIST 6 CODE MENTION 7' 
   DRUGID_8= 'DRUG ID NUMBER MENTION 8' 
   CATID_1_8= 'MULTUM CATEGORY 1 CODE MENTION 8' 
   CATID_2_8= 'MULTUM CATEGORY 2 CODE MENTION 8' 
   CATID_3_8= 'MULTUM CATEGORY 3 CODE MENTION 8' 
   ROUTE_8 = 'ROUTE OF ADMINISTRATION MENTION 8' 
   TOXTEST_8= 'CONFIRMED BY TOXICOLOGY TEST MENTION 8' 
   SDLED_1_8= 'ED STANDARD DRUG LIST 1 CODE MENTION 8' 
   SDLED_2_8= 'ED STANDARD DRUG LIST 2 CODE MENTION 8' 
   SDLED_3_8= 'ED STANDARD DRUG LIST 3 CODE MENTION 8' 
   SDLED_4_8= 'ED STANDARD DRUG LIST 4 CODE MENTION 8' 
   SDLED_5_8= 'ED STANDARD DRUG LIST 5 CODE MENTION 8' 
   SDLED_6_8= 'ED STANDARD DRUG LIST 6 CODE MENTION 8' 
   DRUGID_9= 'DRUG ID NUMBER MENTION 9' 
   CATID_1_9= 'MULTUM CATEGORY 1 CODE MENTION 9' 
   CATID_2_9= 'MULTUM CATEGORY 2 CODE MENTION 9' 
   CATID_3_9= 'MULTUM CATEGORY 3 CODE MENTION 9' 
   ROUTE_9 = 'ROUTE OF ADMINISTRATION MENTION 9' 
   TOXTEST_9= 'CONFIRMED BY TOXICOLOGY TEST MENTION 9' 
   SDLED_1_9= 'ED STANDARD DRUG LIST 1 CODE MENTION 9' 
   SDLED_2_9= 'ED STANDARD DRUG LIST 2 CODE MENTION 9' 
   SDLED_3_9= 'ED STANDARD DRUG LIST 3 CODE MENTION 9' 
   SDLED_4_9= 'ED STANDARD DRUG LIST 4 CODE MENTION 9' 
   SDLED_5_9= 'ED STANDARD DRUG LIST 5 CODE MENTION 9' 
   SDLED_6_9= 'ED STANDARD DRUG LIST 6 CODE MENTION 9' 
   DRUGID_10= 'DRUG ID NUMBER MENTION 10' 
   CATID_1_10= 'MULTUM CATEGORY 1 CODE MENTION 10' 
   CATID_2_10= 'MULTUM CATEGORY 2 CODE MENTION 10' 
   CATID_3_10= 'MULTUM CATEGORY 3 CODE MENTION 10' 
   ROUTE_10= 'ROUTE OF ADMINISTRATION MENTION 10' 
   TOXTEST_10= 'CONFIRMED BY TOXICOLOGY TEST MENTION 10' 
   SDLED_1_10= 'ED STANDARD DRUG LIST 1 CODE MENTION 10' 
   SDLED_2_10= 'ED STANDARD DRUG LIST 2 CODE MENTION 10' 
   SDLED_3_10= 'ED STANDARD DRUG LIST 3 CODE MENTION 10' 
   SDLED_4_10= 'ED STANDARD DRUG LIST 4 CODE MENTION 10' 
   SDLED_5_10= 'ED STANDARD DRUG LIST 5 CODE MENTION 10' 
   SDLED_6_10= 'ED STANDARD DRUG LIST 6 CODE MENTION 10' 
   DRUGID_11= 'DRUG ID NUMBER MENTION 11' 
   CATID_1_11= 'MULTUM CATEGORY 1 CODE MENTION 11' 
   CATID_2_11= 'MULTUM CATEGORY 2 CODE MENTION 11' 
   CATID_3_11= 'MULTUM CATEGORY 3 CODE MENTION 11' 
   ROUTE_11= 'ROUTE OF ADMINISTRATION MENTION 11' 
   TOXTEST_11= 'CONFIRMED BY TOXICOLOGY TEST MENTION 11' 
   SDLED_1_11= 'ED STANDARD DRUG LIST 1 CODE MENTION 11' 
   SDLED_2_11= 'ED STANDARD DRUG LIST 2 CODE MENTION 11' 
   SDLED_3_11= 'ED STANDARD DRUG LIST 3 CODE MENTION 11' 
   SDLED_4_11= 'ED STANDARD DRUG LIST 4 CODE MENTION 11' 
   SDLED_5_11= 'ED STANDARD DRUG LIST 5 CODE MENTION 11' 
   SDLED_6_11= 'ED STANDARD DRUG LIST 6 CODE MENTION 11' 
   DRUGID_12= 'DRUG ID NUMBER MENTION 12' 
   CATID_1_12= 'MULTUM CATEGORY 1 CODE MENTION 12' 
   CATID_2_12= 'MULTUM CATEGORY 2 CODE MENTION 12' 
   CATID_3_12= 'MULTUM CATEGORY 3 CODE MENTION 12' 
   ROUTE_12= 'ROUTE OF ADMINISTRATION MENTION 12' 
   TOXTEST_12= 'CONFIRMED BY TOXICOLOGY TEST MENTION 12' 
   SDLED_1_12= 'ED STANDARD DRUG LIST 1 CODE MENTION 12' 
   SDLED_2_12= 'ED STANDARD DRUG LIST 2 CODE MENTION 12' 
   SDLED_3_12= 'ED STANDARD DRUG LIST 3 CODE MENTION 12' 
   SDLED_4_12= 'ED STANDARD DRUG LIST 4 CODE MENTION 12' 
   SDLED_5_12= 'ED STANDARD DRUG LIST 5 CODE MENTION 12' 
   SDLED_6_12= 'ED STANDARD DRUG LIST 6 CODE MENTION 12' 
   DRUGID_13= 'DRUG ID NUMBER MENTION 13' 
   CATID_1_13= 'MULTUM CATEGORY 1 CODE MENTION 13' 
   CATID_2_13= 'MULTUM CATEGORY 2 CODE MENTION 13' 
   CATID_3_13= 'MULTUM CATEGORY 3 CODE MENTION 13' 
   ROUTE_13= 'ROUTE OF ADMINISTRATION MENTION 13' 
   TOXTEST_13= 'CONFIRMED BY TOXICOLOGY TEST MENTION 13' 
   SDLED_1_13= 'ED STANDARD DRUG LIST 1 CODE MENTION 13' 
   SDLED_2_13= 'ED STANDARD DRUG LIST 2 CODE MENTION 13' 
   SDLED_3_13= 'ED STANDARD DRUG LIST 3 CODE MENTION 13' 
   SDLED_4_13= 'ED STANDARD DRUG LIST 4 CODE MENTION 13' 
   SDLED_5_13= 'ED STANDARD DRUG LIST 5 CODE MENTION 13' 
   SDLED_6_13= 'ED STANDARD DRUG LIST 6 CODE MENTION 13' 
   DRUGID_14= 'DRUG ID NUMBER MENTION 14' 
   CATID_1_14= 'MULTUM CATEGORY 1 CODE MENTION 14' 
   CATID_2_14= 'MULTUM CATEGORY 2 CODE MENTION 14' 
   CATID_3_14= 'MULTUM CATEGORY 3 CODE MENTION 14' 
   ROUTE_14= 'ROUTE OF ADMINISTRATION MENTION 14' 
   TOXTEST_14= 'CONFIRMED BY TOXICOLOGY TEST MENTION 14' 
   SDLED_1_14= 'ED STANDARD DRUG LIST 1 CODE MENTION 14' 
   SDLED_2_14= 'ED STANDARD DRUG LIST 2 CODE MENTION 14' 
   SDLED_3_14= 'ED STANDARD DRUG LIST 3 CODE MENTION 14' 
   SDLED_4_14= 'ED STANDARD DRUG LIST 4 CODE MENTION 14' 
   SDLED_5_14= 'ED STANDARD DRUG LIST 5 CODE MENTION 14' 
   SDLED_6_14= 'ED STANDARD DRUG LIST 6 CODE MENTION 14' 
   DRUGID_15= 'DRUG ID NUMBER MENTION 15' 
   CATID_1_15= 'MULTUM CATEGORY 1 CODE MENTION 15' 
   CATID_2_15= 'MULTUM CATEGORY 2 CODE MENTION 15' 
   CATID_3_15= 'MULTUM CATEGORY 3 CODE MENTION 15' 
   ROUTE_15= 'ROUTE OF ADMINISTRATION MENTION 15' 
   TOXTEST_15= 'CONFIRMED BY TOXICOLOGY TEST MENTION 15' 
   SDLED_1_15= 'ED STANDARD DRUG LIST 1 CODE MENTION 15' 
   SDLED_2_15= 'ED STANDARD DRUG LIST 2 CODE MENTION 15' 
   SDLED_3_15= 'ED STANDARD DRUG LIST 3 CODE MENTION 15' 
   SDLED_4_15= 'ED STANDARD DRUG LIST 4 CODE MENTION 15' 
   SDLED_5_15= 'ED STANDARD DRUG LIST 5 CODE MENTION 15' 
   SDLED_6_15= 'ED STANDARD DRUG LIST 6 CODE MENTION 15' 
   DRUGID_16= 'DRUG ID NUMBER MENTION 16' 
   CATID_1_16= 'MULTUM CATEGORY 1 CODE MENTION 16' 
   CATID_2_16= 'MULTUM CATEGORY 2 CODE MENTION 16' 
   CATID_3_16= 'MULTUM CATEGORY 3 CODE MENTION 16' 
   ROUTE_16= 'ROUTE OF ADMINISTRATION MENTION 16' 
   TOXTEST_16= 'CONFIRMED BY TOXICOLOGY TEST MENTION 16' 
   SDLED_1_16= 'ED STANDARD DRUG LIST 1 CODE MENTION 16' 
   SDLED_2_16= 'ED STANDARD DRUG LIST 2 CODE MENTION 16' 
   SDLED_3_16= 'ED STANDARD DRUG LIST 3 CODE MENTION 16' 
   SDLED_4_16= 'ED STANDARD DRUG LIST 4 CODE MENTION 16' 
   SDLED_5_16= 'ED STANDARD DRUG LIST 5 CODE MENTION 16' 
   SDLED_6_16= 'ED STANDARD DRUG LIST 6 CODE MENTION 16' 
   DRUGID_17= 'DRUG ID NUMBER MENTION 17' 
   CATID_1_17= 'MULTUM CATEGORY 1 CODE MENTION 17' 
   CATID_2_17= 'MULTUM CATEGORY 2 CODE MENTION 17' 
   CATID_3_17= 'MULTUM CATEGORY 3 CODE MENTION 17' 
   ROUTE_17= 'ROUTE OF ADMINISTRATION MENTION 17' 
   TOXTEST_17= 'CONFIRMED BY TOXICOLOGY TEST MENTION 17' 
   SDLED_1_17= 'ED STANDARD DRUG LIST 1 CODE MENTION 17' 
   SDLED_2_17= 'ED STANDARD DRUG LIST 2 CODE MENTION 17' 
   SDLED_3_17= 'ED STANDARD DRUG LIST 3 CODE MENTION 17' 
   SDLED_4_17= 'ED STANDARD DRUG LIST 4 CODE MENTION 17' 
   SDLED_5_17= 'ED STANDARD DRUG LIST 5 CODE MENTION 17' 
   SDLED_6_17= 'ED STANDARD DRUG LIST 6 CODE MENTION 17' 
   DRUGID_18= 'DRUG ID NUMBER MENTION 18' 
   CATID_1_18= 'MULTUM CATEGORY 1 CODE MENTION 18' 
   CATID_2_18= 'MULTUM CATEGORY 2 CODE MENTION 18' 
   CATID_3_18= 'MULTUM CATEGORY 3 CODE MENTION 18' 
   ROUTE_18= 'ROUTE OF ADMINISTRATION MENTION 18' 
   TOXTEST_18= 'CONFIRMED BY TOXICOLOGY TEST MENTION 18' 
   SDLED_1_18= 'ED STANDARD DRUG LIST 1 CODE MENTION 18' 
   SDLED_2_18= 'ED STANDARD DRUG LIST 2 CODE MENTION 18' 
   SDLED_3_18= 'ED STANDARD DRUG LIST 3 CODE MENTION 18' 
   SDLED_4_18= 'ED STANDARD DRUG LIST 4 CODE MENTION 18' 
   SDLED_5_18= 'ED STANDARD DRUG LIST 5 CODE MENTION 18' 
   SDLED_6_18= 'ED STANDARD DRUG LIST 6 CODE MENTION 18' 
   DRUGID_19= 'DRUG ID NUMBER MENTION 19' 
   CATID_1_19= 'MULTUM CATEGORY 1 CODE MENTION 19' 
   CATID_2_19= 'MULTUM CATEGORY 2 CODE MENTION 19' 
   CATID_3_19= 'MULTUM CATEGORY 3 CODE MENTION 19' 
   ROUTE_19= 'ROUTE OF ADMINISTRATION MENTION 19' 
   TOXTEST_19= 'CONFIRMED BY TOXICOLOGY TEST MENTION 19' 
   SDLED_1_19= 'ED STANDARD DRUG LIST 1 CODE MENTION 19' 
   SDLED_2_19= 'ED STANDARD DRUG LIST 2 CODE MENTION 19' 
   SDLED_3_19= 'ED STANDARD DRUG LIST 3 CODE MENTION 19' 
   SDLED_4_19= 'ED STANDARD DRUG LIST 4 CODE MENTION 19' 
   SDLED_5_19= 'ED STANDARD DRUG LIST 5 CODE MENTION 19' 
   SDLED_6_19= 'ED STANDARD DRUG LIST 6 CODE MENTION 19' 
   DRUGID_20= 'DRUG ID NUMBER MENTION 20' 
   CATID_1_20= 'MULTUM CATEGORY 1 CODE MENTION 20' 
   CATID_2_20= 'MULTUM CATEGORY 2 CODE MENTION 20' 
   CATID_3_20= 'MULTUM CATEGORY 3 CODE MENTION 20' 
   ROUTE_20= 'ROUTE OF ADMINISTRATION MENTION 20' 
   TOXTEST_20= 'CONFIRMED BY TOXICOLOGY TEST MENTION 20' 
   SDLED_1_20= 'ED STANDARD DRUG LIST 1 CODE MENTION 20' 
   SDLED_2_20= 'ED STANDARD DRUG LIST 2 CODE MENTION 20' 
   SDLED_3_20= 'ED STANDARD DRUG LIST 3 CODE MENTION 20' 
   SDLED_4_20= 'ED STANDARD DRUG LIST 4 CODE MENTION 20' 
   SDLED_5_20= 'ED STANDARD DRUG LIST 5 CODE MENTION 20' 
   SDLED_6_20= 'ED STANDARD DRUG LIST 6 CODE MENTION 20' 
   DRUGID_21= 'DRUG ID NUMBER MENTION 21' 
   CATID_1_21= 'MULTUM CATEGORY 1 CODE MENTION 21' 
   CATID_2_21= 'MULTUM CATEGORY 2 CODE MENTION 21' 
   CATID_3_21= 'MULTUM CATEGORY 3 CODE MENTION 21' 
   ROUTE_21= 'ROUTE OF ADMINISTRATION MENTION 21' 
   TOXTEST_21= 'CONFIRMED BY TOXICOLOGY TEST MENTION 21' 
   SDLED_1_21= 'ED STANDARD DRUG LIST 1 CODE MENTION 21' 
   SDLED_2_21= 'ED STANDARD DRUG LIST 2 CODE MENTION 21' 
   SDLED_3_21= 'ED STANDARD DRUG LIST 3 CODE MENTION 21' 
   SDLED_4_21= 'ED STANDARD DRUG LIST 4 CODE MENTION 21' 
   SDLED_5_21= 'ED STANDARD DRUG LIST 5 CODE MENTION 21' 
   SDLED_6_21= 'ED STANDARD DRUG LIST 6 CODE MENTION 21' 
   DRUGID_22= 'DRUG ID NUMBER MENTION 22' 
   CATID_1_22= 'MULTUM CATEGORY 1 CODE MENTION 22' 
   CATID_2_22= 'MULTUM CATEGORY 2 CODE MENTION 22' 
   CATID_3_22= 'MULTUM CATEGORY 3 CODE MENTION 22' 
   ROUTE_22= 'ROUTE OF ADMINISTRATION MENTION 22' 
   TOXTEST_22= 'CONFIRMED BY TOXICOLOGY TEST MENTION 22' 
   SDLED_1_22= 'ED STANDARD DRUG LIST 1 CODE MENTION 22' 
   SDLED_2_22= 'ED STANDARD DRUG LIST 2 CODE MENTION 22' 
   SDLED_3_22= 'ED STANDARD DRUG LIST 3 CODE MENTION 22' 
   SDLED_4_22= 'ED STANDARD DRUG LIST 4 CODE MENTION 22' 
   SDLED_5_22= 'ED STANDARD DRUG LIST 5 CODE MENTION 22' 
   SDLED_6_22= 'ED STANDARD DRUG LIST 6 CODE MENTION 22' 
   CASETYPE= 'TYPE OF VISIT' 
   DISPOSITION= 'PATIENT DISPOSITION' 
   ALCOHOL = 'VISIT INCLUDES ALCOHOL MENTION INDICATOR' 
   NONALCILL= 'NON-ALCOHOL ILLICIT INDICATOR' 
   PHARMA  = 'ANY PHARMACEUTICALS INDICATOR' 
   NONMEDPHARMA= 'NON-MEDICAL USE OF PHARMACEUTICALS INDICATOR' 
   ALLABUSE= 'ALL MISUSE AND ABUSE INDICATOR' 
        ; 


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (AGECAT <= -1) THEN AGECAT = .;
   IF (SEX <= -1) THEN SEX = .;
   IF (RACE <= -1) THEN RACE = .;
   IF (DRUGID_1 <= -1) THEN DRUGID_1 = .;
   IF (CATID_1_1 <= -1) THEN CATID_1_1 = .;
   IF (CATID_2_1 <= -1) THEN CATID_2_1 = .;
   IF (CATID_3_1 <= -1) THEN CATID_3_1 = .;
   IF (ROUTE_1 <= -1) THEN ROUTE_1 = .;
   IF (TOXTEST_1 <= -1) THEN TOXTEST_1 = .;
   IF (SDLED_1_1 <= -1) THEN SDLED_1_1 = .;
   IF (SDLED_2_1 <= -1.0) THEN SDLED_2_1 = .;
   IF (SDLED_3_1 <= -1.00) THEN SDLED_3_1 = .;
   IF (SDLED_4_1 <= -1.0000) THEN SDLED_4_1 = .;
   IF (SDLED_5_1 <= -1.0000) THEN SDLED_5_1 = .;
   IF (SDLED_6_1 <= -1.0000) THEN SDLED_6_1 = .;
   IF (DRUGID_2 <= -1) THEN DRUGID_2 = .;
   IF (CATID_1_2 <= -1) THEN CATID_1_2 = .;
   IF (CATID_2_2 <= -1) THEN CATID_2_2 = .;
   IF (CATID_3_2 <= -1) THEN CATID_3_2 = .;
   IF (ROUTE_2 <= -1) THEN ROUTE_2 = .;
   IF (TOXTEST_2 <= -1) THEN TOXTEST_2 = .;
   IF (SDLED_1_2 <= -1) THEN SDLED_1_2 = .;
   IF (SDLED_2_2 <= -1.0) THEN SDLED_2_2 = .;
   IF (SDLED_3_2 <= -1.00) THEN SDLED_3_2 = .;
   IF (SDLED_4_2 <= -1.0000) THEN SDLED_4_2 = .;
   IF (SDLED_5_2 <= -1.0000) THEN SDLED_5_2 = .;
   IF (SDLED_6_2 <= -1.0000) THEN SDLED_6_2 = .;
   IF (DRUGID_3 <= -1) THEN DRUGID_3 = .;
   IF (CATID_1_3 <= -1) THEN CATID_1_3 = .;
   IF (CATID_2_3 <= -1) THEN CATID_2_3 = .;
   IF (CATID_3_3 <= -1) THEN CATID_3_3 = .;
   IF (ROUTE_3 <= -1) THEN ROUTE_3 = .;
   IF (TOXTEST_3 <= -1) THEN TOXTEST_3 = .;
   IF (SDLED_1_3 <= -1) THEN SDLED_1_3 = .;
   IF (SDLED_2_3 <= -1.0) THEN SDLED_2_3 = .;
   IF (SDLED_3_3 <= -1.00) THEN SDLED_3_3 = .;
   IF (SDLED_4_3 <= -1.0000) THEN SDLED_4_3 = .;
   IF (SDLED_5_3 <= -1.0000) THEN SDLED_5_3 = .;
   IF (SDLED_6_3 <= -1.0000) THEN SDLED_6_3 = .;
   IF (DRUGID_4 <= -1) THEN DRUGID_4 = .;
   IF (CATID_1_4 <= -1) THEN CATID_1_4 = .;
   IF (CATID_2_4 <= -1) THEN CATID_2_4 = .;
   IF (CATID_3_4 <= -1) THEN CATID_3_4 = .;
   IF (ROUTE_4 <= -1) THEN ROUTE_4 = .;
   IF (TOXTEST_4 <= -1) THEN TOXTEST_4 = .;
   IF (SDLED_1_4 <= -1) THEN SDLED_1_4 = .;
   IF (SDLED_2_4 <= -1.0) THEN SDLED_2_4 = .;
   IF (SDLED_3_4 <= -1.00) THEN SDLED_3_4 = .;
   IF (SDLED_4_4 <= -1.0000) THEN SDLED_4_4 = .;
   IF (SDLED_5_4 <= -1.0000) THEN SDLED_5_4 = .;
   IF (SDLED_6_4 <= -1.0000) THEN SDLED_6_4 = .;
   IF (DRUGID_5 <= -1) THEN DRUGID_5 = .;
   IF (CATID_1_5 <= -1) THEN CATID_1_5 = .;
   IF (CATID_2_5 <= -1) THEN CATID_2_5 = .;
   IF (CATID_3_5 <= -1) THEN CATID_3_5 = .;
   IF (ROUTE_5 <= -1) THEN ROUTE_5 = .;
   IF (TOXTEST_5 <= -1) THEN TOXTEST_5 = .;
   IF (SDLED_1_5 <= -1) THEN SDLED_1_5 = .;
   IF (SDLED_2_5 <= -1.0) THEN SDLED_2_5 = .;
   IF (SDLED_3_5 <= -1.00) THEN SDLED_3_5 = .;
   IF (SDLED_4_5 <= -1.0000) THEN SDLED_4_5 = .;
   IF (SDLED_5_5 <= -1.0000) THEN SDLED_5_5 = .;
   IF (SDLED_6_5 <= -1.0000) THEN SDLED_6_5 = .;
   IF (DRUGID_6 <= -1) THEN DRUGID_6 = .;
   IF (CATID_1_6 <= -1) THEN CATID_1_6 = .;
   IF (CATID_2_6 <= -1) THEN CATID_2_6 = .;
   IF (CATID_3_6 <= -1) THEN CATID_3_6 = .;
   IF (ROUTE_6 <= -1) THEN ROUTE_6 = .;
   IF (TOXTEST_6 <= -1) THEN TOXTEST_6 = .;
   IF (SDLED_1_6 <= -1) THEN SDLED_1_6 = .;
   IF (SDLED_2_6 <= -1.0) THEN SDLED_2_6 = .;
   IF (SDLED_3_6 <= -1.00) THEN SDLED_3_6 = .;
   IF (SDLED_4_6 <= -1.0000) THEN SDLED_4_6 = .;
   IF (SDLED_5_6 <= -1.0000) THEN SDLED_5_6 = .;
   IF (SDLED_6_6 <= -1.0000) THEN SDLED_6_6 = .;
   IF (DRUGID_7 <= -1) THEN DRUGID_7 = .;
   IF (CATID_1_7 <= -1) THEN CATID_1_7 = .;
   IF (CATID_2_7 <= -1) THEN CATID_2_7 = .;
   IF (CATID_3_7 <= -1) THEN CATID_3_7 = .;
   IF (ROUTE_7 <= -1) THEN ROUTE_7 = .;
   IF (TOXTEST_7 <= -1) THEN TOXTEST_7 = .;
   IF (SDLED_1_7 <= -1) THEN SDLED_1_7 = .;
   IF (SDLED_2_7 <= -1.0) THEN SDLED_2_7 = .;
   IF (SDLED_3_7 <= -1.00) THEN SDLED_3_7 = .;
   IF (SDLED_4_7 <= -1.0000) THEN SDLED_4_7 = .;
   IF (SDLED_5_7 <= -1.0000) THEN SDLED_5_7 = .;
   IF (SDLED_6_7 <= -1.0000) THEN SDLED_6_7 = .;
   IF (DRUGID_8 <= -1) THEN DRUGID_8 = .;
   IF (CATID_1_8 <= -1) THEN CATID_1_8 = .;
   IF (CATID_2_8 <= -1) THEN CATID_2_8 = .;
   IF (CATID_3_8 <= -1) THEN CATID_3_8 = .;
   IF (ROUTE_8 <= -1) THEN ROUTE_8 = .;
   IF (TOXTEST_8 <= -1) THEN TOXTEST_8 = .;
   IF (SDLED_1_8 <= -1) THEN SDLED_1_8 = .;
   IF (SDLED_2_8 <= -1.0) THEN SDLED_2_8 = .;
   IF (SDLED_3_8 <= -1.00) THEN SDLED_3_8 = .;
   IF (SDLED_4_8 <= -1.0000) THEN SDLED_4_8 = .;
   IF (SDLED_5_8 <= -1.0000) THEN SDLED_5_8 = .;
   IF (SDLED_6_8 <= -1.0000) THEN SDLED_6_8 = .;
   IF (DRUGID_9 <= -1) THEN DRUGID_9 = .;
   IF (CATID_1_9 <= -1) THEN CATID_1_9 = .;
   IF (CATID_2_9 <= -1) THEN CATID_2_9 = .;
   IF (CATID_3_9 <= -1) THEN CATID_3_9 = .;
   IF (ROUTE_9 <= -1) THEN ROUTE_9 = .;
   IF (TOXTEST_9 <= -1) THEN TOXTEST_9 = .;
   IF (SDLED_1_9 <= -1) THEN SDLED_1_9 = .;
   IF (SDLED_2_9 <= -1.0) THEN SDLED_2_9 = .;
   IF (SDLED_3_9 <= -1.00) THEN SDLED_3_9 = .;
   IF (SDLED_4_9 <= -1.0000) THEN SDLED_4_9 = .;
   IF (SDLED_5_9 <= -1.0000) THEN SDLED_5_9 = .;
   IF (SDLED_6_9 <= -1.0000) THEN SDLED_6_9 = .;
   IF (DRUGID_10 <= -1) THEN DRUGID_10 = .;
   IF (CATID_1_10 <= -1) THEN CATID_1_10 = .;
   IF (CATID_2_10 <= -1) THEN CATID_2_10 = .;
   IF (CATID_3_10 <= -1) THEN CATID_3_10 = .;
   IF (ROUTE_10 <= -1) THEN ROUTE_10 = .;
   IF (TOXTEST_10 <= -1) THEN TOXTEST_10 = .;
   IF (SDLED_1_10 <= -1) THEN SDLED_1_10 = .;
   IF (SDLED_2_10 <= -1.0) THEN SDLED_2_10 = .;
   IF (SDLED_3_10 <= -1.00) THEN SDLED_3_10 = .;
   IF (SDLED_4_10 <= -1.0000) THEN SDLED_4_10 = .;
   IF (SDLED_5_10 <= -1.0000) THEN SDLED_5_10 = .;
   IF (SDLED_6_10 <= -1.0000) THEN SDLED_6_10 = .;
   IF (DRUGID_11 <= -1) THEN DRUGID_11 = .;
   IF (CATID_1_11 <= -1) THEN CATID_1_11 = .;
   IF (CATID_2_11 <= -1) THEN CATID_2_11 = .;
   IF (CATID_3_11 <= -1) THEN CATID_3_11 = .;
   IF (ROUTE_11 <= -1) THEN ROUTE_11 = .;
   IF (TOXTEST_11 <= -1) THEN TOXTEST_11 = .;
   IF (SDLED_1_11 <= -1) THEN SDLED_1_11 = .;
   IF (SDLED_2_11 <= -1.0) THEN SDLED_2_11 = .;
   IF (SDLED_3_11 <= -1.00) THEN SDLED_3_11 = .;
   IF (SDLED_4_11 <= -1.0000) THEN SDLED_4_11 = .;
   IF (SDLED_5_11 <= -1.0000) THEN SDLED_5_11 = .;
   IF (SDLED_6_11 <= -1.0000) THEN SDLED_6_11 = .;
   IF (DRUGID_12 <= -1) THEN DRUGID_12 = .;
   IF (CATID_1_12 <= -1) THEN CATID_1_12 = .;
   IF (CATID_2_12 <= -1) THEN CATID_2_12 = .;
   IF (CATID_3_12 <= -1) THEN CATID_3_12 = .;
   IF (ROUTE_12 <= -1) THEN ROUTE_12 = .;
   IF (TOXTEST_12 <= -1) THEN TOXTEST_12 = .;
   IF (SDLED_1_12 <= -1) THEN SDLED_1_12 = .;
   IF (SDLED_2_12 <= -1.0) THEN SDLED_2_12 = .;
   IF (SDLED_3_12 <= -1.00) THEN SDLED_3_12 = .;
   IF (SDLED_4_12 <= -1.0000) THEN SDLED_4_12 = .;
   IF (SDLED_5_12 <= -1.0000) THEN SDLED_5_12 = .;
   IF (SDLED_6_12 <= -1.0000) THEN SDLED_6_12 = .;
   IF (DRUGID_13 <= -1) THEN DRUGID_13 = .;
   IF (CATID_1_13 <= -1) THEN CATID_1_13 = .;
   IF (CATID_2_13 <= -1) THEN CATID_2_13 = .;
   IF (CATID_3_13 <= -1) THEN CATID_3_13 = .;
   IF (ROUTE_13 <= -1) THEN ROUTE_13 = .;
   IF (TOXTEST_13 <= -1) THEN TOXTEST_13 = .;
   IF (SDLED_1_13 <= -1) THEN SDLED_1_13 = .;
   IF (SDLED_2_13 <= -1.0) THEN SDLED_2_13 = .;
   IF (SDLED_3_13 <= -1.00) THEN SDLED_3_13 = .;
   IF (SDLED_4_13 <= -1.0000) THEN SDLED_4_13 = .;
   IF (SDLED_5_13 <= -1.0000) THEN SDLED_5_13 = .;
   IF (SDLED_6_13 <= -1.0000) THEN SDLED_6_13 = .;
   IF (DRUGID_14 <= -1) THEN DRUGID_14 = .;
   IF (CATID_1_14 <= -1) THEN CATID_1_14 = .;
   IF (CATID_2_14 <= -1) THEN CATID_2_14 = .;
   IF (CATID_3_14 <= -1) THEN CATID_3_14 = .;
   IF (ROUTE_14 <= -1) THEN ROUTE_14 = .;
   IF (TOXTEST_14 <= -1) THEN TOXTEST_14 = .;
   IF (SDLED_1_14 <= -1) THEN SDLED_1_14 = .;
   IF (SDLED_2_14 <= -1.0) THEN SDLED_2_14 = .;
   IF (SDLED_3_14 <= -1.00) THEN SDLED_3_14 = .;
   IF (SDLED_4_14 <= -1.0000) THEN SDLED_4_14 = .;
   IF (SDLED_5_14 <= -1.0000) THEN SDLED_5_14 = .;
   IF (SDLED_6_14 <= -1.0000) THEN SDLED_6_14 = .;
   IF (DRUGID_15 <= -1) THEN DRUGID_15 = .;
   IF (CATID_1_15 <= -1) THEN CATID_1_15 = .;
   IF (CATID_2_15 <= -1) THEN CATID_2_15 = .;
   IF (CATID_3_15 <= -1) THEN CATID_3_15 = .;
   IF (ROUTE_15 <= -1) THEN ROUTE_15 = .;
   IF (TOXTEST_15 <= -1) THEN TOXTEST_15 = .;
   IF (SDLED_1_15 <= -1) THEN SDLED_1_15 = .;
   IF (SDLED_2_15 <= -1.0) THEN SDLED_2_15 = .;
   IF (SDLED_3_15 <= -1.00) THEN SDLED_3_15 = .;
   IF (SDLED_4_15 <= -1.0000) THEN SDLED_4_15 = .;
   IF (SDLED_5_15 <= -1.0000) THEN SDLED_5_15 = .;
   IF (SDLED_6_15 <= -1.0000) THEN SDLED_6_15 = .;
   IF (DRUGID_16 <= -1) THEN DRUGID_16 = .;
   IF (CATID_1_16 <= -1) THEN CATID_1_16 = .;
   IF (CATID_2_16 <= -1) THEN CATID_2_16 = .;
   IF (CATID_3_16 <= -1) THEN CATID_3_16 = .;
   IF (ROUTE_16 <= -1) THEN ROUTE_16 = .;
   IF (TOXTEST_16 <= -1) THEN TOXTEST_16 = .;
   IF (SDLED_1_16 <= -1) THEN SDLED_1_16 = .;
   IF (SDLED_2_16 <= -1.0) THEN SDLED_2_16 = .;
   IF (SDLED_3_16 <= -1.00) THEN SDLED_3_16 = .;
   IF (SDLED_4_16 <= -1.0000) THEN SDLED_4_16 = .;
   IF (SDLED_5_16 <= -1.0000) THEN SDLED_5_16 = .;
   IF (SDLED_6_16 <= -1.0000) THEN SDLED_6_16 = .;
   IF (DRUGID_17 <= -1) THEN DRUGID_17 = .;
   IF (CATID_1_17 <= -1) THEN CATID_1_17 = .;
   IF (CATID_2_17 <= -1) THEN CATID_2_17 = .;
   IF (CATID_3_17 <= -1) THEN CATID_3_17 = .;
   IF (ROUTE_17 <= -1) THEN ROUTE_17 = .;
   IF (TOXTEST_17 <= -1) THEN TOXTEST_17 = .;
   IF (SDLED_1_17 <= -1) THEN SDLED_1_17 = .;
   IF (SDLED_2_17 <= -1.0) THEN SDLED_2_17 = .;
   IF (SDLED_3_17 <= -1.00) THEN SDLED_3_17 = .;
   IF (SDLED_4_17 <= -1.0000) THEN SDLED_4_17 = .;
   IF (SDLED_5_17 <= -1.0000) THEN SDLED_5_17 = .;
   IF (SDLED_6_17 <= -1.0000) THEN SDLED_6_17 = .;
   IF (DRUGID_18 <= -1) THEN DRUGID_18 = .;
   IF (CATID_1_18 <= -1) THEN CATID_1_18 = .;
   IF (CATID_2_18 <= -1) THEN CATID_2_18 = .;
   IF (CATID_3_18 <= -1) THEN CATID_3_18 = .;
   IF (ROUTE_18 <= -1) THEN ROUTE_18 = .;
   IF (TOXTEST_18 <= -1) THEN TOXTEST_18 = .;
   IF (SDLED_1_18 <= -1) THEN SDLED_1_18 = .;
   IF (SDLED_2_18 <= -1.0) THEN SDLED_2_18 = .;
   IF (SDLED_3_18 <= -1.00) THEN SDLED_3_18 = .;
   IF (SDLED_4_18 <= -1.0000) THEN SDLED_4_18 = .;
   IF (SDLED_5_18 <= -1.0000) THEN SDLED_5_18 = .;
   IF (SDLED_6_18 <= -1.0000) THEN SDLED_6_18 = .;
   IF (DRUGID_19 <= -1) THEN DRUGID_19 = .;
   IF (CATID_1_19 <= -1) THEN CATID_1_19 = .;
   IF (CATID_2_19 <= -1) THEN CATID_2_19 = .;
   IF (CATID_3_19 <= -1) THEN CATID_3_19 = .;
   IF (ROUTE_19 <= -1) THEN ROUTE_19 = .;
   IF (TOXTEST_19 <= -1) THEN TOXTEST_19 = .;
   IF (SDLED_1_19 <= -1) THEN SDLED_1_19 = .;
   IF (SDLED_2_19 <= -1.0) THEN SDLED_2_19 = .;
   IF (SDLED_3_19 <= -1.00) THEN SDLED_3_19 = .;
   IF (SDLED_4_19 <= -1.0000) THEN SDLED_4_19 = .;
   IF (SDLED_5_19 <= -1.0000) THEN SDLED_5_19 = .;
   IF (SDLED_6_19 <= -1.0000) THEN SDLED_6_19 = .;
   IF (DRUGID_20 <= -1) THEN DRUGID_20 = .;
   IF (CATID_1_20 <= -1) THEN CATID_1_20 = .;
   IF (CATID_2_20 <= -1) THEN CATID_2_20 = .;
   IF (CATID_3_20 <= -1) THEN CATID_3_20 = .;
   IF (ROUTE_20 <= -1) THEN ROUTE_20 = .;
   IF (TOXTEST_20 <= -1) THEN TOXTEST_20 = .;
   IF (SDLED_1_20 <= -1) THEN SDLED_1_20 = .;
   IF (SDLED_2_20 <= -1.0) THEN SDLED_2_20 = .;
   IF (SDLED_3_20 <= -1.00) THEN SDLED_3_20 = .;
   IF (SDLED_4_20 <= -1.0000) THEN SDLED_4_20 = .;
   IF (SDLED_5_20 <= -1.0000) THEN SDLED_5_20 = .;
   IF (SDLED_6_20 <= -1.0000) THEN SDLED_6_20 = .;
   IF (DRUGID_21 <= -1) THEN DRUGID_21 = .;
   IF (CATID_1_21 <= -1) THEN CATID_1_21 = .;
   IF (CATID_2_21 <= -1) THEN CATID_2_21 = .;
   IF (CATID_3_21 <= -1) THEN CATID_3_21 = .;
   IF (ROUTE_21 <= -1) THEN ROUTE_21 = .;
   IF (TOXTEST_21 <= -1) THEN TOXTEST_21 = .;
   IF (SDLED_1_21 <= -1) THEN SDLED_1_21 = .;
   IF (SDLED_2_21 <= -1.0) THEN SDLED_2_21 = .;
   IF (SDLED_3_21 <= -1.00) THEN SDLED_3_21 = .;
   IF (SDLED_4_21 <= -1.0000) THEN SDLED_4_21 = .;
   IF (SDLED_5_21 <= -1.0000) THEN SDLED_5_21 = .;
   IF (SDLED_6_21 <= -1.0000) THEN SDLED_6_21 = .;
   IF (DRUGID_22 <= -1) THEN DRUGID_22 = .;
   IF (CATID_1_22 <= -1) THEN CATID_1_22 = .;
   IF (CATID_2_22 <= -1) THEN CATID_2_22 = .;
   IF (CATID_3_22 <= -1) THEN CATID_3_22 = .;
   IF (ROUTE_22 <= -1) THEN ROUTE_22 = .;
   IF (TOXTEST_22 <= -1) THEN TOXTEST_22 = .;
   IF (SDLED_1_22 <= -1) THEN SDLED_1_22 = .;
   IF (SDLED_2_22 <= -1.0) THEN SDLED_2_22 = .;
   IF (SDLED_3_22 <= -1.00) THEN SDLED_3_22 = .;
   IF (SDLED_4_22 <= -1.0000) THEN SDLED_4_22 = .;
   IF (SDLED_5_22 <= -1.0000) THEN SDLED_5_22 = .;
   IF (SDLED_6_22 <= -1.0000) THEN SDLED_6_22 = .;
   IF (DISPOSITION <= -1) THEN DISPOSITION = .;
*/


* SAS FORMAT STATEMENT;

/*
   FORMAT
         AGECAT agecatff. ALCOHOL alcoholf. ALLABUSE allabusf.
         CASETYPE casetypf. CATID_1_1 catid_1f. CATID_1_10 catid_1f.
         CATID_1_11 catid_1f. CATID_1_12 catid_1f. CATID_1_13 catid_1f.
         CATID_1_14 catid_1f. CATID_1_15 catid_1f. CATID_1_16 catid_1f.
         CATID_1_17 catid_1f. CATID_1_18 catid_1f. CATID_1_19 catid_1f.
         CATID_1_2 catid_1f. CATID_1_20 catid_1f. CATID_1_21 catid_1f.
         CATID_1_22 catid_1f. CATID_1_3 catid_1f. CATID_1_4 catid_1f.
         CATID_1_5 catid_1f. CATID_1_6 catid_1f. CATID_1_7 catid_1f.
         CATID_1_8 catid_1f. CATID_1_9 catid_1f. CATID_2_1 catid_2f.
         CATID_2_10 catid_2f. CATID_2_11 catid_2f. CATID_2_12 catid_2f.
         CATID_2_13 catid_2f. CATID_2_14 catid_2f. CATID_2_15 catid_2f.
         CATID_2_16 catid_2f. CATID_2_17 catid_2f. CATID_2_18 catid_2f.
         CATID_2_19 catid_2f. CATID_2_2 catid_2f. CATID_2_20 catid_2f.
         CATID_2_21 catid_2f. CATID_2_22 catid_2f. CATID_2_3 catid_2f.
         CATID_2_4 catid_2f. CATID_2_5 catid_2f. CATID_2_6 catid_2f.
         CATID_2_7 catid_2f. CATID_2_8 catid_2f. CATID_2_9 catid_2f.
         CATID_3_1 catid_3f. CATID_3_10 catid_3f. CATID_3_11 catid_3f.
         CATID_3_12 catid_3f. CATID_3_13 catid_3f. CATID_3_14 catid_3f.
         CATID_3_15 catid_3f. CATID_3_16 catid_3f. CATID_3_17 catid_3f.
         CATID_3_18 catid_3f. CATID_3_19 catid_3f. CATID_3_2 catid_3f.
         CATID_3_20 catid_3f. CATID_3_21 catid_3f. CATID_3_22 catid_3f.
         CATID_3_3 catid_3f. CATID_3_4 catid_3f. CATID_3_5 catid_3f.
         CATID_3_6 catid_3f. CATID_3_7 catid_3f. CATID_3_8 catid_3f.
         CATID_3_9 catid_3f. DAYPART daypartf. DISPOSITION disposif.
         DRUGID_1 drugid_f. DRUGID_10 drugid_f. DRUGID_11 drugid_f.
         DRUGID_12 drugid_f. DRUGID_13 drugid_f. DRUGID_14 drugid_f.
         DRUGID_15 drugid_f. DRUGID_16 drugid_f. DRUGID_17 drugid_f.
         DRUGID_18 drugid_f. DRUGID_19 drugid_f. DRUGID_2 drugid_f.
         DRUGID_20 drugid_f. DRUGID_21 drugid_f. DRUGID_22 drugid_f.
         DRUGID_3 drugid_f. DRUGID_4 drugid_f. DRUGID_5 drugid_f.
         DRUGID_6 drugid_f. DRUGID_7 drugid_f. DRUGID_8 drugid_f.
         DRUGID_9 drugid_f. METRO metrofff. NONALCILL nonalcif.
         NONMEDPHARMA nonmedpf. PHARMA pharmaff. QUARTER quarterf.
         RACE raceffff. ROUTE_1 route_1f. ROUTE_10 route_1f.
         ROUTE_11 route_1f. ROUTE_12 route_1f. ROUTE_13 route_1f.
         ROUTE_14 route_1f. ROUTE_15 route_1f. ROUTE_16 route_1f.
         ROUTE_17 route_1f. ROUTE_18 route_1f. ROUTE_19 route_1f.
         ROUTE_2 route_1f. ROUTE_20 route_1f. ROUTE_21 route_1f.
         ROUTE_22 route_1f. ROUTE_3 route_1f. ROUTE_4 route_1f.
         ROUTE_5 route_1f. ROUTE_6 route_1f. ROUTE_7 route_1f.
         ROUTE_8 route_1f. ROUTE_9 route_1f. SDLED_1_1 sdled_1f.
         SDLED_1_10 sdled_1f. SDLED_1_11 sdled_1f. SDLED_1_12 sdled_1f.
         SDLED_1_13 sdled_1f. SDLED_1_14 sdled_1f. SDLED_1_15 sdled_1f.
         SDLED_1_16 sdled_1f. SDLED_1_17 sdled_1f. SDLED_1_18 sdled_1f.
         SDLED_1_19 sdled_1f. SDLED_1_2 sdled_1f. SDLED_1_20 sdled_1f.
         SDLED_1_21 sdled_1f. SDLED_1_22 sdled_1f. SDLED_1_3 sdled_1f.
         SDLED_1_4 sdled_1f. SDLED_1_5 sdled_1f. SDLED_1_6 sdled_1f.
         SDLED_1_7 sdled_1f. SDLED_1_8 sdled_1f. SDLED_1_9 sdled_1f.
         SDLED_2_1 sdled_2f. SDLED_2_10 sdled_2f. SDLED_2_11 sdled_2f.
         SDLED_2_12 sdled_2f. SDLED_2_13 sdled_2f. SDLED_2_14 sdled_2f.
         SDLED_2_15 sdled_2f. SDLED_2_16 sdled_2f. SDLED_2_17 sdled_2f.
         SDLED_2_18 sdled_2f. SDLED_2_19 sdled_2f. SDLED_2_2 sdled_2f.
         SDLED_2_20 sdled_2f. SDLED_2_21 sdled_2f. SDLED_2_22 sdled_2f.
         SDLED_2_3 sdled_2f. SDLED_2_4 sdled_2f. SDLED_2_5 sdled_2f.
         SDLED_2_6 sdled_2f. SDLED_2_7 sdled_2f. SDLED_2_8 sdled_2f.
         SDLED_2_9 sdled_2f. SDLED_3_1 sdled_3f. SDLED_3_10 sdled_3f.
         SDLED_3_11 sdled_3f. SDLED_3_12 sdled_3f. SDLED_3_13 sdled_3f.
         SDLED_3_14 sdled_3f. SDLED_3_15 sdled_3f. SDLED_3_16 sdled_3f.
         SDLED_3_17 sdled_3f. SDLED_3_18 sdled_3f. SDLED_3_19 sdled_3f.
         SDLED_3_2 sdled_3f. SDLED_3_20 sdled_3f. SDLED_3_21 sdled_3f.
         SDLED_3_22 sdled_3f. SDLED_3_3 sdled_3f. SDLED_3_4 sdled_3f.
         SDLED_3_5 sdled_3f. SDLED_3_6 sdled_3f. SDLED_3_7 sdled_3f.
         SDLED_3_8 sdled_3f. SDLED_3_9 sdled_3f. SDLED_4_1 sdled_4f.
         SDLED_4_10 sdled_4f. SDLED_4_11 sdled_4f. SDLED_4_12 sdled_4f.
         SDLED_4_13 sdled_4f. SDLED_4_14 sdled_4f. SDLED_4_15 sdled_4f.
         SDLED_4_16 sdled_4f. SDLED_4_17 sdled_4f. SDLED_4_18 sdled_4f.
         SDLED_4_19 sdled_4f. SDLED_4_2 sdled_4f. SDLED_4_20 sdled_4f.
         SDLED_4_21 sdled_4f. SDLED_4_22 sdled_4f. SDLED_4_3 sdled_4f.
         SDLED_4_4 sdled_4f. SDLED_4_5 sdled_4f. SDLED_4_6 sdled_4f.
         SDLED_4_7 sdled_4f. SDLED_4_8 sdled_4f. SDLED_4_9 sdled_4f.
         SDLED_5_1 sdled_5f. SDLED_5_10 sdled_5f. SDLED_5_11 sdled_5f.
         SDLED_5_12 sdled_5f. SDLED_5_13 sdled_5f. SDLED_5_14 sdled_5f.
         SDLED_5_15 sdled_5f. SDLED_5_16 sdled_5f. SDLED_5_17 sdled_5f.
         SDLED_5_18 sdled_5f. SDLED_5_19 sdled_5f. SDLED_5_2 sdled_5f.
         SDLED_5_20 sdled_5f. SDLED_5_21 sdled_5f. SDLED_5_22 sdled_5f.
         SDLED_5_3 sdled_5f. SDLED_5_4 sdled_5f. SDLED_5_5 sdled_5f.
         SDLED_5_6 sdled_5f. SDLED_5_7 sdled_5f. SDLED_5_8 sdled_5f.
         SDLED_5_9 sdled_5f. SDLED_6_1 sdled_6f. SDLED_6_10 sdled_6f.
         SDLED_6_11 sdled_6f. SDLED_6_12 sdled_6f. SDLED_6_13 sdled_6f.
         SDLED_6_14 sdled_6f. SDLED_6_15 sdled_6f. SDLED_6_16 sdled_6f.
         SDLED_6_17 sdled_6f. SDLED_6_18 sdled_6f. SDLED_6_19 sdled_6f.
         SDLED_6_2 sdled_6f. SDLED_6_20 sdled_6f. SDLED_6_21 sdled_6f.
         SDLED_6_22 sdled_6f. SDLED_6_3 sdled_6f. SDLED_6_4 sdled_6f.
         SDLED_6_5 sdled_6f. SDLED_6_6 sdled_6f. SDLED_6_7 sdled_6f.
         SDLED_6_8 sdled_6f. SDLED_6_9 sdled_6f. SEX sexfffff.
         TOXTEST_1 toxtestf. TOXTEST_10 toxtestf. TOXTEST_11 toxtestf.
         TOXTEST_12 toxtestf. TOXTEST_13 toxtestf. TOXTEST_14 toxtestf.
         TOXTEST_15 toxtestf. TOXTEST_16 toxtestf. TOXTEST_17 toxtestf.
         TOXTEST_18 toxtestf. TOXTEST_19 toxtestf. TOXTEST_2 toxtestf.
         TOXTEST_20 toxtestf. TOXTEST_21 toxtestf. TOXTEST_22 toxtestf.
         TOXTEST_3 toxtestf. TOXTEST_4 toxtestf. TOXTEST_5 toxtestf.
         TOXTEST_6 toxtestf. TOXTEST_7 toxtestf. TOXTEST_8 toxtestf.
         TOXTEST_9 toxtestf.
    ;
*/

RUN ;
